@@ -23,16 +23,21 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-import sys
 import getopt
 import logging
+import sys
+
+from typing import TYPE_CHECKING
 
 from PyQt5.QtWidgets import QApplication, QErrorMessage
 
-from novelwriter.error import exceptionHandler, logException
 from novelwriter.config import Config
+from novelwriter.error import exceptionHandler
 from novelwriter.shared import SharedData
 
+if TYPE_CHECKING:  # pragma: no cover
+    from novelwriter.guimain import GuiMain
+
 # Package Meta
 # ============
 
@@ -42,9 +47,9 @@ __license__    = "GPLv3"
 __author__     = "Veronica Berglyd Olsen"
 __maintainer__ = "Veronica Berglyd Olsen"
 __email__      = "code@vkbo.net"
-__version__    = "2.2.1"
-__hexversion__ = "0x020201f0"
-__date__       = "2024-01-27"
+__version__    = "2.5.1"
+__hexversion__ = "0x020501f0"
+__date__       = "2024-07-28"
 __status__     = "Stable"
 __domain__     = "novelwriter.io"
 
@@ -60,7 +65,7 @@ CONFIG = Config()
 SHARED = SharedData()
 
 
-def main(sysArgs: list | None = None):
+def main(sysArgs: list | None = None) -> GuiMain | None:
     """Parse command line, set up logging, and launch main GUI."""
     if sysArgs is None:
         sysArgs = sys.argv[1:]
@@ -131,7 +136,7 @@ def main(sysArgs: list | None = None):
         elif inOpt == "--debug":
             CONFIG.isDebug = True
             logLevel = logging.DEBUG
-            logFormat  = "[{asctime:}]  {filename:>17}:{lineno:<4d}  {levelname:8}  {message:}"
+            logFormat  = "[{asctime:}]  {filename:>18}:{lineno:<4d}  {levelname:8}  {message:}"
         elif inOpt == "--style":
             qtStyle = inArg
         elif inOpt == "--config":
@@ -157,19 +162,19 @@ def main(sysArgs: list | None = None):
     # Check Packages and Versions
     errorData = []
     errorCode = 0
-    if sys.hexversion < 0x030800f0:
+    if sys.hexversion < 0x030900f0:
         errorData.append(
-            "At least Python 3.8 is required, found %s" % CONFIG.verPyString
+            "At least Python 3.9 is required, found %s" % CONFIG.verPyString
         )
         errorCode |= 0x04
-    if CONFIG.verQtValue < 0x050a00:
+    if CONFIG.verQtValue < 0x050f00:
         errorData.append(
-            "At least Qt5 version 5.10 is required, found %s" % CONFIG.verQtString
+            "At least Qt5 version 5.15.0 is required, found %s" % CONFIG.verQtString
         )
         errorCode |= 0x08
-    if CONFIG.verPyQtValue < 0x050a00:
+    if CONFIG.verPyQtValue < 0x050f00:
         errorData.append(
-            "At least PyQt5 version 5.10 is required, found %s" % CONFIG.verPyQtString
+            "At least PyQt5 version 5.15.0 is required, found %s" % CONFIG.verPyQtString
         )
         errorCode |= 0x10
 
@@ -187,56 +192,52 @@ def main(sysArgs: list | None = None):
         ))
         for errLine in errorData:
             logger.critical(errLine)
-        errApp.exec_()
+        errApp.exec()
         sys.exit(errorCode)
 
     # Finish initialising config
     CONFIG.initConfig(confPath, dataPath)
 
-    if CONFIG.osDarwin:
+    if sys.platform == "darwin":
         try:
-            from Foundation import NSBundle
+            from Foundation import NSBundle  # type: ignore
             bundle = NSBundle.mainBundle()
             info = bundle.localizedInfoDictionary() or bundle.infoDictionary()
             info["CFBundleName"] = "novelWriter"
         except Exception:
-            logger.error("Failed to set application name")
-            logException()
-
-    elif CONFIG.osWindows:
+            pass  # Quietly ignore error
+    elif sys.platform == "win32":
         try:
             import ctypes
             appID = f"io.novelwriter.{__version__}"
-            ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(appID)
+            ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(appID)  # type: ignore
         except Exception:
-            logger.error("Failed to set application name")
-            logException()
+            pass  # Quietly ignore error
 
     # Import GUI (after dependency checks), and launch
     from novelwriter.guimain import GuiMain
+
     if testMode:
-        nwGUI = GuiMain()
-        return nwGUI
+        # Only used for testing where the test framework creates the app
+        CONFIG.loadConfig()
+        return GuiMain()
 
-    else:
-        nwApp = QApplication([CONFIG.appName, (f"-style={qtStyle}")])
-        nwApp.setApplicationName(CONFIG.appName)
-        nwApp.setApplicationVersion(__version__)
-        nwApp.setOrganizationDomain(__domain__)
-        nwApp.setOrganizationName(__domain__)
-        nwApp.setDesktopFileName(CONFIG.appName)
+    app = QApplication([CONFIG.appName, (f"-style={qtStyle}")])
+    app.setApplicationName(CONFIG.appName)
+    app.setApplicationVersion(__version__)
+    app.setOrganizationDomain(__domain__)
+    app.setOrganizationName(__domain__)
+    app.setDesktopFileName(CONFIG.appName)
 
-        # Connect the exception handler before making the main GUI
-        sys.excepthook = exceptionHandler
+    # Connect the exception handler before making the main GUI
+    sys.excepthook = exceptionHandler
 
-        # Run Config steps that require the QApplication
-        CONFIG.initLocalisation(nwApp)
-        CONFIG.setTextFont(CONFIG.textFont, CONFIG.textSize)  # Makes sure these are valid
+    # Run Config steps that require the QApplication
+    CONFIG.loadConfig()
+    CONFIG.initLocalisation(app)
 
-        # Launch main GUI
-        nwGUI = GuiMain()
-        nwGUI.postLaunchTasks(cmdOpen)
+    # Launch main GUI
+    nwGUI = GuiMain()
+    nwGUI.postLaunchTasks(cmdOpen)
 
-        sys.exit(nwApp.exec_())
-
-# END Function main
+    sys.exit(app.exec())
