@@ -24,27 +24,32 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 from __future__ import annotations
 
 import json
-import uuid
 import logging
 import unicodedata
+import uuid
 import xml.etree.ElementTree as ET
 
-from typing import Any, Literal
-from pathlib import Path
-from datetime import datetime
 from configparser import ConfigParser
+from datetime import datetime
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, Literal, TypeVar
 from urllib.parse import urljoin
 from urllib.request import pathname2url
 
-from PyQt5.QtGui import QDesktopServices
 from PyQt5.QtCore import QCoreApplication, QUrl
+from PyQt5.QtGui import QColor, QDesktopServices, QFont, QFontInfo
 
-from novelwriter.enum import nwItemClass, nwItemType, nwItemLayout
+from novelwriter.constants import nwConst, nwLabels, nwUnicode, trConst
+from novelwriter.enum import nwItemClass, nwItemLayout, nwItemType
 from novelwriter.error import logException
-from novelwriter.constants import nwConst, nwUnicode
+
+if TYPE_CHECKING:  # pragma: no cover
+    from typing import TypeGuard  # Requires Python 3.10
 
 logger = logging.getLogger(__name__)
 
+_Type = TypeVar("_Type")
+
 
 ##
 #  Checker Functions
@@ -104,15 +109,6 @@ def checkBool(value: Any, default: bool) -> bool:
     return default
 
 
-def checkHandle(value, default, allowNone=False):
-    """Check if a value is a handle."""
-    if allowNone and (value is None or value == "None"):
-        return None
-    if isHandle(value):
-        return str(value)
-    return default
-
-
 def checkUuid(value: Any, default: str) -> str:
     """Try to process a value as an UUID, or return a default."""
     try:
@@ -135,7 +131,7 @@ def checkPath(value: Any, default: Path) -> Path:
 #  Validator Functions
 ##
 
-def isHandle(value: Any) -> bool:
+def isHandle(value: Any) -> TypeGuard[str]:
     """Check if a string is a valid novelWriter handle.
     Note: This is case sensitive. Must be lower case!
     """
@@ -149,7 +145,7 @@ def isHandle(value: Any) -> bool:
     return True
 
 
-def isTitleTag(value: Any) -> bool:
+def isTitleTag(value: Any) -> TypeGuard[str]:
     """Check if a string is a valid title tag string."""
     if not isinstance(value, str):
         return False
@@ -163,19 +159,24 @@ def isTitleTag(value: Any) -> bool:
     return True
 
 
-def isItemClass(value: str) -> bool:
+def isItemClass(value: Any) -> TypeGuard[str]:
     """Check if a string is a valid nwItemClass identifier."""
-    return value in nwItemClass.__members__
+    return isinstance(value, str) and value in nwItemClass.__members__
 
 
-def isItemType(value: str) -> bool:
+def isItemType(value: Any) -> TypeGuard[str]:
     """Check if a string is a valid nwItemType identifier."""
-    return value in nwItemType.__members__
+    return isinstance(value, str) and value in nwItemType.__members__
 
 
-def isItemLayout(value: str) -> bool:
+def isItemLayout(value: Any) -> TypeGuard[str]:
     """Check if a string is a valid nwItemLayout identifier."""
-    return value in nwItemLayout.__members__
+    return isinstance(value, str) and value in nwItemLayout.__members__
+
+
+def isListInstance(data: Any, check: type[_Type]) -> TypeGuard[list[_Type]]:
+    """Check that all items of a list is of a given type."""
+    return isinstance(data, list) and all(isinstance(item, check) for item in data)
 
 
 def hexToInt(value: Any, default: int = 0) -> int:
@@ -189,8 +190,7 @@ def hexToInt(value: Any, default: int = 0) -> int:
 
 
 def minmax(value: int, minVal: int, maxVal: int) -> int:
-    """Make sure an integer is between min and max value (inclusive).
-    """
+    """Check that an value is between min and max value (inclusive)."""
     return min(maxVal, max(minVal, value))
 
 
@@ -213,17 +213,17 @@ def formatInt(value: int) -> str:
     if not isinstance(value, int):
         return "ERR"
 
-    theVal = float(value)
-    if theVal > 1000.0:
+    fVal = float(value)
+    if fVal > 1000.0:
         for pF in ["k", "M", "G", "T", "P", "E"]:
-            theVal /= 1000.0
-            if theVal < 1000.0:
-                if theVal < 10.0:
-                    return f"{theVal:4.2f}{nwUnicode.U_THSP}{pF}"
-                elif theVal < 100.0:
-                    return f"{theVal:4.1f}{nwUnicode.U_THSP}{pF}"
+            fVal /= 1000.0
+            if fVal < 1000.0:
+                if fVal < 10.0:
+                    return f"{fVal:4.2f}{nwUnicode.U_THSP}{pF}"
+                elif fVal < 100.0:
+                    return f"{fVal:4.1f}{nwUnicode.U_THSP}{pF}"
                 else:
-                    return f"{theVal:3.0f}{nwUnicode.U_THSP}{pF}"
+                    return f"{fVal:3.0f}{nwUnicode.U_THSP}{pF}"
 
     return str(value)
 
@@ -250,6 +250,24 @@ def formatTime(t: int) -> str:
     return "ERROR"
 
 
+def formatVersion(value: str) -> str:
+    """Format a version number into a more human readable form."""
+    return value.lower().replace("a", " Alpha ").replace("b", " Beta ").replace("rc", " RC ")
+
+
+def formatFileFilter(extensions: list[str | tuple[str, str]]) -> str:
+    """Format a list of extensions, or extension + label pairs into a
+    QFileDialog extensions filter.
+    """
+    result = []
+    for ext in extensions:
+        if isinstance(ext, str):
+            result.append(f"{trConst(nwLabels.FILE_FILTERS.get(ext, 'ERR'))} ({ext})")
+        elif isinstance(ext, tuple) and len(ext) == 2:
+            result.append(f"{ext[0]} ({ext[1]})")
+    return ";;".join(result)
+
+
 ##
 #  String Functions
 ##
@@ -261,6 +279,23 @@ def simplified(text: str) -> str:
     return " ".join(str(text).strip().split())
 
 
+def compact(text: str) -> str:
+    """Compact a string by removing spaces."""
+    return "".join(str(text).split())
+
+
+def uniqueCompact(text: str) -> str:
+    """Return a unique, compact and sorted string."""
+    return "".join(sorted(set(compact(text))))
+
+
+def elide(text: str, length: int) -> str:
+    """Elide a piece of text to a maximum length."""
+    if len(text) > (cut := max(4, length)):
+        return f"{text[:cut-4].rstrip()} ..."
+    return text
+
+
 def yesNo(value: int | bool | None) -> Literal["yes", "no"]:
     """Convert a boolean evaluated variable to a yes or no."""
     return "yes" if value else "no"
@@ -270,22 +305,22 @@ def transferCase(source: str, target: str) -> str:
     """Transfers the case of the source word to the target word. This
     will consider all upper or lower, and first char capitalisation.
     """
-    theResult = target
+    result = target
 
     if not isinstance(source, str) or not isinstance(target, str):
-        return theResult
+        return result
     if len(target) < 1 or len(source) < 1:
-        return theResult
+        return result
 
     if source.istitle():
-        theResult = target.title()
+        result = target.title()
 
     if source.isupper():
-        theResult = target.upper()
+        result = target.upper()
     elif source.islower():
-        theResult = target.lower()
+        result = target.lower()
 
-    return theResult
+    return result
 
 
 def fuzzyTime(seconds: int) -> str:
@@ -371,6 +406,21 @@ def numberToRoman(value: int, toLower: bool = False) -> str:
     return roman.lower() if toLower else roman
 
 
+def cssCol(col: QColor, alpha: int | None = None) -> str:
+    """Convert a QColor object to an rgba entry to use in CSS."""
+    return f"rgba({col.red()}, {col.green()}, {col.blue()}, {alpha or col.alpha()})"
+
+
+def describeFont(font: QFont) -> str:
+    """Describe a font in a way that can be displayed on the GUI."""
+    if isinstance(font, QFont):
+        info = QFontInfo(font)
+        family = info.family()
+        styles = [v for v in info.styleName().split() if v not in family]
+        return " ".join([f"{info.pointSize()} pt", family] + styles)
+    return "Error"
+
+
 ##
 #  Encoder Functions
 ##
@@ -433,7 +483,7 @@ def xmlIndent(tree: ET.Element | ET.ElementTree) -> None:
 
     indentations = ["\n"]
 
-    def indentChildren(elem, level):
+    def indentChildren(elem: ET.Element, level: int) -> None:
         chLevel = level + 1
         try:
             chIndent = indentations[chLevel]
@@ -456,6 +506,8 @@ def xmlIndent(tree: ET.Element | ET.ElementTree) -> None:
         if last is not None:
             last.tail = indentations[level]
 
+        return
+
     if len(tree):
         indentChildren(tree, 0)
     tree.tail = "\n"
@@ -481,12 +533,11 @@ def readTextFile(path: str | Path) -> str:
 
 
 def makeFileNameSafe(text: str) -> str:
-    """Return a filename safe string.
+    """Return a filename-safe string.
     See: https://unicode.org/reports/tr15/#Norm_Forms
     """
     text = unicodedata.normalize("NFKC", text).strip()
-    allowed = (" ", ".", "-", "_")
-    return "".join(c for c in text if c.isalnum() or c in allowed)
+    return "".join(c for c in text if c.isprintable() and c not in r'\/:*?"<>|')
 
 
 def getFileSize(path: Path) -> int:
@@ -518,8 +569,9 @@ class NWConfigParser(ConfigParser):
     helper functions, and support for lists.
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
+        return
 
     def rdStr(self, section: str, option: str, default: str) -> str:
         """Read string value."""
@@ -570,5 +622,3 @@ class NWConfigParser(ConfigParser):
             for i in range(min(len(data), len(result))):
                 result[i] = checkInt(data[i].strip(), result[i])
         return result
-
-# END Class NWConfigParser
