@@ -5,6 +5,7 @@ novelWriter – Config Class
 File History:
 Created: 2018-09-22 [0.0.1]  Config
 Created: 2022-11-09 [2.0rc2] RecentProjects
+Created: 2024-06-16 [2.5rc1] RecentPaths
 
 This file is a part of novelWriter
 Copyright 2018–2024, Veronica Berglyd Olsen
@@ -24,23 +25,24 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-import sys
 import json
 import logging
+import sys
 
-from time import time
+from datetime import datetime
 from pathlib import Path
+from time import time
 
-from PyQt5.QtGui import QFontDatabase
 from PyQt5.QtCore import (
     PYQT_VERSION, PYQT_VERSION_STR, QT_VERSION, QT_VERSION_STR, QLibraryInfo,
     QLocale, QStandardPaths, QSysInfo, QTranslator
 )
+from PyQt5.QtGui import QFont, QFontDatabase
 from PyQt5.QtWidgets import QApplication
 
-from novelwriter.error import formatException, logException
-from novelwriter.common import NWConfigParser, checkInt, checkPath, formatTimeStamp
+from novelwriter.common import NWConfigParser, checkInt, checkPath, describeFont, formatTimeStamp
 from novelwriter.constants import nwFiles, nwUnicode
+from novelwriter.error import formatException, logException
 
 logger = logging.getLogger(__name__)
 
@@ -60,8 +62,12 @@ class Config:
         self.appHandle = "novelwriter"
 
         # Set Paths
-        confRoot = Path(QStandardPaths.writableLocation(QStandardPaths.ConfigLocation))
-        dataRoot = Path(QStandardPaths.writableLocation(QStandardPaths.AppDataLocation))
+        confRoot = Path(QStandardPaths.writableLocation(
+            QStandardPaths.StandardLocation.ConfigLocation)
+        )
+        dataRoot = Path(QStandardPaths.writableLocation(
+            QStandardPaths.StandardLocation.AppDataLocation)
+        )
 
         self._confPath = confRoot.absolute() / self.appHandle  # The user config location
         self._dataPath = dataRoot.absolute() / self.appHandle  # The user data location
@@ -82,10 +88,13 @@ class Config:
         # Localisation
         # Note that these paths must be strings
         self._nwLangPath = self._appPath / "assets" / "i18n"
-        self._qtLangPath = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
+        self._qtLangPath = QLibraryInfo.location(QLibraryInfo.LibraryLocation.TranslationsPath)
 
-        wantedLocale = self._nwLangPath / f"nw_{QLocale.system().name()}.qm"
-        self._qLocale = QLocale.system() if wantedLocale.exists() else QLocale("en_GB")
+        hasLocale = (self._nwLangPath / f"nw_{QLocale.system().name()}.qm").exists()
+        self._qLocale = QLocale.system() if hasLocale else QLocale("en_GB")
+        self._dLocale = QLocale.system()
+        self._dShortDate = self._dLocale.dateFormat(QLocale.FormatType.ShortFormat)
+        self._dShortDateTime = self._dLocale.dateTimeFormat(QLocale.FormatType.ShortFormat)
         self._qtTrans = {}
 
         # PDF Manual
@@ -95,23 +104,24 @@ class Config:
         # User Settings
         # =============
 
-        self._recentObj = RecentProjects(self)
+        self._recentProjects = RecentProjects(self)
+        self._recentPaths = RecentPaths(self)
 
         # General GUI Settings
-        self.guiLocale   = self._qLocale.name()
-        self.guiTheme    = "default"        # GUI theme
-        self.guiSyntax   = "default_light"  # Syntax theme
-        self.guiFont     = ""               # Defaults to system default font in theme class
-        self.guiFontSize = 11               # Is overridden if system default is loaded
-        self.guiScale    = 1.0              # Set automatically by Theme class
-        self.hideVScroll = False            # Hide vertical scroll bars on main widgets
-        self.hideHScroll = False            # Hide horizontal scroll bars on main widgets
-        self.lastNotes   = "0x0"            # The latest release notes that have been shown
+        self.guiLocale    = self._qLocale.name()
+        self.guiTheme     = "default"        # GUI theme
+        self.guiSyntax    = "default_light"  # Syntax theme
+        self.guiFont      = QFont()          # Main GUI font
+        self.guiScale     = 1.0              # Set automatically by Theme class
+        self.hideVScroll  = False            # Hide vertical scroll bars on main widgets
+        self.hideHScroll  = False            # Hide horizontal scroll bars on main widgets
+        self.lastNotes    = "0x0"            # The latest release notes that have been shown
+        self.nativeFont   = True             # Use native font dialog
 
         # Size Settings
         self._mainWinSize  = [1200, 650]     # Last size of the main GUI window
+        self._welcomeSize  = [800, 550]      # Last size of the welcome window
         self._prefsWinSize = [700, 615]      # Last size of the Preferences dialog
-        self._projLoadCols = [280, 60, 160]  # Last columns widths of the Project Load dialog
         self._mainPanePos  = [300, 800]      # Last position of the main window splitter
         self._viewPanePos  = [500, 150]      # Last position of the document viewer splitter
         self._outlnPanePos = [500, 150]      # Last position of the outline panel splitter
@@ -124,42 +134,42 @@ class Config:
         self.askBeforeBackup = True   # Flag for asking before running automatic backup
 
         # Text Editor Settings
-        self.textFont        = ""     # Editor font
-        self.textSize        = 12     # Editor font size
-        self.textWidth       = 700    # Editor text width
-        self.textMargin      = 40     # Editor/viewer text margin
-        self.tabWidth        = 40     # Editor tabulator width
+        self.textFont        = QFont()  # Editor font
+        self.textWidth       = 700      # Editor text width
+        self.textMargin      = 40       # Editor/viewer text margin
+        self.tabWidth        = 40       # Editor tabulator width
 
-        self.focusWidth      = 800    # Focus Mode text width
-        self.hideFocusFooter = False  # Hide document footer in Focus Mode
-        self.showFullPath    = True   # Show full document path in editor header
-        self.autoSelect      = True   # Auto-select word when applying format with no selection
+        self.focusWidth      = 800      # Focus Mode text width
+        self.hideFocusFooter = False    # Hide document footer in Focus Mode
+        self.showFullPath    = True     # Show full document path in editor header
+        self.autoSelect      = True     # Auto-select word when applying format with no selection
 
-        self.doJustify       = False  # Justify text
-        self.showTabsNSpaces = False  # Show tabs and spaces in editor
-        self.showLineEndings = False  # Show line endings in editor
-        self.showMultiSpaces = True   # Highlight multiple spaces in the text
+        self.doJustify       = False    # Justify text
+        self.showTabsNSpaces = False    # Show tabs and spaces in editor
+        self.showLineEndings = False    # Show line endings in editor
+        self.showMultiSpaces = True     # Highlight multiple spaces in the text
 
-        self.doReplace       = True   # Enable auto-replace as you type
-        self.doReplaceSQuote = True   # Smart single quotes
-        self.doReplaceDQuote = True   # Smart double quotes
-        self.doReplaceDash   = True   # Replace multiple hyphens with dashes
-        self.doReplaceDots   = True   # Replace three dots with ellipsis
+        self.doReplace       = True     # Enable auto-replace as you type
+        self.doReplaceSQuote = True     # Smart single quotes
+        self.doReplaceDQuote = True     # Smart double quotes
+        self.doReplaceDash   = True     # Replace multiple hyphens with dashes
+        self.doReplaceDots   = True     # Replace three dots with ellipsis
 
-        self.autoScroll      = False  # Typewriter-like scrolling
-        self.autoScrollPos   = 30     # Start point for typewriter-like scrolling
-        self.scrollPastEnd   = True   # Scroll past end of document, and centre cursor
+        self.autoScroll      = False    # Typewriter-like scrolling
+        self.autoScrollPos   = 30       # Start point for typewriter-like scrolling
+        self.scrollPastEnd   = True     # Scroll past end of document, and centre cursor
 
-        self.wordCountTimer  = 5.0    # Interval for word count update in seconds
-        self.incNotesWCount  = True   # The status bar word count includes notes
+        self.dialogStyle     = 2        # Quote type to use for dialogue
+        self.allowOpenDial   = True     # Allow open-ended dialogue quotes
+        self.narratorBreak   = ""       # Symbol to use for narrator break
+        self.dialogLine      = ""       # Symbol to use for dialogue line
+        self.altDialogOpen   = ""       # Alternative dialog symbol, open
+        self.altDialogClose  = ""       # Alternative dialog symbol, close
+        self.highlightEmph   = True     # Add colour to text emphasis
 
-        self.highlightQuotes = True   # Highlight text in quotes
-        self.allowOpenSQuote = False  # Allow open-ended single quotes
-        self.allowOpenDQuote = True   # Allow open-ended double quotes
-        self.highlightEmph   = True   # Add colour to text emphasis
-
-        self.stopWhenIdle    = True   # Stop the status bar clock when the user is idle
-        self.userIdleTime    = 300    # Time of inactivity to consider user idle
+        self.stopWhenIdle    = True     # Stop the status bar clock when the user is idle
+        self.userIdleTime    = 300      # Time of inactivity to consider user idle
+        self.incNotesWCount  = True     # The status bar word count includes notes
 
         # User-Selected Symbol Settings
         self.fmtApostrophe   = nwUnicode.U_RSQUO
@@ -172,7 +182,6 @@ class Config:
         self.fmtPadThin      = False
 
         # User Paths
-        self._lastPath   = self._homePath  # The user's last used path
         self._backupPath = self._backPath  # Backup path to use, can be none
 
         # Spell Checking Settings
@@ -181,17 +190,19 @@ class Config:
         # State
         self.showViewerPanel = True   # The panel for the viewer is visible
         self.showEditToolBar = False  # The document editor toolbar visibility
-        self.useShortcodes   = False  # Use shortcodes for basic formatting
         self.viewComments    = True   # Comments are shown in the viewer
         self.viewSynopsis    = True   # Synopsis is shown in the viewer
 
-        # Search Bar Switches
-        self.searchCase     = False
-        self.searchWord     = False
-        self.searchRegEx    = False
-        self.searchLoop     = False
-        self.searchNextFile = False
-        self.searchMatchCap = False
+        # Search Box States
+        self.searchCase      = False
+        self.searchWord      = False
+        self.searchRegEx     = False
+        self.searchLoop      = False
+        self.searchNextFile  = False
+        self.searchMatchCap  = False
+        self.searchProjCase  = False
+        self.searchProjWord  = False
+        self.searchProjRegEx = False
 
         # System and App Information
         # ==========================
@@ -243,19 +254,19 @@ class Config:
 
     @property
     def recentProjects(self) -> RecentProjects:
-        return self._recentObj
+        return self._recentProjects
 
     @property
     def mainWinSize(self) -> list[int]:
         return [int(x*self.guiScale) for x in self._mainWinSize]
 
     @property
-    def preferencesWinSize(self) -> list[int]:
-        return [int(x*self.guiScale) for x in self._prefsWinSize]
+    def welcomeWinSize(self) -> list[int]:
+        return [int(x*self.guiScale) for x in self._welcomeSize]
 
     @property
-    def projLoadColWidths(self) -> list[int]:
-        return [int(x*self.guiScale) for x in self._projLoadCols]
+    def preferencesWinSize(self) -> list[int]:
+        return [int(x*self.guiScale) for x in self._prefsWinSize]
 
     @property
     def mainPanePos(self) -> list[int]:
@@ -306,17 +317,18 @@ class Config:
             self._mainWinSize[1] = height
         return
 
+    def setWelcomeWinSize(self, width: int, height: int) -> None:
+        """Set the size of the Preferences dialog window."""
+        self._welcomeSize[0] = int(width/self.guiScale)
+        self._welcomeSize[1] = int(height/self.guiScale)
+        return
+
     def setPreferencesWinSize(self, width: int, height: int) -> None:
         """Set the size of the Preferences dialog window."""
         self._prefsWinSize[0] = int(width/self.guiScale)
         self._prefsWinSize[1] = int(height/self.guiScale)
         return
 
-    def setProjLoadColWidths(self, widths: list[int]) -> None:
-        """Set the column widths of the Load Project dialog."""
-        self._projLoadCols = [int(x/self.guiScale) for x in widths]
-        return
-
     def setMainPanePos(self, pos: list[int]) -> None:
         """Set the position of the main GUI splitter."""
         self._mainPanePos = [int(x/self.guiScale) for x in pos]
@@ -332,7 +344,7 @@ class Config:
         self._outlnPanePos = [int(x/self.guiScale) for x in pos]
         return
 
-    def setLastPath(self, path: str | Path) -> None:
+    def setLastPath(self, key: str, path: str | Path) -> None:
         """Set the last used path. Only the folder is saved, so if the
         path is not a folder, the parent of the path is used instead.
         """
@@ -341,8 +353,7 @@ class Config:
             if not path.is_dir():
                 path = path.parent
             if path.is_dir():
-                self._lastPath = path
-                logger.debug("Last path updated: %s" % self._lastPath)
+                self._recentPaths.setPath(key, path)
         return
 
     def setBackupPath(self, path: Path | str) -> None:
@@ -350,23 +361,53 @@ class Config:
         self._backupPath = checkPath(path, self._backPath)
         return
 
-    def setTextFont(self, family: str | None, pointSize: int = 12) -> None:
+    def setGuiFont(self, value: QFont | str | None) -> None:
+        """Update the GUI's font style from settings."""
+        if isinstance(value, QFont):
+            self.guiFont = value
+        elif value and isinstance(value, str):
+            self.guiFont = QFont()
+            self.guiFont.fromString(value)
+        else:
+            font = QFont()
+            fontDB = QFontDatabase()
+            if self.osWindows and "Arial" in fontDB.families():
+                # On Windows we default to Arial if possible
+                font.setFamily("Arial")
+                font.setPointSize(10)
+            else:
+                font = fontDB.systemFont(QFontDatabase.SystemFont.GeneralFont)
+            self.guiFont = font
+            logger.debug("GUI font set to: %s", describeFont(font))
+
+        QApplication.setFont(self.guiFont)
+
+        return
+
+    def setTextFont(self, value: QFont | str | None) -> None:
         """Set the text font if it exists. If it doesn't, or is None,
         set to default font.
         """
-        fontDB = QFontDatabase()
-        fontFam = fontDB.families()
-        self.textSize = pointSize
-        if family is None or family not in fontFam:
-            logger.warning("Unknown font '%s'", family)
-            if self.osWindows and "Arial" in fontFam:
-                self.textFont = "Arial"
-            elif self.osDarwin and "Helvetica" in fontFam:
-                self.textFont = "Helvetica"
-            else:
-                self.textFont = fontDB.systemFont(QFontDatabase.GeneralFont).family()
+        if isinstance(value, QFont):
+            self.textFont = value
+        elif value and isinstance(value, str):
+            self.textFont = QFont()
+            self.textFont.fromString(value)
         else:
-            self.textFont = family
+            fontDB = QFontDatabase()
+            fontFam = fontDB.families()
+            if self.osWindows and "Arial" in fontFam:
+                font = QFont()
+                font.setFamily("Arial")
+                font.setPointSize(12)
+            elif self.osDarwin and "Helvetica" in fontFam:
+                font = QFont()
+                font.setFamily("Helvetica")
+                font.setPointSize(12)
+            else:
+                font = fontDB.systemFont(QFontDatabase.SystemFont.GeneralFont)
+            self.textFont = font
+            logger.debug("Text font set to: %s", describeFont(font))
         return
 
     ##
@@ -381,6 +422,10 @@ class Config:
         """Un-scale fixed gui sizes by the screen scale factor."""
         return int(value/self.guiScale)
 
+    def homePath(self) -> Path:
+        """The user's home folder."""
+        return self._homePath
+
     def dataPath(self, target: str | None = None) -> Path:
         """Return a path in the data folder."""
         if isinstance(target, str):
@@ -393,11 +438,12 @@ class Config:
             return self._appPath / "assets" / target
         return self._appPath / "assets"
 
-    def lastPath(self) -> Path:
+    def lastPath(self, key: str) -> Path:
         """Return the last path used by the user, if it exists."""
-        if isinstance(self._lastPath, Path):
-            if self._lastPath.is_dir():
-                return self._lastPath
+        if path := self._recentPaths.getPath(key):
+            asPath = Path(path)
+            if asPath.is_dir():
+                return asPath
         return self._homePath
 
     def backupPath(self) -> Path:
@@ -410,10 +456,18 @@ class Config:
         """Compile and return error messages from the initialisation of
         the Config class, and clear the error buffer.
         """
-        errMessage = "<br>".join(self._errData)
+        message = "<br>".join(self._errData)
         self._hasError = False
         self._errData = []
-        return errMessage
+        return message
+
+    def localDate(self, value: datetime) -> str:
+        """Return a localised date format."""
+        return self._dLocale.toString(value, self._dShortDate)
+
+    def localDateTime(self, value: datetime) -> str:
+        """Return a localised datetime format."""
+        return self._dLocale.toString(value, self._dShortDateTime)
 
     def listLanguages(self, lngSet: int) -> list[tuple[str, str]]:
         """List localisation files in the i18n folder. The default GUI
@@ -463,7 +517,6 @@ class Config:
         logger.debug("Data Path: %s", self._dataPath)
         logger.debug("App Root: %s", self._appRoot)
         logger.debug("App Path: %s", self._appPath)
-        logger.debug("Last Path: %s", self._lastPath)
         logger.debug("PDF Manual: %s", self.pdfDocs)
 
         # If the config and data folders don't exist, create them
@@ -478,13 +531,8 @@ class Config:
             (self._dataPath / "syntax").mkdir(exist_ok=True)
             (self._dataPath / "themes").mkdir(exist_ok=True)
 
-        # Check if config file exists, and load it. If not, we save defaults
-        if (self._confPath / nwFiles.CONF_FILE).is_file():
-            self.loadConfig()
-        else:
-            self.saveConfig()
-
-        self._recentObj.loadCache()
+        self._recentPaths.loadCache()
+        self._recentProjects.loadCache()
         self._checkOptionalPackages()
 
         logger.debug("Config instance initialised")
@@ -497,6 +545,11 @@ class Config:
         QLocale.setDefault(self._qLocale)
         self._qtTrans = {}
 
+        hasLocale = (self._nwLangPath / f"nw_{self._qLocale.name()}.qm").exists()
+        self._dLocale = self._qLocale if hasLocale else QLocale.system()
+        self._dShortDate = self._dLocale.dateFormat(QLocale.FormatType.ShortFormat)
+        self._dShortDateTime = self._dLocale.dateTimeFormat(QLocale.FormatType.ShortFormat)
+
         langList = [
             (self._qtLangPath, "qtbase"),   # Qt 5.x
             (str(self._nwLangPath), "nw"),  # novelWriter
@@ -519,6 +572,14 @@ class Config:
 
         conf = NWConfigParser()
         cnfPath = self._confPath / nwFiles.CONF_FILE
+
+        if not cnfPath.exists():
+            # Initial file, so we just create one from defaults
+            self.setGuiFont(None)
+            self.setTextFont(None)
+            self.saveConfig()
+            return True
+
         try:
             with open(cnfPath, mode="r", encoding="utf-8") as inFile:
                 conf.read_file(inFile)
@@ -532,21 +593,20 @@ class Config:
 
         # Main
         sec = "Main"
+        self.setGuiFont(conf.rdStr(sec, "font", ""))
         self.guiTheme    = conf.rdStr(sec, "theme", self.guiTheme)
         self.guiSyntax   = conf.rdStr(sec, "syntax", self.guiSyntax)
-        self.guiFont     = conf.rdStr(sec, "font", self.guiFont)
-        self.guiFontSize = conf.rdInt(sec, "fontsize", self.guiFontSize)
         self.guiLocale   = conf.rdStr(sec, "localisation", self.guiLocale)
         self.hideVScroll = conf.rdBool(sec, "hidevscroll", self.hideVScroll)
         self.hideHScroll = conf.rdBool(sec, "hidehscroll", self.hideHScroll)
         self.lastNotes   = conf.rdStr(sec, "lastnotes", self.lastNotes)
-        self._lastPath   = conf.rdPath(sec, "lastpath", self._lastPath)
+        self.nativeFont  = conf.rdBool(sec, "nativefont", self.nativeFont)
 
         # Sizes
         sec = "Sizes"
         self._mainWinSize  = conf.rdIntList(sec, "mainwindow", self._mainWinSize)
+        self._welcomeSize  = conf.rdIntList(sec, "welcome", self._welcomeSize)
         self._prefsWinSize = conf.rdIntList(sec, "preferences", self._prefsWinSize)
-        self._projLoadCols = conf.rdIntList(sec, "projloadcols", self._projLoadCols)
         self._mainPanePos  = conf.rdIntList(sec, "mainpane", self._mainPanePos)
         self._viewPanePos  = conf.rdIntList(sec, "viewpane", self._viewPanePos)
         self._outlnPanePos = conf.rdIntList(sec, "outlinepane", self._outlnPanePos)
@@ -562,8 +622,7 @@ class Config:
 
         # Editor
         sec = "Editor"
-        self.textFont        = conf.rdStr(sec, "textfont", self.textFont)
-        self.textSize        = conf.rdInt(sec, "textsize", self.textSize)
+        self.setTextFont(conf.rdStr(sec, "textfont", ""))
         self.textWidth       = conf.rdInt(sec, "width", self.textWidth)
         self.textMargin      = conf.rdInt(sec, "margin", self.textMargin)
         self.tabWidth        = conf.rdInt(sec, "tabwidth", self.tabWidth)
@@ -590,12 +649,14 @@ class Config:
         self.showTabsNSpaces = conf.rdBool(sec, "showtabsnspaces", self.showTabsNSpaces)
         self.showLineEndings = conf.rdBool(sec, "showlineendings", self.showLineEndings)
         self.showMultiSpaces = conf.rdBool(sec, "showmultispaces", self.showMultiSpaces)
-        self.wordCountTimer  = conf.rdFlt(sec, "wordcounttimer", self.wordCountTimer)
         self.incNotesWCount  = conf.rdBool(sec, "incnoteswcount", self.incNotesWCount)
         self.showFullPath    = conf.rdBool(sec, "showfullpath", self.showFullPath)
-        self.highlightQuotes = conf.rdBool(sec, "highlightquotes", self.highlightQuotes)
-        self.allowOpenSQuote = conf.rdBool(sec, "allowopensquote", self.allowOpenSQuote)
-        self.allowOpenDQuote = conf.rdBool(sec, "allowopendquote", self.allowOpenDQuote)
+        self.dialogStyle     = conf.rdInt(sec, "dialogstyle", self.dialogStyle)
+        self.allowOpenDial   = conf.rdBool(sec, "allowopendial", self.allowOpenDial)
+        self.narratorBreak   = conf.rdStr(sec, "narratorbreak", self.narratorBreak)
+        self.altDialogOpen   = conf.rdStr(sec, "altdialogopen", self.altDialogOpen)
+        self.altDialogClose  = conf.rdStr(sec, "altdialogclose", self.altDialogClose)
+        self.dialogLine      = conf.rdStr(sec, "dialogline", self.dialogLine)
         self.highlightEmph   = conf.rdBool(sec, "highlightemph", self.highlightEmph)
         self.stopWhenIdle    = conf.rdBool(sec, "stopwhenidle", self.stopWhenIdle)
         self.userIdleTime    = conf.rdInt(sec, "useridletime", self.userIdleTime)
@@ -604,7 +665,6 @@ class Config:
         sec = "State"
         self.showViewerPanel = conf.rdBool(sec, "showviewerpanel", self.showViewerPanel)
         self.showEditToolBar = conf.rdBool(sec, "showedittoolbar", self.showEditToolBar)
-        self.useShortcodes   = conf.rdBool(sec, "useshortcodes", self.useShortcodes)
         self.viewComments    = conf.rdBool(sec, "viewcomments", self.viewComments)
         self.viewSynopsis    = conf.rdBool(sec, "viewsynopsis", self.viewSynopsis)
         self.searchCase      = conf.rdBool(sec, "searchcase", self.searchCase)
@@ -613,6 +673,9 @@ class Config:
         self.searchLoop      = conf.rdBool(sec, "searchloop", self.searchLoop)
         self.searchNextFile  = conf.rdBool(sec, "searchnextfile", self.searchNextFile)
         self.searchMatchCap  = conf.rdBool(sec, "searchmatchcap", self.searchMatchCap)
+        self.searchProjCase  = conf.rdBool(sec, "searchprojcase", self.searchProjCase)
+        self.searchProjWord  = conf.rdBool(sec, "searchprojword", self.searchProjWord)
+        self.searchProjRegEx = conf.rdBool(sec, "searchprojregex", self.searchProjRegEx)
 
         # Check Values
         # ============
@@ -635,28 +698,27 @@ class Config:
         conf = NWConfigParser()
 
         conf["Meta"] = {
-            "timestamp":    formatTimeStamp(time()),
+            "timestamp": formatTimeStamp(time()),
         }
 
         conf["Main"] = {
+            "font":         self.guiFont.toString(),
             "theme":        str(self.guiTheme),
             "syntax":       str(self.guiSyntax),
-            "font":         str(self.guiFont),
-            "fontsize":     str(self.guiFontSize),
             "localisation": str(self.guiLocale),
             "hidevscroll":  str(self.hideVScroll),
             "hidehscroll":  str(self.hideHScroll),
             "lastnotes":    str(self.lastNotes),
-            "lastpath":     str(self._lastPath),
+            "nativefont":   str(self.nativeFont),
         }
 
         conf["Sizes"] = {
-            "mainwindow":   self._packList(self._mainWinSize),
-            "preferences":  self._packList(self._prefsWinSize),
-            "projloadcols": self._packList(self._projLoadCols),
-            "mainpane":     self._packList(self._mainPanePos),
-            "viewpane":     self._packList(self._viewPanePos),
-            "outlinepane":  self._packList(self._outlnPanePos),
+            "mainwindow":  self._packList(self._mainWinSize),
+            "welcome":     self._packList(self._welcomeSize),
+            "preferences": self._packList(self._prefsWinSize),
+            "mainpane":    self._packList(self._mainPanePos),
+            "viewpane":    self._packList(self._viewPanePos),
+            "outlinepane": self._packList(self._outlnPanePos),
         }
 
         conf["Project"] = {
@@ -669,8 +731,7 @@ class Config:
         }
 
         conf["Editor"] = {
-            "textfont":        str(self.textFont),
-            "textsize":        str(self.textSize),
+            "textfont":        self.textFont.toString(),
             "width":           str(self.textWidth),
             "margin":          str(self.textMargin),
             "tabwidth":        str(self.tabWidth),
@@ -697,12 +758,14 @@ class Config:
             "showtabsnspaces": str(self.showTabsNSpaces),
             "showlineendings": str(self.showLineEndings),
             "showmultispaces": str(self.showMultiSpaces),
-            "wordcounttimer":  str(self.wordCountTimer),
             "incnoteswcount":  str(self.incNotesWCount),
             "showfullpath":    str(self.showFullPath),
-            "highlightquotes": str(self.highlightQuotes),
-            "allowopensquote": str(self.allowOpenSQuote),
-            "allowopendquote": str(self.allowOpenDQuote),
+            "dialogstyle":     str(self.dialogStyle),
+            "allowopendial":   str(self.allowOpenDial),
+            "narratorbreak":   str(self.narratorBreak),
+            "altdialogopen":   str(self.altDialogOpen),
+            "altdialogclose":  str(self.altDialogClose),
+            "dialogline":      str(self.dialogLine),
             "highlightemph":   str(self.highlightEmph),
             "stopwhenidle":    str(self.stopWhenIdle),
             "useridletime":    str(self.userIdleTime),
@@ -711,7 +774,6 @@ class Config:
         conf["State"] = {
             "showviewerpanel": str(self.showViewerPanel),
             "showedittoolbar": str(self.showEditToolBar),
-            "useshortcodes":   str(self.useShortcodes),
             "viewcomments":    str(self.viewComments),
             "viewsynopsis":    str(self.viewSynopsis),
             "searchcase":      str(self.searchCase),
@@ -720,6 +782,9 @@ class Config:
             "searchloop":      str(self.searchLoop),
             "searchnextfile":  str(self.searchNextFile),
             "searchmatchcap":  str(self.searchMatchCap),
+            "searchprojcase":  str(self.searchProjCase),
+            "searchprojword":  str(self.searchProjWord),
+            "searchprojregex": str(self.searchProjRegEx),
         }
 
         # Write config file
@@ -745,7 +810,7 @@ class Config:
         """Pack a list of items into a comma-separated string for saving
         to the config file.
         """
-        return ", ".join([str(inVal) for inVal in data])
+        return ", ".join(str(inVal) for inVal in data)
 
     def _checkOptionalPackages(self) -> None:
         """Check optional packages used by some features."""
@@ -759,8 +824,6 @@ class Config:
             logger.debug("Checking package 'pyenchant': OK")
         return
 
-# END Class Config
-
 
 class RecentProjects:
 
@@ -774,22 +837,20 @@ class RecentProjects:
         self._data = {}
 
         cacheFile = self._conf.dataPath(nwFiles.RECENT_FILE)
-        if not cacheFile.is_file():
-            return True
-
-        try:
-            with open(cacheFile, mode="r", encoding="utf-8") as inFile:
-                theData = json.load(inFile)
-            for projPath, theEntry in theData.items():
-                self._data[projPath] = {
-                    "title": theEntry.get("title", ""),
-                    "words": theEntry.get("words", 0),
-                    "time": theEntry.get("time", 0),
-                }
-        except Exception:
-            logger.error("Could not load recent project cache")
-            logException()
-            return False
+        if cacheFile.is_file():
+            try:
+                with open(cacheFile, mode="r", encoding="utf-8") as inFile:
+                    data = json.load(inFile)
+                for path, entry in data.items():
+                    self._data[path] = {
+                        "title": entry.get("title", ""),
+                        "words": entry.get("words", 0),
+                        "time": entry.get("time", 0),
+                    }
+            except Exception:
+                logger.error("Could not load recent project cache")
+                logException()
+                return False
 
         return True
 
@@ -832,4 +893,55 @@ class RecentProjects:
             self.saveCache()
         return
 
-# END Class RecentProjects
+
+class RecentPaths:
+
+    KEYS = ["default", "project", "import", "outline", "stats"]
+
+    def __init__(self, config: Config) -> None:
+        self._conf = config
+        self._data = {}
+        return
+
+    def setPath(self, key: str, path: Path | str) -> None:
+        """Set a path for a given key, and save the cache."""
+        if key in self.KEYS:
+            self._data[key] = str(path)
+        self.saveCache()
+        return
+
+    def getPath(self, key: str) -> str | None:
+        """Get a path for a given key, or return None."""
+        return self._data.get(key)
+
+    def loadCache(self) -> bool:
+        """Load the cache file for recent paths."""
+        self._data = {}
+        cacheFile = self._conf.dataPath(nwFiles.RECENT_PATH)
+        if cacheFile.is_file():
+            try:
+                with open(cacheFile, mode="r", encoding="utf-8") as inFile:
+                    data = json.load(inFile)
+                if isinstance(data, dict):
+                    for key, path in data.items():
+                        if key in self.KEYS and isinstance(path, str):
+                            self._data[key] = path
+            except Exception:
+                logger.error("Could not load recent paths cache")
+                logException()
+                return False
+        return True
+
+    def saveCache(self) -> bool:
+        """Save the cache dictionary of recent paths."""
+        cacheFile = self._conf.dataPath(nwFiles.RECENT_PATH)
+        cacheTemp = cacheFile.with_suffix(".tmp")
+        try:
+            with open(cacheTemp, mode="w+", encoding="utf-8") as outFile:
+                json.dump(self._data, outFile, indent=2)
+            cacheTemp.replace(cacheFile)
+        except Exception:
+            logger.error("Could not save recent paths cache")
+            logException()
+            return False
+        return True
