@@ -23,11 +23,11 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-import re
+from PyQt5.QtCore import QT_TRANSLATE_NOOP, QCoreApplication
 
-from PyQt5.QtCore import QCoreApplication, QT_TRANSLATE_NOOP
-
-from novelwriter.enum import nwBuildFmt, nwItemClass, nwItemLayout, nwOutline
+from novelwriter.enum import (
+    nwBuildFmt, nwComment, nwItemClass, nwItemLayout, nwOutline, nwStatusShape
+)
 
 
 def trConst(text: str) -> str:
@@ -43,34 +43,28 @@ class nwConst:
     FMT_DSTAMP = "%Y-%m-%d"           # Date only format
 
     # URLs
-    URL_WEB     = "https://novelwriter.io"
-    URL_DOCS    = "https://docs.novelwriter.io"
-    URL_CODE    = "https://github.com/vkbo/novelWriter"
-    URL_REPORT  = "https://github.com/vkbo/novelWriter/issues"
-    URL_HELP    = "https://github.com/vkbo/novelWriter/discussions"
-    URL_RELEASE = "https://github.com/vkbo/novelWriter/releases/latest"
+    URL_WEB      = "https://novelwriter.io"
+    URL_DOCS     = "https://docs.novelwriter.io"
+    URL_RELEASES = "https://releases.novelwriter.io"
+    URL_CODE     = "https://github.com/vkbo/novelWriter"
+    URL_REPORT   = "https://github.com/vkbo/novelWriter/issues"
+    URL_HELP     = "https://github.com/vkbo/novelWriter/discussions"
 
     # Requests
     USER_AGENT = "Mozilla/5.0 (compatible; novelWriter (Python))"
 
     # Gui Settings
     STATUS_MSG_TIMEOUT = 15000  # milliseconds
-
-# END Class nwConst
+    MAX_SEARCH_RESULT = 1000
 
 
 class nwRegEx:
 
     FMT_EI = r"(?<![\w\\])(_)(?![\s_])(.+?)(?<![\s\\])(\1)(?!\w)"
-    FMT_EB = r"(?<![\w\\])([\*]{2})(?![\s\*])(.+?)(?<![\s\\])(\1)(?!\w)"
-    FMT_ST = r"(?<![\w\\])([~]{2})(?![\s~])(.+?)(?<![\s\\])(\1)(?!\w)"
-    FMT_SC = r"(?i)(?<!\\)(\[[\/\!]?(?:i|b|s|u|sup|sub)\])"
-    FMT_SV = r"(?<!\\)(\[(?i)(?:fn|footnote):)(.+?)(?<!\\)(\])"
-
-    # Pre-Compiled RegEx
-    RX_SC = re.compile(FMT_SC)
-
-# END Class nwRegEx
+    FMT_EB = r"(?<![\w\\])(\*{2})(?![\s\*])(.+?)(?<![\s\\])(\1)(?!\w)"
+    FMT_ST = r"(?<![\w\\])(~{2})(?![\s~])(.+?)(?<![\s\\])(\1)(?!\w)"
+    FMT_SC = r"(?i)(?<!\\)(\[[\/\!]?(?:b|i|s|u|m|sup|sub)\])"
+    FMT_SV = r"(?i)(?<!\\)(\[(?:footnote):)(.+?)(?<!\\)(\])"
 
 
 class nwShortcode:
@@ -83,20 +77,26 @@ class nwShortcode:
     STRIKE_C = "[/s]"
     ULINE_O  = "[u]"
     ULINE_C  = "[/u]"
+    MARK_O   = "[m]"
+    MARK_C   = "[/m]"
     SUP_O    = "[sup]"
     SUP_C    = "[/sup]"
     SUB_O    = "[sub]"
     SUB_C    = "[/sub]"
 
-# END Class nwShortcode
+    FOOTNOTE_B = "[footnote:"
+
+    COMMENT_STYLES = {
+        nwComment.FOOTNOTE: "[footnote:{0}]",
+        nwComment.COMMENT:  "[comment:{0}]",
+    }
 
 
 class nwHeaders:
 
     H_VALID = ("H0", "H1", "H2", "H3", "H4")
     H_LEVEL = {"H0": 0, "H1": 1, "H2": 2, "H3": 3, "H4": 4}
-
-# END Class nwHeaders
+    H_SIZES = {0: 2.50, 1: 2.00, 2: 1.75, 3: 1.50, 4: 1.25}
 
 
 class nwFiles:
@@ -104,10 +104,10 @@ class nwFiles:
     # Config Files
     CONF_FILE   = "novelwriter.conf"
     RECENT_FILE = "recentProjects.json"
+    RECENT_PATH = "recentPaths.json"
 
     # Project Root Files
     PROJ_FILE   = "nwProject.nwx"
-    PROJ_BACKUP = "nwProject.bak"
     PROJ_LOCK   = "nwProject.lock"
     TOC_TXT     = "ToC.txt"
 
@@ -118,8 +118,6 @@ class nwFiles:
     DICT_FILE   = "userdict.json"
     SESS_FILE   = "sessions.jsonl"
 
-# END Class nwFiles
-
 
 class nwKeyWords:
 
@@ -153,8 +151,6 @@ class nwKeyWords:
         CUSTOM_KEY: nwItemClass.CUSTOM,
     }
 
-# END Class nwKeyWords
-
 
 class nwLists:
 
@@ -168,8 +164,6 @@ class nwLists:
         nwItemClass.CUSTOM,
     ]
 
-# END Class nwLists
-
 
 class nwLabels:
 
@@ -184,6 +178,7 @@ class nwLabels:
         nwItemClass.ENTITY:    QT_TRANSLATE_NOOP("Constant", "Entities"),
         nwItemClass.CUSTOM:    QT_TRANSLATE_NOOP("Constant", "Custom"),
         nwItemClass.ARCHIVE:   QT_TRANSLATE_NOOP("Constant", "Archive"),
+        nwItemClass.TEMPLATE:  QT_TRANSLATE_NOOP("Constant", "Templates"),
         nwItemClass.TRASH:     QT_TRANSLATE_NOOP("Constant", "Trash"),
     }
     CLASS_ICON = {
@@ -197,6 +192,7 @@ class nwLabels:
         nwItemClass.ENTITY:    "cls_entity",
         nwItemClass.CUSTOM:    "cls_custom",
         nwItemClass.ARCHIVE:   "cls_archive",
+        nwItemClass.TEMPLATE:  "cls_template",
         nwItemClass.TRASH:     "cls_trash",
     }
     LAYOUT_NAME = {
@@ -266,6 +262,41 @@ class nwLabels:
         nwBuildFmt.J_HTML: ".json",
         nwBuildFmt.J_NWD:  ".json",
     }
+    SHAPES_PLAIN = {
+        nwStatusShape.SQUARE:   QT_TRANSLATE_NOOP("Constant", "Square"),
+        nwStatusShape.TRIANGLE: QT_TRANSLATE_NOOP("Constant", "Triangle"),
+        nwStatusShape.NABLA:    QT_TRANSLATE_NOOP("Constant", "Nabla"),
+        nwStatusShape.DIAMOND:  QT_TRANSLATE_NOOP("Constant", "Diamond"),
+        nwStatusShape.PENTAGON: QT_TRANSLATE_NOOP("Constant", "Pentagon"),
+        nwStatusShape.HEXAGON:  QT_TRANSLATE_NOOP("Constant", "Hexagon"),
+        nwStatusShape.STAR:     QT_TRANSLATE_NOOP("Constant", "Star"),
+        nwStatusShape.PACMAN:   QT_TRANSLATE_NOOP("Constant", "Pacman"),
+    }
+    SHAPES_CIRCLE = {
+        nwStatusShape.CIRCLE_Q: QT_TRANSLATE_NOOP("Constant", "1/4 Circle"),
+        nwStatusShape.CIRCLE_H: QT_TRANSLATE_NOOP("Constant", "Half Circle"),
+        nwStatusShape.CIRCLE_T: QT_TRANSLATE_NOOP("Constant", "3/4 Circle"),
+        nwStatusShape.CIRCLE:   QT_TRANSLATE_NOOP("Constant", "Full Circle"),
+    }
+    SHAPES_BARS = {
+        nwStatusShape.BARS_1: QT_TRANSLATE_NOOP("Constant", "1 Bar"),
+        nwStatusShape.BARS_2: QT_TRANSLATE_NOOP("Constant", "2 Bars"),
+        nwStatusShape.BARS_3: QT_TRANSLATE_NOOP("Constant", "3 Bars"),
+        nwStatusShape.BARS_4: QT_TRANSLATE_NOOP("Constant", "4 Bars"),
+    }
+    SHAPES_BLOCKS = {
+        nwStatusShape.BLOCK_1: QT_TRANSLATE_NOOP("Constant", "1 Block"),
+        nwStatusShape.BLOCK_2: QT_TRANSLATE_NOOP("Constant", "2 Blocks"),
+        nwStatusShape.BLOCK_3: QT_TRANSLATE_NOOP("Constant", "3 Blocks"),
+        nwStatusShape.BLOCK_4: QT_TRANSLATE_NOOP("Constant", "4 Blocks"),
+    }
+    FILE_FILTERS = {
+        "*.txt": QT_TRANSLATE_NOOP("Constant", "Text files"),
+        "*.md":  QT_TRANSLATE_NOOP("Constant", "Markdown files"),
+        "*.nwd": QT_TRANSLATE_NOOP("Constant", "novelWriter files"),
+        "*.csv": QT_TRANSLATE_NOOP("Constant", "CSV files"),
+        "*":     QT_TRANSLATE_NOOP("Constant", "All files"),
+    }
     UNIT_NAME = {
         "mm": QT_TRANSLATE_NOOP("Constant", "Millimetres"),
         "cm": QT_TRANSLATE_NOOP("Constant", "Centimetres"),
@@ -293,23 +324,30 @@ class nwLabels:
         "Custom": (-1.0, -1.0),
     }
 
-# END Class nwLabels
-
 
 class nwHeadFmt:
 
-    BR      = "{BR}"
-    TITLE   = "{Title}"
-    CH_NUM  = "{Chapter}"
-    CH_WORD = "{Chapter:Word}"
-    CH_ROMU = "{Chapter:URoman}"
-    CH_ROML = "{Chapter:LRoman}"
-    SC_NUM  = "{Scene}"
-    SC_ABS  = "{Scene:Abs}"
+    BR         = "{BR}"
+    TITLE      = "{Title}"
+    CH_NUM     = "{Chapter}"
+    CH_WORD    = "{Chapter:Word}"
+    CH_ROMU    = "{Chapter:URoman}"
+    CH_ROML    = "{Chapter:LRoman}"
+    SC_NUM     = "{Scene}"
+    SC_ABS     = "{Scene:Abs}"
+    CHAR_POV   = "{Char:POV}"
+    CHAR_FOCUS = "{Char:Focus}"
 
-    ALL = [TITLE, CH_NUM, CH_WORD, CH_ROMU, CH_ROML, SC_NUM, SC_ABS]
+    PAGE_HEADERS = [
+        TITLE, CH_NUM, CH_WORD, CH_ROMU, CH_ROML, SC_NUM, SC_ABS,
+        CHAR_POV, CHAR_FOCUS
+    ]
 
-# END Class nwHeadFmt
+    # ODT Document Page Header
+    ODT_PROJECT = "{Project}"
+    ODT_AUTHOR = "{Author}"
+    ODT_PAGE = "{Page}"
+    ODT_AUTO = "{Project} / {Author} / {Page}"
 
 
 class nwQuotes:
@@ -341,8 +379,6 @@ class nwQuotes:
         "\u300f": QT_TRANSLATE_NOOP("Constant", "Right white corner bracket"),
     }
 
-# END Class nwQuotes
-
 
 class nwUnicode:
     """Supported unicode character constants and their HTML equivalents."""
@@ -376,7 +412,7 @@ class nwUnicode:
     U_EMDASH = "\u2014"  # Long dash
     U_HBAR   = "\u2015"  # Horizontal bar
     U_HELLIP = "\u2026"  # Ellipsis
-    U_MAPOSS = "\u02bc"  # Modifier letter single apostrophe
+    U_MAPOS  = "\u02bc"  # Modifier letter single apostrophe
     U_PRIME  = "\u2032"  # Prime
     U_DPRIME = "\u2033"  # Double prime
 
@@ -386,6 +422,7 @@ class nwUnicode:
     U_THNBSP = "\u202f"  # Thin non-breaking space
     U_ENSP   = "\u2002"  # Short (en) space
     U_EMSP   = "\u2003"  # Long (em) space
+    U_MMSP   = "\u205f"  # Medium mathematical space
     U_LSEP   = "\u2028"  # Line separator
     U_PSEP   = "\u2029"  # Paragraph separator
 
@@ -442,7 +479,7 @@ class nwUnicode:
     H_EMDASH = "&mdash;"
     H_HBAR   = "&#8213;"
     H_HELLIP = "&hellip;"
-    H_MAPOSS = "&#700;"
+    H_MAPOS  = "&#700;"
     H_PRIME  = "&prime;"
     H_DPRIME = "&#8243;"
 
@@ -476,8 +513,6 @@ class nwUnicode:
     H_LTRI   = "&#9664;"
     H_LTRIS  = "&#9666;"
 
-# END Class nwUnicode
-
 
 class nwHtmlUnicode():
 
@@ -509,7 +544,7 @@ class nwHtmlUnicode():
         nwUnicode.U_EMDASH: nwUnicode.H_EMDASH,
         nwUnicode.U_HBAR:   nwUnicode.H_HBAR,
         nwUnicode.U_HELLIP: nwUnicode.H_HELLIP,
-        nwUnicode.U_MAPOSS: nwUnicode.H_MAPOSS,
+        nwUnicode.U_MAPOS:  nwUnicode.H_MAPOS,
         nwUnicode.U_PRIME:  nwUnicode.H_PRIME,
         nwUnicode.U_DPRIME: nwUnicode.H_DPRIME,
 
@@ -533,5 +568,3 @@ class nwHtmlUnicode():
         nwUnicode.U_TIMES:  nwUnicode.H_TIMES,
         nwUnicode.U_DIVIDE: nwUnicode.H_DIVIDE,
     }
-
-# END Class nwHtmlUnicode
