@@ -25,21 +25,21 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 from __future__ import annotations
 
 import json
-import uuid
 import logging
+import uuid
 
+from collections.abc import Iterable
 from enum import Enum
-from typing import Iterable
 from pathlib import Path
 
 from PyQt5.QtCore import QT_TRANSLATE_NOOP, QCoreApplication
 
 from novelwriter import CONFIG
-from novelwriter.enum import nwBuildFmt
-from novelwriter.error import logException
 from novelwriter.common import checkUuid, isHandle, jsonEncode
 from novelwriter.constants import nwFiles, nwHeadFmt
 from novelwriter.core.project import NWProject
+from novelwriter.enum import nwBuildFmt
+from novelwriter.error import logException
 
 logger = logging.getLogger(__name__)
 
@@ -49,85 +49,114 @@ logger = logging.getLogger(__name__)
 # (type, default, [min value, max value])
 
 SETTINGS_TEMPLATE = {
-    "filter.includeNovel":    (bool, True),
-    "filter.includeNotes":    (bool, False),
-    "filter.includeInactive": (bool, False),
-    "headings.fmtTitle":      (str, nwHeadFmt.TITLE),
-    "headings.fmtChapter":    (str, nwHeadFmt.TITLE),
-    "headings.fmtUnnumbered": (str, nwHeadFmt.TITLE),
-    "headings.fmtScene":      (str, "* * *"),
-    "headings.fmtSection":    (str, ""),
-    "headings.hideScene":     (bool, False),
-    "headings.hideSection":   (bool, True),
-    "text.includeSynopsis":   (bool, False),
-    "text.includeComments":   (bool, False),
-    "text.includeKeywords":   (bool, False),
-    "text.includeBodyText":   (bool, True),
-    "text.addNoteHeadings":   (bool, True),
-    "format.textFont":        (str, CONFIG.textFont),
-    "format.textSize":        (int, 12),
-    "format.lineHeight":      (float, 1.15, 0.75, 3.0),
-    "format.justifyText":     (bool, False),
-    "format.stripUnicode":    (bool, False),
-    "format.replaceTabs":     (bool, False),
-    "format.pageUnit":        (str, "cm"),
-    "format.pageSize":        (str, "A4"),
-    "format.pageWidth":       (float, 21.0),
-    "format.pageHeight":      (float, 29.7),
-    "format.topMargin":       (float, 2.0),
-    "format.bottomMargin":    (float, 2.0),
-    "format.leftMargin":      (float, 2.0),
-    "format.rightMargin":     (float, 2.0),
-    "odt.addColours":         (bool, True),
-    "html.addStyles":         (bool, True),
+    "filter.includeNovel":     (bool, True),
+    "filter.includeNotes":     (bool, False),
+    "filter.includeInactive":  (bool, False),
+    "headings.fmtTitle":       (str, nwHeadFmt.TITLE),
+    "headings.fmtChapter":     (str, nwHeadFmt.TITLE),
+    "headings.fmtUnnumbered":  (str, nwHeadFmt.TITLE),
+    "headings.fmtScene":       (str, "* * *"),
+    "headings.fmtAltScene":    (str, ""),
+    "headings.fmtSection":     (str, ""),
+    "headings.hideTitle":      (bool, False),
+    "headings.hideChapter":    (bool, False),
+    "headings.hideUnnumbered": (bool, False),
+    "headings.hideScene":      (bool, False),
+    "headings.hideAltScene":   (bool, False),
+    "headings.hideSection":    (bool, True),
+    "headings.centerTitle":    (bool, True),
+    "headings.centerChapter":  (bool, False),
+    "headings.centerScene":    (bool, False),
+    "headings.breakTitle":     (bool, True),
+    "headings.breakChapter":   (bool, True),
+    "headings.breakScene":     (bool, False),
+    "text.includeSynopsis":    (bool, False),
+    "text.includeComments":    (bool, False),
+    "text.includeKeywords":    (bool, False),
+    "text.includeBodyText":    (bool, True),
+    "text.ignoredKeywords":    (str, ""),
+    "text.addNoteHeadings":    (bool, True),
+    "format.textFont":         (str, CONFIG.textFont.toString()),
+    "format.lineHeight":       (float, 1.15, 0.75, 3.0),
+    "format.justifyText":      (bool, False),
+    "format.stripUnicode":     (bool, False),
+    "format.replaceTabs":      (bool, False),
+    "format.keepBreaks":       (bool, True),
+    "format.showDialogue":     (bool, False),
+    "format.firstLineIndent":  (bool, False),
+    "format.firstIndentWidth": (float, 1.4),
+    "format.indentFirstPar":   (bool, False),
+    "format.pageUnit":         (str, "cm"),
+    "format.pageSize":         (str, "A4"),
+    "format.pageWidth":        (float, 21.0),
+    "format.pageHeight":       (float, 29.7),
+    "format.topMargin":        (float, 2.0),
+    "format.bottomMargin":     (float, 2.0),
+    "format.leftMargin":       (float, 2.0),
+    "format.rightMargin":      (float, 2.0),
+    "odt.addColours":          (bool, True),
+    "odt.pageHeader":          (str, nwHeadFmt.ODT_AUTO),
+    "odt.pageCountOffset":     (int, 0),
+    "html.addStyles":          (bool, True),
+    "html.preserveTabs":       (bool, False),
 }
 
 SETTINGS_LABELS = {
-    "filter":                 QT_TRANSLATE_NOOP("Builds", "Document Filters"),
-    "filter.includeNovel":    QT_TRANSLATE_NOOP("Builds", "Novel Documents"),
-    "filter.includeNotes":    QT_TRANSLATE_NOOP("Builds", "Project Notes"),
-    "filter.includeInactive": QT_TRANSLATE_NOOP("Builds", "Inactive Documents"),
+    "filter":                  QT_TRANSLATE_NOOP("Builds", "Document Filters"),
+    "filter.includeNovel":     QT_TRANSLATE_NOOP("Builds", "Novel Documents"),
+    "filter.includeNotes":     QT_TRANSLATE_NOOP("Builds", "Project Notes"),
+    "filter.includeInactive":  QT_TRANSLATE_NOOP("Builds", "Inactive Documents"),
 
-    "headings":               QT_TRANSLATE_NOOP("Builds", "Headings"),
-    "headings.fmtTitle":      QT_TRANSLATE_NOOP("Builds", "Title Headings"),
-    "headings.fmtChapter":    QT_TRANSLATE_NOOP("Builds", "Chapter Headings"),
-    "headings.fmtUnnumbered": QT_TRANSLATE_NOOP("Builds", "Unnumbered Headings"),
-    "headings.fmtScene":      QT_TRANSLATE_NOOP("Builds", "Scene Headings"),
-    "headings.fmtSection":    QT_TRANSLATE_NOOP("Builds", "Section Headings"),
-    "headings.hideScene":     QT_TRANSLATE_NOOP("Builds", "Hide Scene Headings"),
-    "headings.hideSection":   QT_TRANSLATE_NOOP("Builds", "Hide Section Headings"),
+    "headings":                QT_TRANSLATE_NOOP("Builds", "Headings"),
+    "headings.fmtTitle":       QT_TRANSLATE_NOOP("Builds", "Partition Format"),
+    "headings.fmtChapter":     QT_TRANSLATE_NOOP("Builds", "Chapter Format"),
+    "headings.fmtUnnumbered":  QT_TRANSLATE_NOOP("Builds", "Unnumbered Format"),
+    "headings.fmtScene":       QT_TRANSLATE_NOOP("Builds", "Scene Format"),
+    "headings.fmtAltScene":    QT_TRANSLATE_NOOP("Builds", "Alt. Scene Format"),
+    "headings.fmtSection":     QT_TRANSLATE_NOOP("Builds", "Section Format"),
 
-    "text.grpContent":        QT_TRANSLATE_NOOP("Builds", "Text Content"),
-    "text.includeSynopsis":   QT_TRANSLATE_NOOP("Builds", "Include Synopsis"),
-    "text.includeComments":   QT_TRANSLATE_NOOP("Builds", "Include Comments"),
-    "text.includeKeywords":   QT_TRANSLATE_NOOP("Builds", "Include Keywords"),
-    "text.includeBodyText":   QT_TRANSLATE_NOOP("Builds", "Include Body Text"),
-    "text.grpInsert":         QT_TRANSLATE_NOOP("Builds", "Insert Content"),
-    "text.addNoteHeadings":   QT_TRANSLATE_NOOP("Builds", "Add Titles for Notes"),
+    "text.grpContent":         QT_TRANSLATE_NOOP("Builds", "Text Content"),
+    "text.includeSynopsis":    QT_TRANSLATE_NOOP("Builds", "Include Synopsis"),
+    "text.includeComments":    QT_TRANSLATE_NOOP("Builds", "Include Comments"),
+    "text.includeKeywords":    QT_TRANSLATE_NOOP("Builds", "Include Keywords"),
+    "text.includeBodyText":    QT_TRANSLATE_NOOP("Builds", "Include Body Text"),
+    "text.ignoredKeywords":    QT_TRANSLATE_NOOP("Builds", "Ignore These Keywords"),
+    "text.grpInsert":          QT_TRANSLATE_NOOP("Builds", "Insert Content"),
+    "text.addNoteHeadings":    QT_TRANSLATE_NOOP("Builds", "Add Titles for Notes"),
 
-    "format.grpFormat":       QT_TRANSLATE_NOOP("Builds", "Text Format"),
-    "format.textFont":        QT_TRANSLATE_NOOP("Builds", "Font Family"),
-    "format.textSize":        QT_TRANSLATE_NOOP("Builds", "Font Size"),
-    "format.lineHeight":      QT_TRANSLATE_NOOP("Builds", "Line Height"),
-    "format.grpOptions":      QT_TRANSLATE_NOOP("Builds", "Text Options"),
-    "format.justifyText":     QT_TRANSLATE_NOOP("Builds", "Justify Text Margins"),
-    "format.stripUnicode":    QT_TRANSLATE_NOOP("Builds", "Replace Unicode Characters"),
-    "format.replaceTabs":     QT_TRANSLATE_NOOP("Builds", "Replace Tabs with Spaces"),
-    "format.grpPage":         QT_TRANSLATE_NOOP("Builds", "Page Layout"),
-    "format.pageUnit":        QT_TRANSLATE_NOOP("Builds", "Unit"),
-    "format.pageSize":        QT_TRANSLATE_NOOP("Builds", "Page Size"),
-    "format.pageWidth":       QT_TRANSLATE_NOOP("Builds", "Page Width"),
-    "format.pageHeight":      QT_TRANSLATE_NOOP("Builds", "Page Height"),
-    "format.topMargin":       QT_TRANSLATE_NOOP("Builds", "Top Margin"),
-    "format.bottomMargin":    QT_TRANSLATE_NOOP("Builds", "Bottom Margin"),
-    "format.leftMargin":      QT_TRANSLATE_NOOP("Builds", "Left Margin"),
-    "format.rightMargin":     QT_TRANSLATE_NOOP("Builds", "Right Margin"),
+    "format.grpFormat":        QT_TRANSLATE_NOOP("Builds", "Text Format"),
+    "format.textFont":         QT_TRANSLATE_NOOP("Builds", "Text Font"),
+    "format.lineHeight":       QT_TRANSLATE_NOOP("Builds", "Line Height"),
+    "format.grpOptions":       QT_TRANSLATE_NOOP("Builds", "Text Options"),
+    "format.justifyText":      QT_TRANSLATE_NOOP("Builds", "Justify Text Margins"),
+    "format.stripUnicode":     QT_TRANSLATE_NOOP("Builds", "Replace Unicode Characters"),
+    "format.replaceTabs":      QT_TRANSLATE_NOOP("Builds", "Replace Tabs with Spaces"),
+    "format.keepBreaks":       QT_TRANSLATE_NOOP("Builds", "Preserve Hard Line Breaks"),
+    "format.showDialogue":     QT_TRANSLATE_NOOP("Builds", "Apply Dialogue Highlighting"),
 
-    "odt":                    QT_TRANSLATE_NOOP("Builds", "Open Document (.odt)"),
-    "odt.addColours":         QT_TRANSLATE_NOOP("Builds", "Add Highlight Colours"),
+    "format.grpParIndent":     QT_TRANSLATE_NOOP("Builds", "First Line Indent"),
+    "format.firstLineIndent":  QT_TRANSLATE_NOOP("Builds", "Enable Indent"),
+    "format.firstIndentWidth": QT_TRANSLATE_NOOP("Builds", "Indent Width"),
+    "format.indentFirstPar":   QT_TRANSLATE_NOOP("Builds", "Indent First Paragraph"),
 
-    "html":                   QT_TRANSLATE_NOOP("Builds", "HTML (.html)"),
-    "html.addStyles":         QT_TRANSLATE_NOOP("Builds", "Add CSS Styles"),
+    "format.grpPage":          QT_TRANSLATE_NOOP("Builds", "Page Layout"),
+    "format.pageUnit":         QT_TRANSLATE_NOOP("Builds", "Unit"),
+    "format.pageSize":         QT_TRANSLATE_NOOP("Builds", "Page Size"),
+    "format.pageWidth":        QT_TRANSLATE_NOOP("Builds", "Page Width"),
+    "format.pageHeight":       QT_TRANSLATE_NOOP("Builds", "Page Height"),
+    "format.topMargin":        QT_TRANSLATE_NOOP("Builds", "Top Margin"),
+    "format.bottomMargin":     QT_TRANSLATE_NOOP("Builds", "Bottom Margin"),
+    "format.leftMargin":       QT_TRANSLATE_NOOP("Builds", "Left Margin"),
+    "format.rightMargin":      QT_TRANSLATE_NOOP("Builds", "Right Margin"),
+
+    "odt":                     QT_TRANSLATE_NOOP("Builds", "Open Document (.odt)"),
+    "odt.addColours":          QT_TRANSLATE_NOOP("Builds", "Add Highlight Colours"),
+    "odt.pageHeader":          QT_TRANSLATE_NOOP("Builds", "Page Header"),
+    "odt.pageCountOffset":     QT_TRANSLATE_NOOP("Builds", "Page Counter Offset"),
+
+    "html":                    QT_TRANSLATE_NOOP("Builds", "HTML (.html)"),
+    "html.addStyles":          QT_TRANSLATE_NOOP("Builds", "Add CSS Styles"),
+    "html.preserveTabs":       QT_TRANSLATE_NOOP("Builds", "Preserve Tab Characters"),
 }
 
 
@@ -141,8 +170,6 @@ class FilterMode(Enum):
     SKIPPED  = 4
     ROOT     = 5
 
-# END Enum FilterMode
-
 
 class BuildSettings:
     """Core: Build Settings Class
@@ -154,7 +181,7 @@ class BuildSettings:
     def __init__(self) -> None:
         self._name = ""
         self._uuid = str(uuid.uuid4())
-        self._path = Path.home()
+        self._path = CONFIG.homePath()
         self._build = ""
         self._order = 0
         self._format = nwBuildFmt.ODT
@@ -192,11 +219,11 @@ class BuildSettings:
         return self._order
 
     @property
-    def lastPath(self) -> Path:
+    def lastBuildPath(self) -> Path:
         """The last used build path."""
         if self._path.is_dir():
             return self._path
-        return Path.home()
+        return CONFIG.homePath()
 
     @property
     def lastBuildName(self) -> str:
@@ -235,16 +262,12 @@ class BuildSettings:
     def getInt(self, key: str) -> int:
         """Type safe value access for integers."""
         value = self._settings.get(key, SETTINGS_TEMPLATE.get(key, (None, None))[1])
-        if isinstance(value, (int, float)):
-            return int(value)
-        return 0
+        return int(value) if isinstance(value, (int, float)) else 0
 
     def getFloat(self, key: str) -> float:
         """Type safe value access for floats."""
         value = self._settings.get(key, SETTINGS_TEMPLATE.get(key, (None, None))[1])
-        if isinstance(value, (int, float)):
-            return float(value)
-        return 0.0
+        return float(value) if isinstance(value, (int, float)) else 0.0
 
     ##
     #  Setters
@@ -270,14 +293,14 @@ class BuildSettings:
             self._order = value
         return
 
-    def setLastPath(self, path: Path | str | None) -> None:
+    def setLastBuildPath(self, path: Path | str | None) -> None:
         """Set the last used build path."""
         if isinstance(path, str):
             path = Path(path)
         if isinstance(path, Path) and path.is_dir():
             self._path = path
         else:
-            self._path = Path.home()
+            self._path = CONFIG.homePath()
         self._changed = True
         return
 
@@ -362,7 +385,7 @@ class BuildSettings:
 
         postponed = []
 
-        def allowRoot(rHandle):
+        def allowRoot(rHandle: str | None) -> None:
             if rHandle in postponed and rHandle in result and rHandle is not None:
                 result[rHandle] = (True, FilterMode.ROOT)
                 postponed.remove(rHandle)
@@ -438,7 +461,7 @@ class BuildSettings:
         self.setName(data.get("name", ""))
         self.setBuildID(data.get("uuid", ""))
         self.setOrder(data.get("order", 0))
-        self.setLastPath(data.get("path", None))
+        self.setLastBuildPath(data.get("path", None))
         self.setLastBuildName(data.get("build", ""))
 
         buildFmt = str(data.get("format", ""))
@@ -461,8 +484,6 @@ class BuildSettings:
 
         return
 
-# END Class BuildSettings
-
 
 class BuildCollection:
     """Core: Build Collection Class
@@ -610,5 +631,3 @@ class BuildCollection:
             return False
 
         return True
-
-# END Class BuildCollection
