@@ -3,7 +3,6 @@ novelWriter – Project Index
 ===========================
 
 File History:
-Created: 2019-04-22 [0.0.1]  countWords
 Created: 2019-05-27 [0.1.4]  NWIndex
 Created: 2022-05-28 [2.0rc1] IndexItem
 Created: 2022-05-28 [2.0rc1] IndexHeading
@@ -30,16 +29,21 @@ from __future__ import annotations
 
 import json
 import logging
+import random
 
-from time import time
-from typing import TYPE_CHECKING, ItemsView, Iterable, Iterator
+from collections.abc import ItemsView, Iterable
 from pathlib import Path
+from time import time
+from typing import TYPE_CHECKING, Literal
 
 from novelwriter import SHARED
-from novelwriter.enum import nwComment, nwItemClass, nwItemType, nwItemLayout
+from novelwriter.common import (
+    checkInt, isHandle, isItemClass, isListInstance, isTitleTag, jsonEncode
+)
+from novelwriter.constants import nwFiles, nwHeaders, nwKeyWords
+from novelwriter.enum import nwComment, nwItemClass, nwItemLayout, nwItemType
 from novelwriter.error import logException
-from novelwriter.common import checkInt, isHandle, isItemClass, isTitleTag, jsonEncode
-from novelwriter.constants import nwFiles, nwKeyWords, nwRegEx, nwUnicode, nwHeaders
+from novelwriter.text.counting import standardCounter
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.core.item import NWItem
@@ -47,7 +51,12 @@ if TYPE_CHECKING:  # pragma: no cover
 
 logger = logging.getLogger(__name__)
 
-TT_NONE = "T0000"
+T_NoteTypes = Literal["footnotes", "comments"]
+
+TT_NONE = "T0000"  # Default title key
+MAX_RETRY = 1000  # Key generator recursion limit
+KEY_SOURCE = "0123456789bcdfghjklmnpqrstvwxz"
+NOTE_TYPES: list[T_NoteTypes] = ["footnotes", "comments"]
 
 
 class NWIndex:
@@ -121,9 +130,8 @@ class NWIndex:
         self.clearIndex()
         for nwItem in self._project.tree:
             if nwItem.isFileType():
-                tHandle = nwItem.itemHandle
-                theDoc = self._project.storage.getDocument(tHandle)
-                self.scanText(tHandle, theDoc.readDocument() or "", blockSignal=True)
+                text = self._project.storage.getDocumentText(nwItem.itemHandle)
+                self.scanText(nwItem.itemHandle, text, blockSignal=True)
         self._indexBroken = False
         SHARED.indexSignalProxy({"event": "buildIndex"})
         return
@@ -141,17 +149,15 @@ class NWIndex:
         })
         return
 
-    def reIndexHandle(self, tHandle: str | None) -> bool:
+    def reIndexHandle(self, tHandle: str | None) -> None:
         """Put a file back into the index. This is used when files are
         moved from the archive or trash folders back into the active
         project.
         """
         if tHandle and self._project.tree.checkType(tHandle, nwItemType.FILE):
             logger.debug("Re-indexing item '%s'", tHandle)
-            theDoc = self._project.storage.getDocument(tHandle)
-            self.scanText(tHandle, theDoc.readDocument() or "")
-            return True
-        return False
+            self.scanText(tHandle, self._project.storage.getDocumentText(tHandle))
+        return
 
     def indexChangedSince(self, checkTime: int | float) -> bool:
         """Check if the index has changed since a given time."""
@@ -265,7 +271,7 @@ class NWIndex:
         self._itemIndex.add(tHandle, tItem)
 
         # Run word counter for the whole text
-        cC, wC, pC = countWords(text)
+        cC, wC, pC = standardCounter(text)
         tItem.setCharCount(cC)
         tItem.setWordCount(wC)
         tItem.setParaCount(pC)
@@ -303,10 +309,10 @@ class NWIndex:
 
     def _scanActive(self, tHandle: str, nwItem: NWItem, text: str, tags: dict[str, bool]) -> None:
         """Scan an active document for meta data."""
-        nTitle = 0           # Line Number of the previous title
-        cTitle = TT_NONE     # Tag of the current title
-        pTitle = TT_NONE     # Tag of the previous title
-        canSetHeader = True  # First header has not yet been set
+        nTitle = 0         # Line Number of the previous title
+        cTitle = TT_NONE   # Tag of the current title
+        pTitle = TT_NONE   # Tag of the previous title
+        canSetHead = True  # First heading has not yet been set
 
         lines = text.splitlines()
         for n, line in enumerate(lines, start=1):
@@ -319,9 +325,9 @@ class NWIndex:
                 if hDepth == "H0":
                     continue
 
-                if canSetHeader:
+                if canSetHead:
                     nwItem.setMainHeading(hDepth)
-                    canSetHeader = False
+                    canSetHead = False
 
                 cTitle = self._itemIndex.addItemHeading(tHandle, n, hDepth, hText)
                 if cTitle != TT_NONE:
@@ -337,10 +343,11 @@ class NWIndex:
                     self._indexKeyword(tHandle, line, cTitle, nwItem.itemClass, tags)
 
             elif line.startswith("%"):
-                if cTitle != TT_NONE:
-                    cStyle, cText, _ = processComment(line)
-                    if cStyle in (nwComment.SYNOPSIS, nwComment.SHORT):
-                        self._itemIndex.setHeadingSynopsis(tHandle, cTitle, cText)
+                cStyle, cKey, cText, _, _ = processComment(line)
+                if cStyle in (nwComment.SYNOPSIS, nwComment.SHORT):
+                    self._itemIndex.setHeadingSynopsis(tHandle, cTitle, cText)
+                elif cStyle == nwComment.FOOTNOTE:
+                    self._itemIndex.addNoteKey(tHandle, "footnotes", cKey)
 
         # Count words for remaining text after last heading
         if pTitle != TT_NONE:
@@ -382,7 +389,7 @@ class NWIndex:
         return
 
     def _splitHeading(self, line: str) -> tuple[str, str]:
-        """Split a heading into its header level and text value."""
+        """Split a heading into its heading level and text value."""
         if line.startswith("# "):
             return "H1", line[2:].strip()
         elif line.startswith("## "):
@@ -395,11 +402,13 @@ class NWIndex:
             return "H1", line[3:].strip()
         elif line.startswith("##! "):
             return "H2", line[4:].strip()
+        elif line.startswith("###! "):
+            return "H3", line[5:].strip()
         return "H0", ""
 
     def _indexWordCounts(self, tHandle: str, text: str, sTitle: str) -> None:
         """Count text stats and save the counts to the index."""
-        cC, wC, pC = countWords(text)
+        cC, wC, pC = standardCounter(text)
         self._itemIndex.setHeadingCounts(tHandle, sTitle, cC, wC, pC)
         return
 
@@ -420,10 +429,10 @@ class NWIndex:
             return
 
         if tBits[0] == nwKeyWords.TAG_KEY:
-            tagName = tBits[1]
-            self._tagsIndex.add(tagName, tHandle, sTitle, itemClass)
-            self._itemIndex.setHeadingTag(tHandle, sTitle, tagName)
-            tags[tagName.lower()] = True
+            tagKey, displayName = self.parseValue(tBits[1])
+            self._tagsIndex.add(tagKey, displayName, tHandle, sTitle, itemClass.name)
+            self._itemIndex.setHeadingTag(tHandle, sTitle, tagKey)
+            tags[tagKey.lower()] = True
         else:
             self._itemIndex.addHeadingRef(tHandle, sTitle, tBits[1:], tBits[0])
 
@@ -471,10 +480,8 @@ class NWIndex:
 
         return True, tBits, tPos
 
-    def checkThese(self, tBits: list[str], nwItem: NWItem) -> list[bool]:
-        """Check the tags against the index to see if they are valid
-        tags. This is needed for syntax highlighting.
-        """
+    def checkThese(self, tBits: list[str], tHandle: str) -> list[bool]:
+        """Check tags against the index to see if they are valid."""
         nBits = len(tBits)
         isGood = [False]*nBits
         if nBits == 0:
@@ -487,20 +494,35 @@ class NWIndex:
 
         # For a tag, only the first value is accepted, the rest are ignored
         if tBits[0] == nwKeyWords.TAG_KEY and nBits > 1:
-            if tBits[1] in self._tagsIndex:
-                isGood[1] = self._tagsIndex.tagHandle(tBits[1]) == nwItem.itemHandle
+            check, _ = self.parseValue(tBits[1])
+            if check in self._tagsIndex:
+                isGood[1] = self._tagsIndex.tagHandle(check) == tHandle
             else:
                 isGood[1] = True
             return isGood
 
         # If we're still here, we check that the references exist
+        # Class references cannot have the | symbol in them
         refKey = nwKeyWords.KEY_CLASS[tBits[0]].name
         for n in range(1, nBits):
-            if tBits[n] in self._tagsIndex:
-                isGood[n] = self._tagsIndex.tagClass(tBits[n]) == refKey
+            if (aBit := tBits[n]) in self._tagsIndex:
+                isGood[n] = self._tagsIndex.tagClass(aBit) == refKey and "|" not in aBit
 
         return isGood
 
+    def parseValue(self, text: str) -> tuple[str, str]:
+        """Parse a single value into a name and display part."""
+        name, _, display = text.partition("|")
+        return name.rstrip(), display.lstrip()
+
+    def newCommentKey(self, tHandle: str, style: nwComment) -> str:
+        """Generate a new key for a comment style."""
+        if style == nwComment.FOOTNOTE:
+            return self._itemIndex.genNewNoteKey(tHandle, "footnotes")
+        elif style == nwComment.COMMENT:
+            return self._itemIndex.genNewNoteKey(tHandle, "comments")
+        return "err"
+
     ##
     #  Extract Data
     ##
@@ -509,36 +531,44 @@ class NWIndex:
         """Get the index data for a given item."""
         return self._itemIndex[tHandle]
 
-    def getItemHeader(self, tHandle: str, sTitle: str) -> IndexHeading | None:
-        """Get the header entry for a specific item and heading."""
-        tItem = self._itemIndex[tHandle]
-        if isinstance(tItem, IndexItem):
+    def getItemHeading(self, tHandle: str, sTitle: str) -> IndexHeading | None:
+        """Get the heading entry for a specific item and heading."""
+        if tItem := self._itemIndex[tHandle]:
             return tItem[sTitle]
         return None
 
+    def iterItemHeadings(self, tHandle: str) -> Iterable[tuple[str, IndexHeading]]:
+        """Get all headings for a specific item."""
+        if tItem := self._itemIndex[tHandle]:
+            yield from tItem.items()
+        return []
+
     def novelStructure(
-        self, rootHandle: str | None = None, skipExcl: bool = True
-    ) -> Iterator[tuple[str, str, str, IndexHeading]]:
+        self, rootHandle: str | None = None, activeOnly: bool = True
+    ) -> Iterable[tuple[str, str, str, IndexHeading]]:
         """Iterate over all titles in the novel, in the correct order as
         they appear in the tree view and in the respective document
         files, but skipping all note files.
         """
-        structure = self._itemIndex.iterNovelStructure(rHandle=rootHandle, skipExcl=skipExcl)
+        structure = self._itemIndex.iterNovelStructure(rHandle=rootHandle, activeOnly=activeOnly)
         for tHandle, sTitle, hItem in structure:
             yield f"{tHandle}:{sTitle}", tHandle, sTitle, hItem
         return
 
-    def getNovelWordCount(self, skipExcl: bool = True) -> int:
-        """Count the number of words in the novel project."""
-        wCount = 0
-        for _, _, hItem in self._itemIndex.iterNovelStructure(skipExcl=skipExcl):
-            wCount += hItem.wordCount
-        return wCount
+    def getNovelWordCount(self, rootHandle: str | None = None, activeOnly: bool = True) -> int:
+        """Count the number of words in one or all novel roots."""
+        return sum(hItem.wordCount for _, _, hItem in self._itemIndex.iterNovelStructure(
+            rHandle=rootHandle, activeOnly=activeOnly
+        ))
 
-    def getNovelTitleCounts(self, skipExcl: bool = True) -> list[int]:
-        """Count the number of titles in the novel project."""
+    def getNovelTitleCounts(
+        self, rootHandle: str | None = None, activeOnly: bool = True
+    ) -> list[int]:
+        """Count the number of titles in one or all novel roots."""
         hCount = [0, 0, 0, 0, 0]
-        for _, _, hItem in self._itemIndex.iterNovelStructure(skipExcl=skipExcl):
+        for _, _, hItem in self._itemIndex.iterNovelStructure(
+            rHandle=rootHandle, activeOnly=activeOnly
+        ):
             iLevel = nwHeaders.H_LEVEL.get(hItem.level, 0)
             hCount[iLevel] += 1
         return hCount
@@ -551,14 +581,14 @@ class NWIndex:
         return 0
 
     def getTableOfContents(
-        self, rHandle: str | None, maxDepth: int, skipExcl: bool = True
+        self, rHandle: str | None, maxDepth: int, activeOnly: bool = True
     ) -> list[tuple[str, int, str, int]]:
         """Generate a table of contents up to a maximum depth."""
         tOrder = []
         tData = {}
         pKey = None
         for tHandle, sTitle, hItem in self._itemIndex.iterNovelStructure(
-            rHandle=rHandle, skipExcl=skipExcl
+            rHandle=rHandle, activeOnly=activeOnly
         ):
             tKey = f"{tHandle}:{sTitle}"
             iLevel = nwHeaders.H_LEVEL.get(hItem.level, 0)
@@ -612,9 +642,18 @@ class NWIndex:
                     for refType in refTypes:
                         if refType in tRefs:
                             tRefs[refType].append(self._tagsIndex.tagName(aTag))
-
         return tRefs
 
+    def getReferenceForHeader(self, tHandle: str, nHead: int, keyClass: str) -> list[str]:
+        """Get the display names for a tags class for insertion into a
+        heading by one of the build classes.
+        """
+        if iItem := self._itemIndex[tHandle]:
+            if hItem := iItem[f"T{nHead:04d}"]:
+                hRefs = [k for k, v in hItem.references.items() if keyClass in v]
+                return [self._tagsIndex.tagDisplay(k) for k in hRefs]
+        return []
+
     def getBackReferenceList(self, tHandle: str) -> dict[str, tuple[str, IndexHeading]]:
         """Build a dict of files referring back to our file."""
         if tHandle is None or tHandle not in self._itemIndex:
@@ -646,12 +685,15 @@ class NWIndex:
         """Return all tags based on itemClass."""
         return self._tagsIndex.filterTagNames(itemClass.name)
 
-    def getTagsData(self) -> Iterator[tuple[str, str, str, IndexItem | None, IndexHeading | None]]:
+    def getTagsData(
+        self, activeOnly: bool = True
+    ) -> Iterable[tuple[str, str, str, IndexItem | None, IndexHeading | None]]:
         """Return all known tags."""
         for tag, data in self._tagsIndex.items():
             iItem = self._itemIndex[data.get("handle")]
             hItem = None if iItem is None else iItem[data.get("heading")]
-            yield tag, data.get("name", ""), data.get("class", ""), iItem, hItem
+            if not activeOnly or (iItem and iItem.item.isActive):
+                yield tag, data.get("name", ""), data.get("class", ""), iItem, hItem
         return
 
     def getSingleTag(self, tagKey: str) -> tuple[str, str, IndexItem | None, IndexHeading | None]:
@@ -665,12 +707,9 @@ class NWIndex:
             return tName, tClass, iItem, None if iItem is None else iItem[tHeading]
         return "", "", None, None
 
-# END Class NWIndex
 
-
-# =============================================================================================== #
-#  The Tags Index Object
-# =============================================================================================== #
+# The Tags Index Object
+# =====================
 
 class TagsIndex:
     """Core: Tags Index Wrapper Class
@@ -709,17 +748,26 @@ class TagsIndex:
         """Return a dictionary view of all tags."""
         return self._tags.items()
 
-    def add(self, tagKey: str, tHandle: str, sTitle: str, itemClass: nwItemClass) -> None:
+    def add(self, tagKey: str, displayName: str, tHandle: str,
+            sTitle: str, className: str) -> None:
         """Add a key to the index and set all values."""
         self._tags[tagKey.lower()] = {
-            "name": tagKey, "handle": tHandle, "heading": sTitle, "class": itemClass.name
+            "name": tagKey,
+            "display": displayName or tagKey,
+            "handle": tHandle,
+            "heading": sTitle,
+            "class": className,
         }
         return
 
     def tagName(self, tagKey: str) -> str:
-        """Get the display name of a given tag."""
+        """Get the name of a given tag."""
         return self._tags.get(tagKey.lower(), {}).get("name", "")
 
+    def tagDisplay(self, tagKey: str) -> str:
+        """Get the display name of a given tag."""
+        return self._tags.get(tagKey.lower(), {}).get("display", "")
+
     def tagHandle(self, tagKey: str) -> str | None:
         """Get the handle of a given tag."""
         return self._tags.get(tagKey.lower(), {}).get("handle", None)
@@ -754,36 +802,36 @@ class TagsIndex:
         if not isinstance(data, dict):
             raise ValueError("tagsIndex is not a dict")
 
-        for tagKey, tagData in data.items():
-            if not isinstance(tagKey, str):
-                raise ValueError("tagsIndex keys must be a strings")
-            if "name" not in tagData:
-                raise KeyError("A tagIndex item is missing a name entry")
-            if "handle" not in tagData:
-                raise KeyError("A tagIndex item is missing a handle entry")
-            if "heading" not in tagData:
-                raise KeyError("A tagIndex item is missing a heading entry")
-            if "class" not in tagData:
-                raise KeyError("A tagIndex item is missing a class entry")
-            if tagData["name"].lower() != tagKey:
-                raise ValueError("tagsIndex name must match key")
-            if not isHandle(tagData["handle"]):
+        for key, entry in data.items():
+            if not isinstance(key, str):
+                raise ValueError("tagsIndex key must be a string")
+            if not isinstance(entry, dict):
+                raise ValueError("tagsIndex entry is not a dict")
+
+            name = entry.get("name")
+            display = entry.get("display")
+            handle = entry.get("handle")
+            heading = entry.get("heading")
+            className = entry.get("class")
+
+            if not isinstance(name, str):
+                raise ValueError("tagsIndex name is not a string")
+            if not isinstance(display, str):
+                raise ValueError("tagsIndex display is not a string")
+            if not isHandle(handle):
                 raise ValueError("tagsIndex handle must be a handle")
-            if not isTitleTag(tagData["heading"]):
+            if not isTitleTag(heading):
                 raise ValueError("tagsIndex heading must be a title tag")
-            if not isItemClass(tagData["class"]):
+            if not isItemClass(className):
                 raise ValueError("tagsIndex handle must be an nwItemClass")
 
-        self._tags = data
+            self.add(name, display, handle, heading, className)
 
         return
 
-# END Class TagsIndex
 
-
-# =============================================================================================== #
-#  The Item Index Objects
-# =============================================================================================== #
+# The Item Index Objects
+# ======================
 
 class ItemIndex:
     """Core: Item Index Wrapper Class
@@ -792,7 +840,7 @@ class ItemIndex:
     class around a single storage dictionary with a set of utility
     functions for setting and accessing the index data. Each indexed
     item is stored in an IndexItem object, which again holds an
-    IndexHeading object for each header of the text.
+    IndexHeading object for each heading of the text.
     """
 
     __slots__ = ("_project", "_items")
@@ -848,7 +896,7 @@ class ItemIndex:
         return
 
     def iterNovelStructure(
-        self, rHandle: str | None = None, skipExcl: bool = False
+        self, rHandle: str | None = None, activeOnly: bool = False
     ) -> Iterable[tuple[str, str, IndexHeading]]:
         """Iterate over all items and headers in the novel structure for
         a given root handle, or for all if root handle is None.
@@ -856,7 +904,7 @@ class ItemIndex:
         for tItem in self._project.tree:
             if tItem.isNoteLayout():
                 continue
-            if skipExcl and not tItem.isActive:
+            if activeOnly and not tItem.isActive:
                 continue
 
             tHandle = tItem.itemHandle
@@ -865,13 +913,11 @@ class ItemIndex:
 
             if rHandle is None:
                 for sTitle in self._items[tHandle].headings():
-                    hItem = self._items[tHandle][sTitle]
-                    if hItem:
+                    if hItem := self._items[tHandle][sTitle]:
                         yield tHandle, sTitle, hItem
             elif tItem.itemRoot == rHandle:
                 for sTitle in self._items[tHandle].headings():
-                    hItem = self._items[tHandle][sTitle]
-                    if hItem:
+                    if hItem := self._items[tHandle][sTitle]:
                         yield tHandle, sTitle, hItem
 
         return
@@ -915,6 +961,25 @@ class ItemIndex:
             self._items[tHandle].addHeadingRef(sTitle, tagKeys, refType)
         return
 
+    def addNoteKey(self, tHandle: str, style: T_NoteTypes, key: str) -> None:
+        """Set notes key for a given item."""
+        if tHandle in self._items:
+            self._items[tHandle].addNoteKey(style, key)
+        return
+
+    def genNewNoteKey(self, tHandle: str, style: T_NoteTypes) -> str:
+        """Set notes key for a given item."""
+        if style in NOTE_TYPES and (item := self._items.get(tHandle)):
+            keys = set()
+            for entry in self._items.values():
+                keys.update(entry.noteKeys(style))
+            for _ in range(MAX_RETRY):
+                key = style[:1] + "".join(random.choices(KEY_SOURCE, k=4))
+                if key not in keys:
+                    item.addNoteKey(style, key)
+                    return key
+        return "err"
+
     ##
     #  Pack/Unpack
     ##
@@ -943,8 +1008,6 @@ class ItemIndex:
 
         return
 
-# END Class ItemIndex
-
 
 class IndexItem:
     """Core: Single Index Item Class
@@ -956,12 +1019,13 @@ class IndexItem:
     must be reset each time the item is re-indexed.
     """
 
-    __slots__ = ("_handle", "_item", "_headings", "_count")
+    __slots__ = ("_handle", "_item", "_headings", "_count", "_notes")
 
     def __init__(self, tHandle: str, nwItem: NWItem) -> None:
         self._handle = tHandle
         self._item = nwItem
         self._headings: dict[str, IndexHeading] = {TT_NONE: IndexHeading(TT_NONE)}
+        self._notes: dict[str, set[str]] = {}
         self._count = 0
         return
 
@@ -1029,6 +1093,13 @@ class IndexItem:
                 self._headings[sTitle].addReference(tagKey, refType)
         return
 
+    def addNoteKey(self, style: T_NoteTypes, key: str) -> None:
+        """Add a note key to the index."""
+        if style not in self._notes:
+            self._notes[style] = set()
+        self._notes[style].add(key)
+        return
+
     ##
     #  Data Methods
     ##
@@ -1050,6 +1121,10 @@ class IndexItem:
         self._count += 1
         return f"T{self._count:04d}"
 
+    def noteKeys(self, style: T_NoteTypes) -> set[str]:
+        """Return a set of all note keys."""
+        return self._notes.get(style, set())
+
     ##
     #  Pack/Unpack
     ##
@@ -1068,6 +1143,8 @@ class IndexItem:
         data["headings"] = heads
         if refs:
             data["references"] = refs
+        if self._notes:
+            data["notes"] = {style: list(keys) for style, keys in self._notes.items()}
 
         return data
 
@@ -1081,9 +1158,15 @@ class IndexItem:
             tHeading.unpackData(hData)
             tHeading.unpackReferences(references.get(sTitle, {}))
             self.addHeading(tHeading)
-        return
 
-# END Class IndexItem
+        for style, keys in data.get("notes", {}).items():
+            if style not in NOTE_TYPES:
+                raise ValueError("The notes style is invalid")
+            if not isListInstance(keys, str):
+                raise ValueError("The notes keys must be a list of strings")
+            self._notes[style] = set(keys)
+
+        return
 
 
 class IndexHeading:
@@ -1159,7 +1242,7 @@ class IndexHeading:
         return self._tag
 
     @property
-    def references(self) -> dict:
+    def references(self) -> dict[str, set[str]]:
         return self._refs
 
     ##
@@ -1167,7 +1250,7 @@ class IndexHeading:
     ##
 
     def setLevel(self, level: str) -> None:
-        """Set the level of the header if it's a valid value."""
+        """Set the level of the heading if it's a valid value."""
         if level in nwHeaders.H_VALID:
             self._level = level
         return
@@ -1260,108 +1343,47 @@ class IndexHeading:
                     raise ValueError("The itemIndex contains an invalid reference type")
         return
 
-# END Class IndexHeading
 
+# Text Processing Functions
+# =========================
 
-# =============================================================================================== #
-#  Text Processing Functions
-# =============================================================================================== #
-
-CLASSIFIERS = {
-    "short": nwComment.SHORT,
+MODIFIERS = {
     "synopsis": nwComment.SYNOPSIS,
+    "short":    nwComment.SHORT,
+    "note":     nwComment.NOTE,
+    "footnote": nwComment.FOOTNOTE,
+}
+KEY_REQ = {
+    "synopsis": 0,  # Key not allowed
+    "short":    0,  # Key not allowed
+    "note":     1,  # Key optional
+    "footnote": 2,  # Key required
 }
 
 
-def processComment(text: str) -> tuple[nwComment, str, int]:
-    """Extract comment style and text. Should only be called on text
-    starting with a %.
+def _checkModKey(modifier: str, key: str) -> bool:
+    """Check if a modifier and key set are ok."""
+    if modifier in MODIFIERS:
+        if key == "":
+            return KEY_REQ[modifier] < 2
+        elif key.replace("_", "").isalnum():
+            return KEY_REQ[modifier] > 0
+    return False
+
+
+def processComment(text: str) -> tuple[nwComment, str, str, int, int]:
+    """Extract comment style, key and text. Should only be called on
+    text starting with a %.
     """
-    check = text[1:].lstrip()
-    classifier, _, content = check.partition(":")
-    if content and (clean := classifier.strip().lower()) in CLASSIFIERS:
-        return CLASSIFIERS[clean], content.strip(), text.find(":") + 1
-    return nwComment.PLAIN, check, 0
+    if text[:2] == "%~":
+        return nwComment.IGNORE, "", text[2:].lstrip(), 0, 0
 
+    check = text[1:].strip()
+    start, _, content = check.partition(":")
+    modifier, _, key = start.rstrip().partition(".")
+    if content and (clean := modifier.lower()) and _checkModKey(clean, key):
+        col = text.find(":") + 1
+        dot = text.find(".", 0, col) + 1
+        return MODIFIERS[clean], key, content.lstrip(), dot, col
 
-def countWords(text: str) -> tuple[int, int, int]:
-    """Count words in a piece of text, skipping special syntax and
-    comments.
-    """
-    charCount = 0
-    wordCount = 0
-    paraCount = 0
-    prevEmpty = True
-
-    if not isinstance(text, str):
-        return charCount, wordCount, paraCount
-
-    # We need to treat dashes as word separators for counting words.
-    # The check+replace approach is much faster than direct replace for
-    # large texts, and a bit slower for small texts, but in the latter
-    # case it doesn't really matter.
-    if nwUnicode.U_ENDASH in text:
-        text = text.replace(nwUnicode.U_ENDASH, " ")
-    if nwUnicode.U_EMDASH in text:
-        text = text.replace(nwUnicode.U_EMDASH, " ")
-
-    # Strip shortcodes
-    if "[" in text:
-        text = nwRegEx.RX_SC.sub("", text)
-
-    for line in text.splitlines():
-
-        countPara = True
-
-        if not line:
-            prevEmpty = True
-            continue
-
-        if line[0] == "@" or line[0] == "%":
-            continue
-
-        if line[0] == "[":
-            check = line.lower()
-            if check.startswith(("[newpage]", "[new page]", "[vspace]")):
-                continue
-            elif check.startswith("[vspace:") and line.endswith("]"):
-                continue
-
-        elif line[0] == "#":
-            if line[:5] == "#### ":
-                line = line[5:]
-                countPara = False
-            elif line[:4] == "### ":
-                line = line[4:]
-                countPara = False
-            elif line[:3] == "## ":
-                line = line[3:]
-                countPara = False
-            elif line[:2] == "# ":
-                line = line[2:]
-                countPara = False
-            elif line[:3] == "#! ":
-                line = line[3:]
-                countPara = False
-            elif line[:4] == "##! ":
-                line = line[4:]
-                countPara = False
-
-        elif line[0] == ">" or line[-1] == "<":
-            if line[:2] == ">>":
-                line = line[2:].lstrip(" ")
-            elif line[:1] == ">":
-                line = line[1:].lstrip(" ")
-            if line[-2:] == "<<":
-                line = line[:-2].rstrip(" ")
-            elif line[-1:] == "<":
-                line = line[:-1].rstrip(" ")
-
-        wordCount += len(line.split())
-        charCount += len(line)
-        if countPara and prevEmpty:
-            paraCount += 1
-
-        prevEmpty = not countPara
-
-    return charCount, wordCount, paraCount
+    return nwComment.PLAIN, "", check, 0, 0
