@@ -25,15 +25,16 @@ from __future__ import annotations
 
 import logging
 
-from typing import TYPE_CHECKING, Any, Literal, overload
+from typing import TYPE_CHECKING, Any
 
 from PyQt5.QtGui import QIcon
 
-from novelwriter.enum import nwItemType, nwItemClass, nwItemLayout
 from novelwriter.common import (
-    checkInt, isHandle, isItemClass, isItemLayout, isItemType, simplified, yesNo
+    checkInt, isHandle, isItemClass, isItemLayout, isItemType, simplified,
+    yesNo
 )
 from novelwriter.constants import nwHeaders, nwLabels, trConst
+from novelwriter.enum import nwItemClass, nwItemLayout, nwItemType
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.core.project import NWProject
@@ -308,25 +309,15 @@ class NWItem:
 
         return trConst(nwLabels.ITEM_DESCRIPTION.get(descKey, ""))
 
-    @overload  # pragma: no cover
-    def getImportStatus(self, incIcon: Literal[True] = True) -> tuple[str, QIcon]:
-        pass
-
-    @overload  # pragma: no cover
-    def getImportStatus(self, incIcon: Literal[False]) -> tuple[str, None]:
-        pass
-
-    def getImportStatus(self, incIcon=True):
+    def getImportStatus(self) -> tuple[str, QIcon]:
         """Return the relevant importance or status label and icon for
         the current item based on its class.
         """
         if self.isNovelLike():
-            stName = self._project.data.itemStatus.name(self._status)
-            stIcon = self._project.data.itemStatus.icon(self._status) if incIcon else None
+            entry = self._project.data.itemStatus[self._status]
         else:
-            stName = self._project.data.itemImport.name(self._import)
-            stIcon = self._project.data.itemImport.icon(self._import) if incIcon else None
-        return stName, stIcon
+            entry = self._project.data.itemImport[self._import]
+        return entry.name, entry.icon
 
     ##
     #  Checker Methods
@@ -334,15 +325,33 @@ class NWItem:
 
     def isNovelLike(self) -> bool:
         """Check if the item is of a novel-like class."""
-        return self._class in (nwItemClass.NOVEL, nwItemClass.ARCHIVE)
+        return self._class in (
+            nwItemClass.NOVEL,
+            nwItemClass.ARCHIVE,
+            nwItemClass.TEMPLATE,
+        )
+
+    def isTemplateFile(self) -> bool:
+        """Check if the item is a template file."""
+        return self._type == nwItemType.FILE and self._class == nwItemClass.TEMPLATE
 
     def documentAllowed(self) -> bool:
         """Check if the item is allowed to be of document layout."""
-        return self._class in (nwItemClass.NOVEL, nwItemClass.ARCHIVE, nwItemClass.TRASH)
+        return self._class in (
+            nwItemClass.NOVEL,
+            nwItemClass.ARCHIVE,
+            nwItemClass.TEMPLATE,
+            nwItemClass.TRASH,
+        )
 
     def isInactiveClass(self) -> bool:
         """Check if the item is in an inactive class."""
-        return self._class in (nwItemClass.NO_CLASS, nwItemClass.ARCHIVE, nwItemClass.TRASH)
+        return self._class in (
+            nwItemClass.NO_CLASS,
+            nwItemClass.ARCHIVE,
+            nwItemClass.TEMPLATE,
+            nwItemClass.TRASH,
+        )
 
     def isRootType(self) -> bool:
         """Check if item is a root item."""
@@ -549,5 +558,3 @@ class NWItem:
         """Save the initial word count."""
         self._initCount = self._wordCount
         return
-
-# END Class NWItem
