@@ -28,12 +28,12 @@ import json
 import logging
 
 from enum import Enum
-from typing import TYPE_CHECKING, Any, TypeVar
 from pathlib import Path
+from typing import TYPE_CHECKING, Any, TypeVar
 
-from novelwriter.error import logException
 from novelwriter.common import checkBool, checkFloat, checkInt, checkString, jsonEncode
 from novelwriter.constants import nwFiles
+from novelwriter.error import logException
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.core.project import NWProject
@@ -42,7 +42,7 @@ logger = logging.getLogger(__name__)
 
 NWEnum = TypeVar("NWEnum", bound=Enum)
 
-VALID_MAP = {
+VALID_MAP: dict[str, set[str]] = {
     "GuiWritingStats": {
         "winWidth", "winHeight", "widthCol0", "widthCol1", "widthCol2",
         "widthCol3", "sortCol", "sortOrder", "incNovel", "incNotes",
@@ -53,10 +53,6 @@ VALID_MAP = {
     "GuiProjectSettings": {
         "winWidth", "winHeight", "replaceColW", "statusColW", "importColW",
     },
-    "GuiProjectDetails": {
-        "winWidth", "winHeight", "widthCol0", "widthCol1", "widthCol2",
-        "widthCol3", "widthCol4", "wordsPerPage", "countFrom", "clearDouble",
-    },
     "GuiWordList": {"winWidth", "winHeight"},
     "GuiNovelView": {"lastCol", "lastColSize"},
     "GuiBuildSettings": {
@@ -70,8 +66,13 @@ VALID_MAP = {
         "winWidth", "winHeight", "fmtWidth", "sumWidth",
     },
     "GuiDocViewerPanel": {
-        "colWidths",
-    }
+        "colWidths", "hideInactive",
+    },
+    "GuiNovelDetails": {
+        "winWidth", "winHeight", "widthCol0", "widthCol1", "widthCol2",
+        "widthCol3", "widthCol4", "wordsPerPage", "countFrom", "clearDouble",
+        "novelRoot",
+    },
 }
 
 
@@ -217,5 +218,3 @@ class OptionState:
                     if value in lookup.__members__:
                         return lookup[value]
         return default
-
-# END Class OptionState
