@@ -26,35 +26,45 @@ from __future__ import annotations
 import json
 import logging
 
-from time import time
-from typing import TYPE_CHECKING, Iterator
-from pathlib import Path
+from collections.abc import Iterable
+from enum import Enum
 from functools import partial
+from pathlib import Path
+from time import time
+from typing import TYPE_CHECKING
 
 from PyQt5.QtCore import QCoreApplication
 
-from novelwriter import CONFIG, SHARED, __version__, __hexversion__
-from novelwriter.enum import nwItemType, nwItemClass, nwItemLayout
-from novelwriter.error import logException
-from novelwriter.constants import trConst, nwLabels
-from novelwriter.core.tree import NWTree
+from novelwriter import CONFIG, SHARED, __hexversion__, __version__
+from novelwriter.common import (
+    checkStringNone, formatInt, formatTimeStamp, getFileSize, hexToInt,
+    makeFileNameSafe, minmax
+)
+from novelwriter.constants import nwLabels, trConst
 from novelwriter.core.index import NWIndex
 from novelwriter.core.options import OptionState
-from novelwriter.core.storage import NWStorage
-from novelwriter.core.sessions import NWSessionLog
-from novelwriter.core.projectxml import ProjectXMLReader, ProjectXMLWriter, XMLReadState
 from novelwriter.core.projectdata import NWProjectData
-from novelwriter.common import (
-    checkStringNone, formatInt, formatTimeStamp, getFileSize, hexToInt, makeFileNameSafe, minmax
-)
+from novelwriter.core.projectxml import ProjectXMLReader, ProjectXMLWriter, XMLReadState
+from novelwriter.core.sessions import NWSessionLog
+from novelwriter.core.storage import NWStorage, NWStorageOpen
+from novelwriter.core.tree import NWTree
+from novelwriter.enum import nwItemClass, nwItemLayout, nwItemType
+from novelwriter.error import logException
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.core.item import NWItem
-    from novelwriter.core.status import NWStatus
 
 logger = logging.getLogger(__name__)
 
 
+class NWProjectState(Enum):
+
+    UNKNOWN  = 0
+    LOCKED   = 1
+    RECOVERY = 2
+    READY    = 3
+
+
 class NWProject:
 
     def __init__(self) -> None:
@@ -69,9 +79,9 @@ class NWProject:
 
         # Project Status
         self._langData = {}     # Localisation data
-        self._lockedBy = None   # Data on which computer has the project open
         self._changed  = False  # The project has unsaved changes
         self._valid    = False  # The project was successfully loaded
+        self._state    = NWProjectState.UNKNOWN
 
         # Internal Mapping
         self.tr = partial(QCoreApplication.translate, "NWProject")
@@ -125,12 +135,15 @@ class NWProject:
         """Return True if a project is loaded."""
         return self._valid
 
+    @property
+    def state(self) -> NWProjectState:
+        """Return the current project state."""
+        return self._state
+
     @property
     def lockStatus(self) -> list | None:
         """Return the project lock information."""
-        if isinstance(self._lockedBy, list) and len(self._lockedBy) == 4:
-            return self._lockedBy
-        return None
+        return self._storage.lockStatus
 
     @property
     def currentEditTime(self) -> int:
@@ -160,25 +173,43 @@ class NWProject:
         """Write content to a new document after it is created. This
         will not run if the file exists and is not empty.
         """
-        tItem = self._tree[tHandle]
-        if tItem is None:
-            return False
-        if not tItem.isFileType():
+        if not ((tItem := self._tree[tHandle]) and tItem.isFileType()):
             return False
 
-        newDoc = self._storage.getDocument(tHandle)
-        if (newDoc.readDocument() or "").strip():
+        if self._storage.getDocumentText(tHandle).strip():
             return False
 
-        hshText = "#"*minmax(hLevel, 1, 4)
-        newText = f"{hshText} {tItem.itemName}\n\n{text}"
+        indent = "#"*minmax(hLevel, 1, 4)
+        text = f"{indent} {tItem.itemName}\n\n{text}"
+
         if tItem.isNovelLike() and isDocument:
             tItem.setLayout(nwItemLayout.DOCUMENT)
         else:
             tItem.setLayout(nwItemLayout.NOTE)
 
-        newDoc.writeDocument(newText)
-        self._index.scanText(tHandle, newText)
+        self._storage.getDocument(tHandle).writeDocument(text)
+        self._index.scanText(tHandle, text)
+
+        return True
+
+    def copyFileContent(self, tHandle: str, sHandle: str) -> bool:
+        """Copy content to a new document after it is created. This
+        will not run if the file exists and is not empty.
+        """
+        if not ((tItem := self._tree[tHandle]) and tItem.isFileType()):
+            return False
+
+        if not ((sItem := self._tree[sHandle]) and sItem.isFileType()):
+            return False
+
+        if self._storage.getDocumentText(tHandle).strip():
+            return False
+
+        logger.debug("Populating '%s' with text from '%s'", tHandle, sHandle)
+        text = self._storage.getDocumentText(sHandle)
+        self._storage.getDocument(tHandle).writeDocument(text)
+        sItem.setLayout(tItem.itemLayout)
+        self._index.scanText(tHandle, text)
 
         return True
 
@@ -219,29 +250,31 @@ class NWProject:
         build the tree of project items.
         """
         logger.info("Opening project: %s", projPath)
-        if not self._storage.openProjectInPlace(projPath):
-            SHARED.error(self.tr("Could not open project with path: {0}").format(projPath))
+
+        status = self._storage.initProjectStorage(projPath, clearLock)
+        if status != NWStorageOpen.READY:
+            if status == NWStorageOpen.UNKOWN:
+                SHARED.error(
+                    self.tr("Not a known project file format."),
+                    info=self.tr("Path: {0}").format(str(projPath))
+                )
+            elif status == NWStorageOpen.NOT_FOUND:
+                SHARED.error(
+                    self.tr("Project file not found."),
+                    info=self.tr("Path: {0}").format(str(projPath))
+                )
+            elif status == NWStorageOpen.FAILED:
+                SHARED.error(
+                    self.tr("Failed to open project."),
+                    info=self.tr("Path: {0}").format(str(projPath)),
+                    exc=self._storage.exc
+                )
+            elif status == NWStorageOpen.LOCKED:
+                self._state = NWProjectState.LOCKED
             return False
 
-        # Project Lock
-        # ============
-
-        if clearLock:
-            self._storage.clearLockFile()
-
-        lockStatus = self._storage.readLockFile()
-        if len(lockStatus) > 0:
-            if lockStatus[0] == "ERROR":
-                logger.warning("Failed to check lock file")
-            else:
-                logger.error("Project is locked, so not opening")
-                self._lockedBy = lockStatus
-                return False
-        else:
-            logger.debug("Project is not locked")
-
-        # Open The Project XML File
-        # =========================
+        # Read Project XML
+        # ================
 
         xmlReader = self._storage.getXmlReader()
         if not isinstance(xmlReader, ProjectXMLReader):
@@ -250,9 +283,7 @@ class NWProject:
         self._data = NWProjectData(self)
         projContent = []
         xmlParsed = xmlReader.read(self._data, projContent)
-
         appVersion = xmlReader.appVersion or self.tr("Unknown")
-
         if not xmlParsed:
             if xmlReader.state == XMLReadState.NOT_NWX_FILE:
                 SHARED.error(self.tr(
@@ -302,8 +333,7 @@ class NWProject:
         self._loadProjectLocalisation()
 
         # Update recent projects
-        storePath = self._storage.storagePath
-        if storePath:
+        if storePath := self._storage.storagePath:
             CONFIG.recentProjects.update(
                 storePath, self._data.name, sum(self._data.initCounts), time()
             )
@@ -323,9 +353,10 @@ class NWProject:
 
         self.updateWordCounts()
         self._session.startSession()
-        self._storage.writeLockFile()
         self.setProjectChanged(False)
         self._valid = True
+        self._state = NWProjectState.READY
+        self._storage.lockSession()  # Lock only after a successful open. See issue #1977.
 
         SHARED.newStatusMessage(self.tr("Opened Project: {0}").format(self._data.name))
 
@@ -370,13 +401,11 @@ class NWProject:
         self._storage.runPostSaveTasks(autoSave=autoSave)
 
         # Update recent projects
-        storePath = self._storage.storagePath
-        if storePath:
+        if storagePath := self._storage.storagePath:
             CONFIG.recentProjects.update(
-                storePath, self._data.name, sum(self._data.currCounts), saveTime
+                storagePath, self._data.name, sum(self._data.currCounts), saveTime
             )
 
-        self._storage.writeLockFile()
         SHARED.newStatusMessage(self.tr("Saved Project: {0}").format(self._data.name))
         self.setProjectChanged(False)
 
@@ -385,6 +414,7 @@ class NWProject:
     def closeProject(self, idleTime: float = 0.0) -> None:
         """Close the project."""
         logger.info("Closing project")
+        self._index.clearIndex()  # Triggers clear signal, see #1718
         self._options.saveSettings()
         self._tree.writeToCFile()
         self._session.appendSession(idleTime)
@@ -420,8 +450,8 @@ class NWProject:
         timeStamp = formatTimeStamp(time(), fileSafe=True)
         archName = baseDir / f"{cleanName} {timeStamp}.zip"
         if self._storage.zipIt(archName, compression=2):
-            size = formatInt(getFileSize(archName))
             if doNotify:
+                size = formatInt(getFileSize(archName))
                 SHARED.info(
                     self.tr("Created a backup of your project of size {0}B.").format(size),
                     info=self.tr("Path: {0}").format(str(backupPath))
@@ -440,14 +470,14 @@ class NWProject:
 
     def setDefaultStatusImport(self) -> None:
         """Set the default status and importance values."""
-        self._data.itemStatus.write(None, self.tr("New"),      (100, 100, 100))
-        self._data.itemStatus.write(None, self.tr("Note"),     (200, 50,  0))
-        self._data.itemStatus.write(None, self.tr("Draft"),    (200, 150, 0))
-        self._data.itemStatus.write(None, self.tr("Finished"), (50,  200, 0))
-        self._data.itemImport.write(None, self.tr("New"),      (100, 100, 100))
-        self._data.itemImport.write(None, self.tr("Minor"),    (200, 50,  0))
-        self._data.itemImport.write(None, self.tr("Major"),    (200, 150, 0))
-        self._data.itemImport.write(None, self.tr("Main"),     (50,  200, 0))
+        self._data.itemStatus.add(None, self.tr("New"),      (100, 100, 100), "SQUARE", 0)
+        self._data.itemStatus.add(None, self.tr("Note"),     (200, 50,  0),   "SQUARE", 0)
+        self._data.itemStatus.add(None, self.tr("Draft"),    (200, 150, 0),   "SQUARE", 0)
+        self._data.itemStatus.add(None, self.tr("Finished"), (50,  200, 0),   "SQUARE", 0)
+        self._data.itemImport.add(None, self.tr("New"),      (100, 100, 100), "SQUARE", 0)
+        self._data.itemImport.add(None, self.tr("Minor"),    (200, 50,  0),   "SQUARE", 0)
+        self._data.itemImport.add(None, self.tr("Major"),    (200, 150, 0),   "SQUARE", 0)
+        self._data.itemImport.add(None, self.tr("Main"),     (50,  200, 0),   "SQUARE", 0)
         return
 
     def setProjectLang(self, language: str | None) -> None:
@@ -470,14 +500,6 @@ class NWProject:
         self.setProjectChanged(True)
         return
 
-    def setStatusColours(self, new: list[dict], deleted: list[str]) -> bool:
-        """Update the list of novel file status flags."""
-        return self._setStatusImport(new, deleted, self._data.itemStatus)
-
-    def setImportColours(self, new: list[dict], deleted: list[str]) -> bool:
-        """Update the list of note file importance flags."""
-        return self._setStatusImport(new, deleted, self._data.itemImport)
-
     def setProjectChanged(self, status: bool) -> bool:
         """Toggle the project changed flag, and propagate the
         information to the GUI statusbar.
@@ -491,7 +513,7 @@ class NWProject:
     #  Class Methods
     ##
 
-    def iterProjectItems(self) -> Iterator[NWItem]:
+    def iterProjectItems(self) -> Iterable[NWItem]:
         """This function ensures that the item tree loaded is sent to
         the GUI tree view in such a way that the tree can be built. That
         is, the parent item must be sent before its child. In principle,
@@ -563,28 +585,6 @@ class NWProject:
     #  Internal Functions
     ##
 
-    def _setStatusImport(self, new: list[dict], delete: list[str], target: NWStatus) -> bool:
-        """Update the list of novel file status or importance flags, and
-        delete those that have been requested deleted.
-        """
-        if not (new or delete):
-            return False
-
-        order = []
-        for entry in new:
-            key = entry.get("key", None)
-            name = entry.get("name", "")
-            cols = entry.get("cols", (100, 100, 100))
-            if name:
-                order.append(target.write(key, name, cols))
-
-        for key in delete:
-            target.remove(key)
-
-        target.reorder(order)
-
-        return True
-
     def _loadProjectLocalisation(self) -> bool:
         """Load the language data for the current project language."""
         if self._data.language is None or CONFIG._nwLangPath is None:
@@ -605,5 +605,3 @@ class NWProject:
             return False
 
         return True
-
-# END Class NWProject
