@@ -23,8 +23,8 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-import uuid
 import logging
+import uuid
 
 from typing import TYPE_CHECKING, Any
 
@@ -53,7 +53,6 @@ class NWProjectData:
         # Project Meta
         self._uuid = ""
         self._name = ""
-        self._title = ""
         self._author = ""
         self._saveCount = 0
         self._autoCount = 0
@@ -102,11 +101,6 @@ class NWProjectData:
         """Return the project name."""
         return self._name
 
-    @property
-    def title(self) -> str:
-        """Return the project title."""
-        return self._title
-
     @property
     def author(self) -> str:
         """Return the project author."""
@@ -228,16 +222,9 @@ class NWProjectData:
             self._project.setProjectChanged(True)
         return
 
-    def setTitle(self, value: str | None) -> None:
-        """Set a new novel title."""
-        if value != self._title:
-            self._title = simplified(str(value or ""))
-            self._project.setProjectChanged(True)
-        return
-
     def setAuthor(self, value: str | None) -> None:
         """Set the author value."""
-        if value != self._title:
+        if value != self._author:
             self._author = simplified(str(value or ""))
             self._project.setProjectChanged(True)
         return
@@ -335,5 +322,3 @@ class NWProjectData:
                     self._autoReplace[key] = simplified(entry)
             self._project.setProjectChanged(True)
         return
-
-# END Class NWProjectData
