@@ -29,25 +29,24 @@ import logging
 import xml.etree.ElementTree as ET
 
 from enum import Enum
+from pathlib import Path
 from time import time
 from typing import TYPE_CHECKING
-from pathlib import Path
 
-from novelwriter import __version__, __hexversion__
+from novelwriter import __hexversion__, __version__
 from novelwriter.common import (
     checkBool, checkInt, checkString, checkStringNone, formatTimeStamp,
     hexToInt, simplified, xmlIndent, yesNo
 )
-from novelwriter.constants import nwFiles
 
 if TYPE_CHECKING:  # pragma: no cover
-    from novelwriter.core.status import NWStatus
     from novelwriter.core.projectdata import NWProjectData
+    from novelwriter.core.status import NWStatus
 
 logger = logging.getLogger(__name__)
 
 FILE_VERSION = "1.5"  # The current project file format version
-FILE_REVISION = "1"   # The current project file format revision
+FILE_REVISION = "4"   # The current project file format revision
 HEX_VERSION = 0x0105
 
 NUM_VERSION = {
@@ -65,14 +64,11 @@ class XMLReadState(Enum):
 
     NO_ACTION       = 0
     NO_ERROR        = 1
-    PARSED_BACKUP   = 2
-    CANNOT_PARSE    = 3
-    NOT_NWX_FILE    = 4
-    UNKNOWN_VERSION = 5
-    PARSED_OK       = 6
-    WAS_LEGACY      = 7
-
-# END Class XMLReadState
+    CANNOT_PARSE    = 2
+    NOT_NWX_FILE    = 3
+    UNKNOWN_VERSION = 4
+    PARSED_OK       = 5
+    WAS_LEGACY      = 6
 
 
 class ProjectXMLReader:
@@ -107,7 +103,12 @@ class ProjectXMLReader:
         the project or the content into their respective section nodes
         as attributes. The id attribute was also added to the project.
 
-        Rev 1: Drops the titleFormat section of settings.
+        Rev 1: Drops the titleFormat node from settings. 2.1 Beta 1.
+        Rev 2: Drops the title node from project and adds the TEMPLATE
+               class for items. 2.3 Beta 1.
+        Rev 3: Added TEMPLATE class. 2.3.
+        Rev 4: Added shape attribute to status and importance entry
+               nodes. 2.5.
     """
 
     def __init__(self, path: str | Path) -> None:
@@ -172,23 +173,9 @@ class ProjectXMLReader:
             xml = ET.parse(str(self._path))
             self._state = XMLReadState.NO_ERROR
         except Exception as exc:
-            # Trying to open backup file instead
             logger.error("Failed to parse project XML", exc_info=exc)
             self._state = XMLReadState.CANNOT_PARSE
-
-            backFile = self._path.with_suffix(".bak")
-            if backFile.is_file():
-                try:
-                    xml = ET.parse(str(backFile))
-                    self._state = XMLReadState.PARSED_BACKUP
-                    logger.info("Backup project file parsed")
-                except Exception as exc:
-                    logger.error("Failed to parse backup project XML", exc_info=exc)
-                    self._state = XMLReadState.CANNOT_PARSE
-                    return False
-            else:
-                self._state = XMLReadState.CANNOT_PARSE
-                return False
+            return False
 
         xRoot = xml.getroot()
         self._root = str(xRoot.tag)
@@ -248,8 +235,6 @@ class ProjectXMLReader:
         for xItem in xSection:
             if xItem.tag == "name":
                 data.setName(xItem.text)
-            elif xItem.tag == "title":
-                data.setTitle(xItem.text)
             elif xItem.tag == "author":
                 data.setAuthor(xItem.text)
             else:
@@ -371,8 +356,8 @@ class ProjectXMLReader:
         logger.debug("Parsing <content> section (legacy format)")
 
         # Create maps to look up name -> key for status and importance
-        statusMap = {entry.get("name"): key for key, entry in data.itemStatus.items()}
-        importMap = {entry.get("name"): key for key, entry in data.itemImport.items()}
+        sMap: dict[str | None, str] = {e.name: k for k, e in data.itemStatus.iterItems()}
+        iMap: dict[str | None, str] = {e.name: k for k, e in data.itemImport.iterItems()}
 
         for xItem in xSection:
             if xItem.tag != "item":
@@ -419,9 +404,9 @@ class ProjectXMLReader:
 
             # Status was split into separate status/import with a key in 1.4
             if item.get("class", "") in ("NOVEL", "ARCHIVE"):
-                name["status"] = statusMap.get(tmpStatus, None)
+                name["status"] = sMap.get(tmpStatus, None)
             else:
-                name["import"] = importMap.get(tmpStatus, None)
+                name["import"] = iMap.get(tmpStatus, None)
 
             # A number of layouts were removed in 1.3
             if item.get("layout", "") in (
@@ -451,7 +436,8 @@ class ProjectXMLReader:
                 green = checkInt(xEntry.attrib.get("green", 0), 0)
                 blue  = checkInt(xEntry.attrib.get("blue", 0), 0)
                 count = checkInt(xEntry.attrib.get("count", 0), 0)
-                sObject.write(key, xEntry.text or "", (red, green, blue), count)
+                shape = xEntry.attrib.get("shape", "")
+                sObject.add(key, xEntry.text or "", (red, green, blue), shape, count)
         return
 
     def _parseDictKeyText(self, xItem: ET.Element) -> dict:
@@ -464,14 +450,12 @@ class ProjectXMLReader:
                 result[xEntry.attrib["key"]] = checkString(xEntry.text, "")
         return result
 
-    def _parseDictTagText(self, xItem) -> dict:
+    def _parseDictTagText(self, xItem: ET.Element) -> dict:
         """Parse a dictionary stored with key as the tag and the value
         as the text property.
         """
         return {xNode.tag: checkString(xNode.text, "") for xNode in xItem}
 
-# END Class ProjectXMLReader
-
 
 class ProjectXMLWriter:
     """Core: Project XML Writer
@@ -521,7 +505,6 @@ class ProjectXMLWriter:
 
         xProject = ET.SubElement(xRoot, "project", attrib=projAttr)
         self._packSingleValue(xProject, "name", data.name)
-        self._packSingleValue(xProject, "title", data.title)
         self._packSingleValue(xProject, "author", data.author)
 
         # Save Project Settings
@@ -558,23 +541,12 @@ class ProjectXMLWriter:
             xName.text = item["name"]
 
         # Write the XML tree to file
-        saveFile = self._path / nwFiles.PROJ_FILE
-        tempFile = saveFile.with_suffix(".tmp")
-        backFile = saveFile.with_suffix(".bak")
+        tmp = self._path.with_suffix(".tmp")
         try:
             xml = ET.ElementTree(xRoot)
             xmlIndent(xml)
-            xml.write(tempFile, encoding="utf-8", xml_declaration=True)
-        except Exception as exc:
-            self._error = exc
-            return False
-
-        # If we're here, the file was successfully saved,
-        # so let's sort out the temps and backups
-        try:
-            if saveFile.exists():
-                saveFile.replace(backFile)
-            tempFile.replace(saveFile)
+            xml.write(tmp, encoding="utf-8", xml_declaration=True)
+            tmp.replace(self._path)
         except Exception as exc:
             self._error = exc
             return False
@@ -603,5 +575,3 @@ class ProjectXMLWriter:
                 xEntry = ET.SubElement(xItem, "entry", attrib={"key": key})
                 xEntry.text = str(value) or ""
         return
-
-# END Class ProjectXMLWriter
