@@ -27,13 +27,14 @@ from __future__ import annotations
 import json
 import logging
 
-from typing import TYPE_CHECKING, Iterator
+from collections.abc import Iterator
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 from PyQt5.QtCore import QLocale
 
-from novelwriter.error import logException
 from novelwriter.constants import nwFiles
+from novelwriter.error import logException
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.core.project import NWProject
@@ -73,7 +74,7 @@ class NWSpellEnchant:
     #  Setters
     ##
 
-    def setLanguage(self, language: str | None):
+    def setLanguage(self, language: str | None) -> None:
         """Load a dictionary for the language specified in the config.
         If that fails, we load a mock dictionary so that lookups don't
         crash. Note that enchant will allow loading an empty string as
@@ -163,11 +164,10 @@ class NWSpellEnchant:
             name = ""
         return tag, name
 
-# END Class NWSpellEnchant
-
 
 class FakeEnchant:
     """Fallback for when Enchant is selected, but not installed."""
+
     def __init__(self) -> None:
 
         class FakeProvider:
@@ -181,14 +181,12 @@ class FakeEnchant:
     def check(self, word: str) -> bool:
         return True
 
-    def suggest(self, word) -> list[str]:
+    def suggest(self, word: str) -> list[str]:
         return []
 
-    def add_to_session(self, word: str):
+    def add_to_session(self, word: str) -> None:
         return
 
-# END Class FakeEnchant
-
 
 class UserDictionary:
 
@@ -239,5 +237,3 @@ class UserDictionary:
                 logger.error("Failed to save user dictionary")
                 logException()
         return
-
-# END Class UserDictionary
