@@ -23,17 +23,18 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-import random
 import logging
+import random
 
-from typing import TYPE_CHECKING, Iterator, Literal, overload
+from collections.abc import Iterable, Iterator
 from pathlib import Path
+from typing import TYPE_CHECKING, Literal, overload
 
-from novelwriter.enum import nwItemClass, nwItemLayout, nwItemType
-from novelwriter.error import logException
 from novelwriter.common import isHandle
 from novelwriter.constants import nwFiles
 from novelwriter.core.item import NWItem
+from novelwriter.enum import nwItemClass, nwItemLayout, nwItemType
+from novelwriter.error import logException
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.core.project import NWProject
@@ -350,16 +351,16 @@ class NWTree:
             return False
         return tItem.itemType == itemType
 
-    def getItemPath(self, tHandle: str) -> list[str]:
+    def getItemPath(self, tHandle: str, asName: bool = False) -> list[str]:
         """Iterate upwards in the tree until we find the item with
-        parent None, the root item, and return the list of handles.
-        We do this with a for loop with a maximum depth to make
-        infinite loops impossible.
+        parent None, the root item, and return the list of handles, or
+        alternatively item names. We do this with a for loop with a
+        maximum depth to make infinite loops impossible.
         """
         tTree = []
         tItem = self.__getitem__(tHandle)
         if tItem is not None:
-            tTree.append(tHandle)
+            tTree.append(tItem.itemName if asName else tHandle)
             for _ in range(MAX_DEPTH):
                 if tItem.itemParent is None:
                     return tTree
@@ -369,7 +370,7 @@ class NWTree:
                     if tItem is None:
                         return tTree
                     else:
-                        tTree.append(tHandle)
+                        tTree.append(tItem.itemName if asName else tHandle)
             else:
                 raise RecursionError("Critical internal error")
 
@@ -386,7 +387,7 @@ class NWTree:
             rootClasses.add(nwItem.itemClass)
         return rootClasses
 
-    def iterRoots(self, itemClass: nwItemClass | None) -> Iterator[tuple[str, NWItem]]:
+    def iterRoots(self, itemClass: nwItemClass | None) -> Iterable[tuple[str, NWItem]]:
         """Iterate over all root items of a given class in order."""
         for tHandle in self._order:
             nwItem = self.__getitem__(tHandle)
@@ -500,7 +501,7 @@ class NWTree:
     ##
 
     def _setTreeChanged(self, state: bool) -> None:
-        """Set the changed flag to theState, and if being set to True,
+        """Set the changed flag to state, and if being set to True,
         propagate that state change to the parent NWProject class.
         """
         self._changed = state
@@ -519,5 +520,3 @@ class NWTree:
             handle = self._makeHandle()
 
         return handle
-
-# END Class NWTree
