@@ -26,23 +26,24 @@ from __future__ import annotations
 
 import logging
 
-from PyQt5.QtGui import QCloseEvent
-from PyQt5.QtCore import Qt, QSize, pyqtSlot
+from PyQt5.QtCore import Qt, pyqtSlot
 from PyQt5.QtWidgets import (
-    QAbstractItemView, QDialog, QDialogButtonBox, QGridLayout, QLabel,
-    QListWidget, QListWidgetItem, QVBoxLayout, QWidget
+    QAbstractItemView, QDialogButtonBox, QGridLayout, QLabel, QListWidget,
+    QListWidgetItem, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG, SHARED
+from novelwriter.extensions.configlayout import NColourLabel
+from novelwriter.extensions.modified import NDialog
 from novelwriter.extensions.switch import NSwitch
-from novelwriter.extensions.configlayout import NHelpLabel
+from novelwriter.types import QtAccepted, QtDialogCancel, QtDialogOk, QtDialogReset, QtUserRole
 
 logger = logging.getLogger(__name__)
 
 
-class GuiDocMerge(QDialog):
+class GuiDocMerge(NDialog):
 
-    D_HANDLE = Qt.ItemDataRole.UserRole
+    D_HANDLE = QtUserRole
 
     def __init__(self, parent: QWidget, sHandle: str, itemList: list[str]) -> None:
         super().__init__(parent=parent)
@@ -53,27 +54,30 @@ class GuiDocMerge(QDialog):
 
         self._data = {}
 
-        self.headLabel = QLabel("<b>{0}</b>".format(self.tr("Documents to Merge")))
-        self.helpLabel = NHelpLabel(self.tr(
-            "Drag and drop items to change the order, or uncheck to exclude."
-        ), SHARED.theme.helpText)
+        self.headLabel = QLabel(self.tr("Documents to Merge"), self)
+        self.headLabel.setFont(SHARED.theme.guiFontB)
+        self.helpLabel = NColourLabel(
+            self.tr("Drag and drop items to change the order, or uncheck to exclude."),
+            self, color=SHARED.theme.helpText, wrap=True
+        )
 
-        iPx = SHARED.theme.baseIconSize
+        iPx = SHARED.theme.baseIconHeight
+        iSz = SHARED.theme.baseIconSize
         hSp = CONFIG.pxInt(12)
         vSp = CONFIG.pxInt(8)
         bSp = CONFIG.pxInt(12)
 
-        self.listBox = QListWidget()
-        self.listBox.setIconSize(QSize(iPx, iPx))
+        self.listBox = QListWidget(self)
+        self.listBox.setIconSize(iSz)
         self.listBox.setMinimumWidth(CONFIG.pxInt(400))
         self.listBox.setMinimumHeight(CONFIG.pxInt(180))
-        self.listBox.setSelectionBehavior(QAbstractItemView.SelectRows)
-        self.listBox.setSelectionMode(QAbstractItemView.SingleSelection)
-        self.listBox.setDragDropMode(QAbstractItemView.InternalMove)
+        self.listBox.setSelectionBehavior(QAbstractItemView.SelectionBehavior.SelectRows)
+        self.listBox.setSelectionMode(QAbstractItemView.SelectionMode.SingleSelection)
+        self.listBox.setDragDropMode(QAbstractItemView.DragDropMode.InternalMove)
 
         # Merge Options
-        self.trashLabel = QLabel(self.tr("Move merged items to Trash"))
-        self.trashSwitch = NSwitch(width=2*iPx, height=iPx)
+        self.trashLabel = QLabel(self.tr("Move merged items to Trash"), self)
+        self.trashSwitch = NSwitch(self, height=iPx)
 
         self.optBox = QGridLayout()
         self.optBox.addWidget(self.trashLabel,  0, 0)
@@ -82,11 +86,11 @@ class GuiDocMerge(QDialog):
         self.optBox.setColumnStretch(2, 1)
 
         # Buttons
-        self.buttonBox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
+        self.buttonBox = QDialogButtonBox(QtDialogOk | QtDialogCancel, self)
         self.buttonBox.accepted.connect(self.accept)
         self.buttonBox.rejected.connect(self.reject)
 
-        self.resetButton = self.buttonBox.addButton(QDialogButtonBox.Reset)
+        self.resetButton = self.buttonBox.addButton(QtDialogReset)
         self.resetButton.clicked.connect(self._resetList)
 
         # Assemble
@@ -113,12 +117,12 @@ class GuiDocMerge(QDialog):
         logger.debug("Delete: GuiDocMerge")
         return
 
-    def getData(self) -> dict:
+    def data(self) -> dict:
         """Return the user's choices."""
         finalItems = []
         for i in range(self.listBox.count()):
             item = self.listBox.item(i)
-            if item is not None and item.checkState() == Qt.Checked:
+            if item is not None and item.checkState() == Qt.CheckState.Checked:
                 finalItems.append(item.data(self.D_HANDLE))
 
         self._data["moveToTrash"] = self.trashSwitch.isChecked()
@@ -126,15 +130,15 @@ class GuiDocMerge(QDialog):
 
         return self._data
 
-    ##
-    #  Events
-    ##
-
-    def closeEvent(self, event: QCloseEvent) -> None:
-        """Capture the close event and perform cleanup."""
-        event.accept()
-        self.deleteLater()
-        return
+    @classmethod
+    def getData(cls, parent: QWidget, handle: str, items: list[str]) -> tuple[dict, bool]:
+        """Pop the dialog and return the result."""
+        cls = GuiDocMerge(parent, handle, items)
+        cls.exec()
+        data = cls.data()
+        accepted = cls.result() == QtAccepted
+        cls.softDelete()
+        return data, accepted
 
     ##
     #  Private Slots
@@ -173,10 +177,8 @@ class GuiDocMerge(QDialog):
             newItem.setIcon(itemIcon)
             newItem.setText(nwItem.itemName)
             newItem.setData(self.D_HANDLE, tHandle)
-            newItem.setCheckState(Qt.Checked)
+            newItem.setCheckState(Qt.CheckState.Checked)
 
             self.listBox.addItem(newItem)
 
         return
-
-# END Class GuiDocMerge
