@@ -25,17 +25,16 @@ from __future__ import annotations
 
 import logging
 
-from PyQt5.QtWidgets import (
-    QDialog, QDialogButtonBox, QHBoxLayout, QLabel, QLineEdit, QVBoxLayout,
-    QWidget
-)
+from PyQt5.QtWidgets import QDialogButtonBox, QHBoxLayout, QLabel, QLineEdit, QVBoxLayout, QWidget
 
 from novelwriter import CONFIG
+from novelwriter.extensions.modified import NDialog
+from novelwriter.types import QtAccepted, QtDialogCancel, QtDialogOk
 
 logger = logging.getLogger(__name__)
 
 
-class GuiEditLabel(QDialog):
+class GuiEditLabel(NDialog):
 
     def __init__(self, parent: QWidget, text: str = "") -> None:
         super().__init__(parent=parent)
@@ -48,20 +47,20 @@ class GuiEditLabel(QDialog):
         mSp = CONFIG.pxInt(12)
 
         # Item Label
-        self.labelValue = QLineEdit()
+        self.labelValue = QLineEdit(self)
         self.labelValue.setMinimumWidth(mVd)
         self.labelValue.setMaxLength(200)
         self.labelValue.setText(text)
         self.labelValue.selectAll()
 
         # Buttons
-        self.buttonBox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
+        self.buttonBox = QDialogButtonBox(QtDialogOk | QtDialogCancel, self)
         self.buttonBox.accepted.connect(self.accept)
         self.buttonBox.rejected.connect(self.reject)
 
         # Assemble
         self.innerBox = QHBoxLayout()
-        self.innerBox.addWidget(QLabel(self.tr("Label")), 0)
+        self.innerBox.addWidget(QLabel(self.tr("Label"), self), 0)
         self.innerBox.addWidget(self.labelValue, 1)
         self.innerBox.setSpacing(mSp)
 
@@ -88,10 +87,8 @@ class GuiEditLabel(QDialog):
     def getLabel(cls, parent: QWidget, text: str) -> tuple[str, bool]:
         """Pop the dialog and return the result."""
         cls = GuiEditLabel(parent, text=text)
-        cls.exec_()
+        cls.exec()
         label = cls.itemLabel
-        accepted = cls.result() == QDialog.Accepted
-        cls.deleteLater()
+        accepted = cls.result() == QtAccepted
+        cls.softDelete()
         return label, accepted
-
-# END Class GuiEditLabel
