@@ -25,36 +25,42 @@ from __future__ import annotations
 
 import logging
 
-from PyQt5.QtGui import QCloseEvent, QFontMetrics
-from PyQt5.QtCore import QSize, Qt, pyqtSlot
+from PyQt5.QtCore import QSize, pyqtSlot
+from PyQt5.QtGui import QFontMetrics
 from PyQt5.QtWidgets import (
-    QDialog, QDialogButtonBox, QFrame, QHBoxLayout, QLabel, QListWidget,
+    QDialogButtonBox, QFrame, QHBoxLayout, QLabel, QListWidget,
     QListWidgetItem, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG
-from novelwriter.constants import trConst, nwQuotes
+from novelwriter.constants import nwQuotes, trConst
+from novelwriter.extensions.modified import NDialog
+from novelwriter.types import (
+    QtAccepted, QtAlignCenter, QtAlignTop, QtDialogCancel, QtDialogOk,
+    QtUserRole
+)
 
 logger = logging.getLogger(__name__)
 
 
-class GuiQuoteSelect(QDialog):
+class GuiQuoteSelect(NDialog):
 
-    selectedQuote = ""
+    _selected = ""
 
-    D_KEY = Qt.ItemDataRole.UserRole
+    D_KEY = QtUserRole
 
-    def __init__(self, parent: QWidget, currentQuote: str = '"') -> None:
+    def __init__(self, parent: QWidget, current: str = '"') -> None:
         super().__init__(parent=parent)
 
         logger.debug("Create: GuiQuoteSelect")
         self.setObjectName("GuiQuoteSelect")
+        self.setWindowTitle(self.tr("Select Quote Style"))
 
         self.outerBox = QVBoxLayout()
         self.innerBox = QHBoxLayout()
         self.labelBox = QVBoxLayout()
 
-        self.selectedQuote = currentQuote
+        self._selected = current
 
         qMetrics = QFontMetrics(self.font())
         pxW = 7*qMetrics.boundingRectChar("M").width()
@@ -65,36 +71,36 @@ class GuiQuoteSelect(QDialog):
         lblFont.setPointSizeF(4*lblFont.pointSizeF())
 
         # Preview Label
-        self.previewLabel = QLabel(currentQuote)
+        self.previewLabel = QLabel(current, self)
         self.previewLabel.setFont(lblFont)
         self.previewLabel.setFixedSize(QSize(pxW, pxH))
-        self.previewLabel.setAlignment(Qt.AlignCenter)
-        self.previewLabel.setFrameStyle(QFrame.Box | QFrame.Plain)
+        self.previewLabel.setAlignment(QtAlignCenter)
+        self.previewLabel.setFrameStyle(QFrame.Shape.Box | QFrame.Shadow.Plain)
 
         # Quote Symbols
-        self.listBox = QListWidget()
+        self.listBox = QListWidget(self)
         self.listBox.itemSelectionChanged.connect(self._selectedSymbol)
 
         minSize = 100
         for sKey, sLabel in nwQuotes.SYMBOLS.items():
-            theText = "[ %s ] %s" % (sKey, trConst(sLabel))
-            minSize = max(minSize, qMetrics.boundingRect(theText).width())
-            qtItem = QListWidgetItem(theText)
+            text = "[ %s ] %s" % (sKey, trConst(sLabel))
+            minSize = max(minSize, qMetrics.boundingRect(text).width())
+            qtItem = QListWidgetItem(text)
             qtItem.setData(self.D_KEY, sKey)
             self.listBox.addItem(qtItem)
-            if sKey == currentQuote:
+            if sKey == current:
                 self.listBox.setCurrentItem(qtItem)
 
         self.listBox.setMinimumWidth(minSize + CONFIG.pxInt(40))
         self.listBox.setMinimumHeight(CONFIG.pxInt(150))
 
         # Buttons
-        self.buttonBox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
+        self.buttonBox = QDialogButtonBox(QtDialogOk | QtDialogCancel, self)
         self.buttonBox.accepted.connect(self.accept)
         self.buttonBox.rejected.connect(self.reject)
 
         # Assemble
-        self.labelBox.addWidget(self.previewLabel, 0, Qt.AlignTop)
+        self.labelBox.addWidget(self.previewLabel, 0, QtAlignTop)
         self.labelBox.addStretch(1)
 
         self.innerBox.addLayout(self.labelBox)
@@ -113,15 +119,20 @@ class GuiQuoteSelect(QDialog):
         logger.debug("Delete: GuiQuoteSelect")
         return
 
-    ##
-    #  Events
-    ##
+    @property
+    def selectedQuote(self) -> str:
+        """Return the selected quote symbol."""
+        return self._selected
 
-    def closeEvent(self, event: QCloseEvent) -> None:
-        """Capture the close event and perform cleanup."""
-        event.accept()
-        self.deleteLater()
-        return
+    @classmethod
+    def getQuote(cls, parent: QWidget, current: str = "") -> tuple[str, bool]:
+        """Pop the dialog and return the result."""
+        cls = GuiQuoteSelect(parent, current=current)
+        cls.exec()
+        quote = cls._selected
+        accepted = cls.result() == QtAccepted
+        cls.softDelete()
+        return quote, accepted
 
     ##
     #  Private Slots
@@ -130,11 +141,8 @@ class GuiQuoteSelect(QDialog):
     @pyqtSlot()
     def _selectedSymbol(self) -> None:
         """Update the preview label and the selected quote style."""
-        selItems = self.listBox.selectedItems()
-        if selItems:
-            theSymbol = selItems[0].data(self.D_KEY)
-            self.previewLabel.setText(theSymbol)
-            self.selectedQuote = theSymbol
+        if items := self.listBox.selectedItems():
+            quote = items[0].data(self.D_KEY)
+            self.previewLabel.setText(quote)
+            self._selected = quote
         return
-
-# END Class GuiQuoteSelect
