@@ -32,8 +32,6 @@ class nwItemType(Enum):
     FOLDER  = 2
     FILE    = 3
 
-# END Enum nwItemType
-
 
 class nwItemClass(Enum):
 
@@ -47,9 +45,8 @@ class nwItemClass(Enum):
     ENTITY    = 7
     CUSTOM    = 8
     ARCHIVE   = 9
-    TRASH     = 10
-
-# END Enum nwItemClass
+    TEMPLATE  = 10
+    TRASH     = 11
 
 
 class nwItemLayout(Enum):
@@ -58,16 +55,17 @@ class nwItemLayout(Enum):
     DOCUMENT  = 1
     NOTE      = 2
 
-# END Enum nwItemLayout
-
 
 class nwComment(Enum):
 
     PLAIN    = 0
-    SYNOPSIS = 1
-    SHORT    = 2
-
-# END Enum nwComment
+    IGNORE   = 1
+    SYNOPSIS = 2
+    SHORT    = 3
+    NOTE     = 4
+    FOOTNOTE = 5
+    COMMENT  = 6
+    STORY    = 7
 
 
 class nwTrinary(Enum):
@@ -76,16 +74,12 @@ class nwTrinary(Enum):
     NEUTRAL  = 0
     POSITIVE = 1
 
-# END Enum nwTrinary
-
 
 class nwDocMode(Enum):
 
     VIEW = 0
     EDIT = 1
 
-# END Enum nwDocMode
-
 
 class nwDocAction(Enum):
 
@@ -107,25 +101,26 @@ class nwDocAction(Enum):
     BLOCK_H3  = 15
     BLOCK_H4  = 16
     BLOCK_COM = 17
-    BLOCK_TXT = 18
-    BLOCK_TTL = 19
-    BLOCK_UNN = 20
-    REPL_SNG  = 21
-    REPL_DBL  = 22
-    RM_BREAKS = 23
-    ALIGN_L   = 24
-    ALIGN_C   = 25
-    ALIGN_R   = 26
-    INDENT_L  = 27
-    INDENT_R  = 28
-    SC_ITALIC = 29
-    SC_BOLD   = 30
-    SC_STRIKE = 31
-    SC_ULINE  = 32
-    SC_SUP    = 33
-    SC_SUB    = 34
-
-# END Enum nwDocAction
+    BLOCK_IGN = 18
+    BLOCK_TXT = 19
+    BLOCK_TTL = 20
+    BLOCK_UNN = 21
+    BLOCK_HSC = 22
+    REPL_SNG  = 23
+    REPL_DBL  = 24
+    RM_BREAKS = 25
+    ALIGN_L   = 26
+    ALIGN_C   = 27
+    ALIGN_R   = 28
+    INDENT_L  = 29
+    INDENT_R  = 30
+    SC_ITALIC = 31
+    SC_BOLD   = 32
+    SC_STRIKE = 33
+    SC_ULINE  = 34
+    SC_MARK   = 35
+    SC_SUP    = 36
+    SC_SUB    = 37
 
 
 class nwDocInsert(Enum):
@@ -141,8 +136,7 @@ class nwDocInsert(Enum):
     VSPACE_S  = 8
     VSPACE_M  = 9
     LIPSUM    = 10
-
-# END Enum nwDocInsert
+    FOOTNOTE  = 11
 
 
 class nwView(Enum):
@@ -151,18 +145,14 @@ class nwView(Enum):
     PROJECT = 1
     NOVEL   = 2
     OUTLINE = 3
-
-# END Enum nwView
+    SEARCH  = 4
 
 
-class nwWidget(Enum):
+class nwFocus(Enum):
 
-    TREE    = 1
-    EDITOR  = 2
-    VIEWER  = 3
-    OUTLINE = 4
-
-# END Enum nwWidget
+    TREE     = 1
+    DOCUMENT = 2
+    OUTLINE  = 3
 
 
 class nwOutline(Enum):
@@ -185,8 +175,6 @@ class nwOutline(Enum):
     CUSTOM = 15
     SYNOP  = 16
 
-# END Enum nwOutline
-
 
 class nwBuildFmt(Enum):
 
@@ -199,4 +187,26 @@ class nwBuildFmt(Enum):
     J_HTML = 6
     J_NWD  = 7
 
-# END Enum nwBuildFormat
+
+class nwStatusShape(Enum):
+
+    SQUARE   = 0
+    TRIANGLE = 1
+    NABLA    = 2
+    DIAMOND  = 3
+    PENTAGON = 4
+    HEXAGON  = 5
+    STAR     = 6
+    PACMAN   = 7
+    CIRCLE_Q = 8
+    CIRCLE_H = 9
+    CIRCLE_T = 10
+    CIRCLE   = 11
+    BARS_1   = 12
+    BARS_2   = 13
+    BARS_3   = 14
+    BARS_4   = 15
+    BLOCK_1  = 16
+    BLOCK_2  = 17
+    BLOCK_3  = 18
+    BLOCK_4  = 19
