@@ -29,27 +29,24 @@ from __future__ import annotations
 import logging
 
 from enum import Enum
-from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import pyqtSignal, pyqtSlot, QPoint, QSize, Qt, QUrl
-from PyQt5.QtGui import (
-    QColor, QCursor, QFont, QMouseEvent, QPalette, QResizeEvent, QTextCursor,
-    QTextOption
-)
+from PyQt5.QtCore import QPoint, Qt, QUrl, pyqtSignal, pyqtSlot
+from PyQt5.QtGui import QCursor, QMouseEvent, QPalette, QResizeEvent, QTextCursor
 from PyQt5.QtWidgets import (
-    QAction, QFrame, QHBoxLayout, QLabel, QMenu, QTextBrowser, QToolButton,
-    QWidget, qApp
+    QAction, QApplication, QFrame, QHBoxLayout, QMenu, QTextBrowser,
+    QToolButton, QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.enum import nwItemType, nwDocAction, nwDocMode
+from novelwriter.constants import nwHeaders, nwUnicode
+from novelwriter.core.toqdoc import TextDocumentTheme, ToQTextDocument
+from novelwriter.enum import nwDocAction, nwDocMode, nwItemType
 from novelwriter.error import logException
-from novelwriter.constants import nwUnicode
-from novelwriter.core.tohtml import ToHtml
+from novelwriter.extensions.configlayout import NColourLabel
 from novelwriter.extensions.eventfilters import WheelEventFilter
-
-if TYPE_CHECKING:  # pragma: no cover
-    from novelwriter.guimain import GuiMain
+from novelwriter.extensions.modified import NIconToolButton
+from novelwriter.gui.theme import STYLES_MIN_TOOLBUTTON
+from novelwriter.types import QtAlignCenterTop, QtKeepAnchor, QtMouseLeft, QtMoveAnchor
 
 logger = logging.getLogger(__name__)
 
@@ -58,19 +55,19 @@ class GuiDocViewer(QTextBrowser):
 
     documentLoaded = pyqtSignal(str)
     loadDocumentTagRequest = pyqtSignal(str, Enum)
+    closeDocumentRequest = pyqtSignal()
+    reloadDocumentRequest = pyqtSignal()
     togglePanelVisibility = pyqtSignal()
     requestProjectItemSelected = pyqtSignal(str, bool)
 
-    def __init__(self, mainGui: GuiMain) -> None:
-        super().__init__(parent=mainGui)
+    def __init__(self, parent: QWidget) -> None:
+        super().__init__(parent=parent)
 
         logger.debug("Create: GuiDocViewer")
 
-        # Class Variables
-        self.mainGui = mainGui
-
         # Internal Variables
         self._docHandle = None
+        self._docTheme = TextDocumentTheme()
 
         # Settings
         self.setMinimumWidth(CONFIG.pxInt(300))
@@ -96,6 +93,9 @@ class GuiDocViewer(QTextBrowser):
         self.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.customContextMenuRequested.connect(self._openContextMenu)
 
+        # Function Mapping
+        self.changeFocusState = self.docHeader.changeFocusState
+
         self.initViewer()
 
         logger.debug("Ready: GuiDocViewer")
@@ -128,7 +128,7 @@ class GuiDocViewer(QTextBrowser):
         self.clear()
         self.setSearchPaths([""])
         self._docHandle = None
-        self.docHeader.setTitleFromHandle(self._docHandle)
+        self.docHeader.clearHeader()
         return
 
     def updateTheme(self) -> None:
@@ -139,35 +139,41 @@ class GuiDocViewer(QTextBrowser):
 
     def initViewer(self) -> None:
         """Set editor settings from main config."""
-        self._makeStyleSheet()
-
-        # Set Font
-        textFont = QFont()
-        textFont.setFamily(CONFIG.textFont)
-        textFont.setPointSize(CONFIG.textSize)
-        self.setFont(textFont)
+        # Set the font. See issues #1862 and #1875.
+        self.setFont(CONFIG.textFont)
+        self.docHeader.updateFont()
+        self.docFooter.updateFont()
 
         # Set the widget colours to match syntax theme
         mainPalette = self.palette()
-        mainPalette.setColor(QPalette.ColorRole.Window, QColor(*SHARED.theme.colBack))
-        mainPalette.setColor(QPalette.ColorRole.Base, QColor(*SHARED.theme.colBack))
-        mainPalette.setColor(QPalette.ColorRole.Text, QColor(*SHARED.theme.colText))
+        mainPalette.setColor(QPalette.ColorRole.Window, SHARED.theme.colBack)
+        mainPalette.setColor(QPalette.ColorRole.Base, SHARED.theme.colBack)
+        mainPalette.setColor(QPalette.ColorRole.Text, SHARED.theme.colText)
         self.setPalette(mainPalette)
 
         docPalette = self.viewport().palette()
-        docPalette.setColor(QPalette.ColorRole.Base, QColor(*SHARED.theme.colBack))
-        docPalette.setColor(QPalette.ColorRole.Text, QColor(*SHARED.theme.colText))
+        docPalette.setColor(QPalette.ColorRole.Base, SHARED.theme.colBack)
+        docPalette.setColor(QPalette.ColorRole.Text, SHARED.theme.colText)
         self.viewport().setPalette(docPalette)
-
         self.docHeader.matchColours()
         self.docFooter.matchColours()
 
+        # Update theme colours
+        self._docTheme.text      = SHARED.theme.colText
+        self._docTheme.highlight = SHARED.theme.colMark
+        self._docTheme.head      = SHARED.theme.colHead
+        self._docTheme.comment   = SHARED.theme.colHidden
+        self._docTheme.note      = SHARED.theme.colNote
+        self._docTheme.code      = SHARED.theme.colCode
+        self._docTheme.modifier  = SHARED.theme.colMod
+        self._docTheme.keyword   = SHARED.theme.colKey
+        self._docTheme.tag       = SHARED.theme.colTag
+        self._docTheme.optional  = SHARED.theme.colOpt
+        self._docTheme.dialog    = SHARED.theme.colDialN
+        self._docTheme.altdialog = SHARED.theme.colDialA
+
         # Set default text margins
         self.document().setDocumentMargin(0)
-        theOpt = QTextOption()
-        if CONFIG.doJustify:
-            theOpt.setAlignment(Qt.AlignmentFlag.AlignJustify)
-        self.document().setDefaultTextOption(theOpt)
 
         # Scroll bars
         if CONFIG.hideVScroll:
@@ -184,8 +190,7 @@ class GuiDocViewer(QTextBrowser):
         self.setTabStopDistance(CONFIG.getTabWidth())
 
         # If we have a document open, we should reload it in case the font changed
-        if self._docHandle is not None:
-            self.reloadText()
+        self.reloadText()
 
         return
 
@@ -197,26 +202,31 @@ class GuiDocViewer(QTextBrowser):
             return False
 
         logger.debug("Generating preview for item '%s'", tHandle)
-        qApp.setOverrideCursor(QCursor(Qt.CursorShape.WaitCursor))
+        QApplication.setOverrideCursor(QCursor(Qt.CursorShape.WaitCursor))
 
         sPos = self.verticalScrollBar().value()
-        aDoc = ToHtml(SHARED.project)
-        aDoc.setPreview(CONFIG.viewComments, CONFIG.viewSynopsis)
-        aDoc.setLinkHeaders(True)
+        qDoc = ToQTextDocument(SHARED.project)
+        qDoc.setJustify(CONFIG.doJustify)
+        qDoc.setDialogueHighlight(True)
+        qDoc.initDocument(CONFIG.textFont, self._docTheme)
+        qDoc.setKeywords(True)
+        qDoc.setComments(CONFIG.viewComments)
+        qDoc.setSynopsis(CONFIG.viewSynopsis)
 
         # Be extra careful here to prevent crashes when first opening a
         # project as a crash here leaves no way of recovering.
         # See issue #298
         try:
-            aDoc.setText(tHandle)
-            aDoc.doPreProcessing()
-            aDoc.tokenizeText()
-            aDoc.doConvert()
+            qDoc.setText(tHandle)
+            qDoc.doPreProcessing()
+            qDoc.tokenizeText()
+            qDoc.doConvert()
+            qDoc.appendFootnotes()
         except Exception:
             logger.error("Failed to generate preview for document with handle '%s'", tHandle)
             logException()
             self.setText(self.tr("An error occurred while generating the preview."))
-            qApp.restoreOverrideCursor()
+            QApplication.restoreOverrideCursor()
             return False
 
         # Refresh the tab stops
@@ -227,11 +237,7 @@ class GuiDocViewer(QTextBrowser):
             self.docHistory.append(tHandle)
 
         self.setDocumentTitle(tHandle)
-
-        # Replace tabs before setting the HTML, and then put them back in
-        self.setHtml(aDoc.theResult.replace("\t", "!!tab!!"))
-        while self.find("!!tab!!"):
-            self.textCursor().insertText("\t")
+        self.setDocument(qDoc.document)
 
         if self._docHandle == tHandle:
             # This is a refresh, so we set the scrollbar back to where it was
@@ -239,13 +245,14 @@ class GuiDocViewer(QTextBrowser):
 
         self._docHandle = tHandle
         SHARED.project.data.setLastHandle(tHandle, "viewer")
-        self.docHeader.setTitleFromHandle(self._docHandle)
+        self.docHeader.setHandle(tHandle)
+        self.docHeader.setOutline({
+            sTitle: (hItem.title, nwHeaders.H_LEVEL.get(hItem.level, 0))
+            for sTitle, hItem in SHARED.project.index.iterItemHeadings(tHandle)
+        })
         self.updateDocMargins()
 
-        # Since we change the content while it may still be rendering, we mark
-        # the document dirty again to make sure it's re-rendered properly.
-        self.redrawText()
-        qApp.restoreOverrideCursor()
+        QApplication.restoreOverrideCursor()
         self.documentLoaded.emit(tHandle)
 
         return True
@@ -256,12 +263,6 @@ class GuiDocViewer(QTextBrowser):
             self.loadText(self._docHandle, updateHistory=False)
         return
 
-    def redrawText(self) -> None:
-        """Redraw the text by marking the content as "dirty"."""
-        self.document().markContentsDirty(0, self.document().characterCount())
-        self.updateDocMargins()
-        return
-
     def docAction(self, action: nwDocAction) -> bool:
         """Process document actions on the current document."""
         logger.debug("Requesting action: '%s'", action.name)
@@ -281,12 +282,9 @@ class GuiDocViewer(QTextBrowser):
             return False
         return True
 
-    def navigateTo(self, tAnchor: str) -> None:
-        """Go to a specific #link in the document."""
-        if isinstance(tAnchor, str) and tAnchor.startswith("#"):
-            logger.debug("Moving to anchor '%s'", tAnchor)
-            self.setSource(QUrl(tAnchor))
-        return
+    def anyFocus(self) -> bool:
+        """Check if any widget or child widget has focus."""
+        return self.hasFocus() or self.isAncestorOf(QApplication.focusWidget())
 
     def clearNavHistory(self) -> None:
         """Clear the navigation history."""
@@ -340,11 +338,19 @@ class GuiDocViewer(QTextBrowser):
     @pyqtSlot(str)
     def updateDocInfo(self, tHandle: str) -> None:
         """Update the header title bar if needed."""
-        if tHandle == self._docHandle:
-            self.docHeader.setTitleFromHandle(self._docHandle)
+        if tHandle and tHandle == self._docHandle:
+            self.docHeader.setHandle(tHandle)
             self.updateDocMargins()
         return
 
+    @pyqtSlot(str)
+    def navigateTo(self, anchor: str) -> None:
+        """Go to a specific #link in the document."""
+        if isinstance(anchor, str) and anchor.startswith("#"):
+            logger.debug("Moving to anchor '%s'", anchor)
+            self.setSource(QUrl(anchor))
+        return
+
     ##
     #  Private Slots
     ##
@@ -364,12 +370,12 @@ class GuiDocViewer(QTextBrowser):
     @pyqtSlot("QUrl")
     def _linkClicked(self, url: QUrl) -> None:
         """Process a clicked link in the document."""
-        link = url.url()
-        logger.debug("Clicked link: '%s'", link)
-        if len(link) > 0:
-            theBits = link.split("=")
-            if len(theBits) == 2:
-                self.loadDocumentTagRequest.emit(theBits[1], nwDocMode.VIEW)
+        if link := url.url():
+            logger.debug("Clicked link: '%s'", link)
+            if (bits := link.partition("_")) and bits[0] == "#tag" and bits[2]:
+                self.loadDocumentTagRequest.emit(bits[2], nwDocMode.VIEW)
+            else:
+                self.navigateTo(link)
         return
 
     @pyqtSlot("QPoint")
@@ -404,7 +410,7 @@ class GuiDocViewer(QTextBrowser):
         ctxMenu.addAction(mnuSelPara)
 
         # Open the context menu
-        ctxMenu.exec_(self.viewport().mapToGlobal(point))
+        ctxMenu.exec(self.viewport().mapToGlobal(point))
         ctxMenu.deleteLater()
 
         return
@@ -446,8 +452,8 @@ class GuiDocViewer(QTextBrowser):
             posE = cursor.selectionEnd()
             selTxt = cursor.selectedText()
             if selTxt.startswith(nwUnicode.U_PSEP):
-                cursor.setPosition(posS+1, QTextCursor.MoveMode.MoveAnchor)
-                cursor.setPosition(posE, QTextCursor.MoveMode.KeepAnchor)
+                cursor.setPosition(posS+1, QtMoveAnchor)
+                cursor.setPosition(posE, QtKeepAnchor)
 
         self.setTextCursor(cursor)
 
@@ -459,65 +465,6 @@ class GuiDocViewer(QTextBrowser):
         self._makeSelection(selType)
         return
 
-    def _makeStyleSheet(self) -> None:
-        """Generate an appropriate style sheet for the document viewer,
-        based on the current syntax highlighter theme,
-        """
-        pTheme = SHARED.theme
-        styleSheet = (
-            "body {{"
-            "  color: rgb({tColR}, {tColG}, {tColB});"
-            "}}\n"
-            "h1, h2, h3, h4 {{"
-            "  color: rgb({hColR}, {hColG}, {hColB});"
-            "}}\n"
-            "a {{"
-            "  color: rgb({aColR}, {aColG}, {aColB});"
-            "}}\n"
-            "mark {{"
-            "  color: rgb({eColR}, {eColG}, {eColB});"
-            "}}\n"
-            ".tags {{"
-            "  color: rgb({kColR}, {kColG}, {kColB});"
-            "}}\n"
-            ".comment {{"
-            "  color: rgb({cColR}, {cColG}, {cColB});"
-            "}}\n"
-            ".synopsis {{"
-            "  color: rgb({mColR}, {mColG}, {mColB});"
-            "}}\n"
-            ".title {{"
-            "  text-align: center;"
-            "}}\n"
-        ).format(
-            tColR=pTheme.colText[0],
-            tColG=pTheme.colText[1],
-            tColB=pTheme.colText[2],
-            hColR=pTheme.colHead[0],
-            hColG=pTheme.colHead[1],
-            hColB=pTheme.colHead[2],
-            aColR=pTheme.colVal[0],
-            aColG=pTheme.colVal[1],
-            aColB=pTheme.colVal[2],
-            eColR=pTheme.colEmph[0],
-            eColG=pTheme.colEmph[1],
-            eColB=pTheme.colEmph[2],
-            kColR=pTheme.colKey[0],
-            kColG=pTheme.colKey[1],
-            kColB=pTheme.colKey[2],
-            cColR=pTheme.colHidden[0],
-            cColG=pTheme.colHidden[1],
-            cColB=pTheme.colHidden[2],
-            mColR=pTheme.colMod[0],
-            mColG=pTheme.colMod[1],
-            mColB=pTheme.colMod[2],
-        )
-        self.document().setDefaultStyleSheet(styleSheet)
-
-        return
-
-# END Class GuiDocViewer
-
 
 class GuiDocViewHistory:
 
@@ -631,15 +578,13 @@ class GuiDocViewHistory:
                 )
         return
 
-# END Class GuiDocViewHistory
-
-
-# =============================================================================================== #
-#  The Embedded Document Header
-#  Only used by DocViewer, and is at a fixed position in the QTextBrowser's viewport
-# =============================================================================================== #
 
 class GuiDocViewHeader(QWidget):
+    """The Embedded Document Header
+
+    Only used by DocViewer, and is at a fixed position in the
+    QTextBrowser's viewport.
+    """
 
     def __init__(self, docViewer: GuiDocViewer) -> None:
         super().__init__(parent=docViewer)
@@ -647,86 +592,77 @@ class GuiDocViewHeader(QWidget):
         logger.debug("Create: GuiDocViewHeader")
 
         self.docViewer = docViewer
-        self.mainGui   = docViewer.mainGui
 
         # Internal Variables
         self._docHandle = None
+        self._docOutline: dict[str, tuple[str, int]] = {}
 
-        fPx = int(0.9*SHARED.theme.fontPixelSize)
-        hSp = CONFIG.pxInt(6)
+        iPx = SHARED.theme.baseIconHeight
+        iSz = SHARED.theme.baseIconSize
+        mPx = CONFIG.pxInt(4)
 
         # Main Widget Settings
         self.setAutoFillBackground(True)
 
         # Title Label
-        self.docTitle = QLabel()
-        self.docTitle.setText("")
-        self.docTitle.setIndent(0)
-        self.docTitle.setMargin(0)
-        self.docTitle.setContentsMargins(0, 0, 0, 0)
-        self.docTitle.setAutoFillBackground(True)
-        self.docTitle.setAlignment(Qt.AlignmentFlag.AlignHCenter | Qt.AlignmentFlag.AlignTop)
-        self.docTitle.setFixedHeight(fPx)
+        self.itemTitle = NColourLabel("", self, faded=SHARED.theme.fadedText)
+        self.itemTitle.setMargin(0)
+        self.itemTitle.setContentsMargins(0, 0, 0, 0)
+        self.itemTitle.setAutoFillBackground(True)
+        self.itemTitle.setAlignment(QtAlignCenterTop)
+        self.itemTitle.setFixedHeight(iPx)
 
-        lblFont = self.docTitle.font()
-        lblFont.setPointSizeF(0.9*SHARED.theme.fontPointSize)
-        self.docTitle.setFont(lblFont)
+        # Other Widgets
+        self.outlineMenu = QMenu(self)
 
         # Buttons
-        self.backButton = QToolButton(self)
-        self.backButton.setContentsMargins(0, 0, 0, 0)
-        self.backButton.setIconSize(QSize(fPx, fPx))
-        self.backButton.setFixedSize(fPx, fPx)
-        self.backButton.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
+        self.outlineButton = NIconToolButton(self, iSz)
+        self.outlineButton.setVisible(False)
+        self.outlineButton.setToolTip(self.tr("Outline"))
+        self.outlineButton.setMenu(self.outlineMenu)
+
+        self.backButton = NIconToolButton(self, iSz)
         self.backButton.setVisible(False)
         self.backButton.setToolTip(self.tr("Go Backward"))
         self.backButton.clicked.connect(self.docViewer.navBackward)
 
-        self.forwardButton = QToolButton(self)
-        self.forwardButton.setContentsMargins(0, 0, 0, 0)
-        self.forwardButton.setIconSize(QSize(fPx, fPx))
-        self.forwardButton.setFixedSize(fPx, fPx)
-        self.forwardButton.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
+        self.forwardButton = NIconToolButton(self, iSz)
         self.forwardButton.setVisible(False)
         self.forwardButton.setToolTip(self.tr("Go Forward"))
         self.forwardButton.clicked.connect(self.docViewer.navForward)
 
-        self.refreshButton = QToolButton(self)
-        self.refreshButton.setContentsMargins(0, 0, 0, 0)
-        self.refreshButton.setIconSize(QSize(fPx, fPx))
-        self.refreshButton.setFixedSize(fPx, fPx)
-        self.refreshButton.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
+        self.refreshButton = NIconToolButton(self, iSz)
         self.refreshButton.setVisible(False)
         self.refreshButton.setToolTip(self.tr("Reload"))
         self.refreshButton.clicked.connect(self._refreshDocument)
 
-        self.closeButton = QToolButton(self)
-        self.closeButton.setContentsMargins(0, 0, 0, 0)
-        self.closeButton.setIconSize(QSize(fPx, fPx))
-        self.closeButton.setFixedSize(fPx, fPx)
-        self.closeButton.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
+        self.closeButton = NIconToolButton(self, iSz)
         self.closeButton.setVisible(False)
         self.closeButton.setToolTip(self.tr("Close"))
         self.closeButton.clicked.connect(self._closeDocument)
 
         # Assemble Layout
         self.outerBox = QHBoxLayout()
-        self.outerBox.setSpacing(hSp)
+        self.outerBox.addWidget(self.outlineButton, 0)
         self.outerBox.addWidget(self.backButton, 0)
         self.outerBox.addWidget(self.forwardButton, 0)
-        self.outerBox.addWidget(self.docTitle, 1)
+        self.outerBox.addSpacing(mPx)
+        self.outerBox.addWidget(self.itemTitle, 1)
+        self.outerBox.addSpacing(mPx)
+        self.outerBox.addSpacing(iPx)
         self.outerBox.addWidget(self.refreshButton, 0)
         self.outerBox.addWidget(self.closeButton, 0)
+        self.outerBox.setSpacing(0)
+
         self.setLayout(self.outerBox)
 
         # Fix Margins and Size
         # This is needed for high DPI systems. See issue #499.
-        cM = CONFIG.pxInt(8)
         self.setContentsMargins(0, 0, 0, 0)
-        self.outerBox.setContentsMargins(cM, cM, cM, cM)
-        self.setMinimumHeight(fPx + 2*cM)
+        self.outerBox.setContentsMargins(mPx, mPx, mPx, mPx)
+        self.setMinimumHeight(iPx + 2*mPx)
 
-        # Fix the Colours
+        self.updateFont()
         self.updateTheme()
 
         logger.debug("Ready: GuiDocViewHeader")
@@ -737,18 +673,56 @@ class GuiDocViewHeader(QWidget):
     #  Methods
     ##
 
+    def clearHeader(self) -> None:
+        """Clear the header."""
+        self._docHandle = None
+        self._docOutline = {}
+
+        self.itemTitle.setText("")
+        self.outlineMenu.clear()
+        self.outlineButton.setVisible(False)
+        self.backButton.setVisible(False)
+        self.forwardButton.setVisible(False)
+        self.closeButton.setVisible(False)
+        self.refreshButton.setVisible(False)
+        return
+
+    def setOutline(self, data: dict[str, tuple[str, int]]) -> None:
+        """Set the document outline dataset."""
+        tHandle = self._docHandle
+        if data != self._docOutline and tHandle:
+            self.outlineMenu.clear()
+            entries = []
+            minLevel = 5
+            for title, (text, level) in data.items():
+                if title != "T0000":
+                    entries.append((title, text, level))
+                    minLevel = min(minLevel, level)
+            for title, text, level in entries[:30]:
+                indent = "    "*(level - minLevel)
+                action = self.outlineMenu.addAction(f"{indent}{text}")
+                action.triggered.connect(
+                    lambda _, title=title: self.docViewer.navigateTo(f"#{tHandle}:{title}")
+                )
+            self._docOutline = data
+        return
+
+    def updateFont(self) -> None:
+        """Update the font settings."""
+        self.setFont(SHARED.theme.guiFont)
+        self.itemTitle.setFont(SHARED.theme.guiFontSmall)
+        return
+
     def updateTheme(self) -> None:
         """Update theme elements."""
-        self.backButton.setIcon(SHARED.theme.getIcon("backward"))
-        self.forwardButton.setIcon(SHARED.theme.getIcon("forward"))
-        self.refreshButton.setIcon(SHARED.theme.getIcon("refresh"))
-        self.closeButton.setIcon(SHARED.theme.getIcon("close"))
-
-        buttonStyle = (
-            "QToolButton {{border: none; background: transparent;}} "
-            "QToolButton:hover {{border: none; background: rgba({0},{1},{2},0.2);}}"
-        ).format(*SHARED.theme.colText)
+        self.outlineButton.setThemeIcon("list")
+        self.backButton.setThemeIcon("backward")
+        self.forwardButton.setThemeIcon("forward")
+        self.refreshButton.setThemeIcon("refresh")
+        self.closeButton.setThemeIcon("close")
 
+        buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
+        self.outlineButton.setStyleSheet(buttonStyle)
         self.backButton.setStyleSheet(buttonStyle)
         self.forwardButton.setStyleSheet(buttonStyle)
         self.refreshButton.setStyleSheet(buttonStyle)
@@ -763,42 +737,36 @@ class GuiDocViewHeader(QWidget):
         theme rather than the main GUI.
         """
         palette = QPalette()
-        palette.setColor(QPalette.ColorRole.Window, QColor(*SHARED.theme.colBack))
-        palette.setColor(QPalette.ColorRole.WindowText, QColor(*SHARED.theme.colText))
-        palette.setColor(QPalette.ColorRole.Text, QColor(*SHARED.theme.colText))
+        palette.setColor(QPalette.ColorRole.Window, SHARED.theme.colBack)
+        palette.setColor(QPalette.ColorRole.WindowText, SHARED.theme.colText)
+        palette.setColor(QPalette.ColorRole.Text, SHARED.theme.colText)
         self.setPalette(palette)
-        self.docTitle.setPalette(palette)
+        self.itemTitle.setTextColors(
+            color=palette.windowText().color(), faded=SHARED.theme.fadedText
+        )
         return
 
-    def setTitleFromHandle(self, tHandle: str | None) -> None:
+    def changeFocusState(self, state: bool) -> None:
+        """Toggle focus state."""
+        self.itemTitle.setColorState(state)
+        return
+
+    def setHandle(self, tHandle: str) -> None:
         """Sets the document title from the handle, or alternatively,
         set the whole document path.
         """
         self._docHandle = tHandle
-        if tHandle is None:
-            self.docTitle.setText("")
-            self.backButton.setVisible(False)
-            self.forwardButton.setVisible(False)
-            self.closeButton.setVisible(False)
-            self.refreshButton.setVisible(False)
-            return
 
-        pTree = SHARED.project.tree
         if CONFIG.showFullPath:
-            tTitle = []
-            tTree = pTree.getItemPath(tHandle)
-            for aHandle in reversed(tTree):
-                nwItem = pTree[aHandle]
-                if nwItem is not None:
-                    tTitle.append(nwItem.itemName)
-            sSep = "  %s  " % nwUnicode.U_RSAQUO
-            self.docTitle.setText(sSep.join(tTitle))
+            self.itemTitle.setText(f"  {nwUnicode.U_RSAQUO}  ".join(reversed(
+                [name for name in SHARED.project.tree.getItemPath(tHandle, asName=True)]
+            )))
         else:
-            if nwItem := pTree[tHandle]:
-                self.docTitle.setText(nwItem.itemName)
+            self.itemTitle.setText(i.itemName if (i := SHARED.project.tree[tHandle]) else "")
 
         self.backButton.setVisible(True)
         self.forwardButton.setVisible(True)
+        self.outlineButton.setVisible(True)
         self.closeButton.setVisible(True)
         self.refreshButton.setVisible(True)
 
@@ -817,15 +785,14 @@ class GuiDocViewHeader(QWidget):
     @pyqtSlot()
     def _closeDocument(self) -> None:
         """Trigger the close editor/viewer on the main window."""
-        self.mainGui.closeDocViewer()
+        self.clearHeader()
+        self.docViewer.closeDocumentRequest.emit()
         return
 
     @pyqtSlot()
     def _refreshDocument(self) -> None:
         """Reload the content of the document."""
-        if self.docViewer.docHandle == self.mainGui.docEditor.docHandle:
-            self.mainGui.saveDocument()
-        self.docViewer.reloadText()
+        self.docViewer.reloadDocumentRequest.emit()
         return
 
     ##
@@ -836,19 +803,17 @@ class GuiDocViewHeader(QWidget):
         """Capture a click on the title and ensure that the item is
         selected in the project tree.
         """
-        if event.button() == Qt.MouseButton.LeftButton:
+        if event.button() == QtMouseLeft:
             self.docViewer.requestProjectItemSelected.emit(self._docHandle, True)
         return
 
-# END Class GuiDocViewHeader
-
-
-# =============================================================================================== #
-#  The Embedded Document Footer
-#  Only used by DocViewer, and is at a fixed position in the QTextBrowser's viewport
-# =============================================================================================== #
 
 class GuiDocViewFooter(QWidget):
+    """The Embedded Document Footer
+
+    Only used by DocViewer, and is at a fixed position in the
+    QTextBrowser's viewport.
+    """
 
     def __init__(self, docViewer: GuiDocViewer) -> None:
         super().__init__(parent=docViewer)
@@ -856,22 +821,21 @@ class GuiDocViewFooter(QWidget):
         logger.debug("Create: GuiDocViewFooter")
 
         self.docViewer = docViewer
-        self.mainGui   = docViewer.mainGui
 
         # Internal Variables
         self._docHandle = None
 
-        fPx = int(0.9*SHARED.theme.fontPixelSize)
+        iPx = SHARED.theme.baseIconHeight
+        iSz = SHARED.theme.baseIconSize
         hSp = CONFIG.pxInt(4)
+        mPx = CONFIG.pxInt(4)
 
         # Main Widget Settings
         self.setContentsMargins(0, 0, 0, 0)
         self.setAutoFillBackground(True)
 
         # Show/Hide Details
-        self.showHide = QToolButton(self)
-        self.showHide.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
-        self.showHide.setIconSize(QSize(fPx, fPx))
+        self.showHide = NIconToolButton(self, iSz)
         self.showHide.clicked.connect(lambda: self.docViewer.togglePanelVisibility.emit())
         self.showHide.setToolTip(self.tr("Show/Hide Viewer Panel"))
 
@@ -881,7 +845,7 @@ class GuiDocViewFooter(QWidget):
         self.showComments.setCheckable(True)
         self.showComments.setChecked(CONFIG.viewComments)
         self.showComments.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
-        self.showComments.setIconSize(QSize(fPx, fPx))
+        self.showComments.setIconSize(iSz)
         self.showComments.toggled.connect(self._doToggleComments)
         self.showComments.setToolTip(self.tr("Show Comments"))
 
@@ -891,15 +855,10 @@ class GuiDocViewFooter(QWidget):
         self.showSynopsis.setCheckable(True)
         self.showSynopsis.setChecked(CONFIG.viewSynopsis)
         self.showSynopsis.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
-        self.showSynopsis.setIconSize(QSize(fPx, fPx))
+        self.showSynopsis.setIconSize(iSz)
         self.showSynopsis.toggled.connect(self._doToggleSynopsis)
         self.showSynopsis.setToolTip(self.tr("Show Synopsis Comments"))
 
-        lblFont = self.font()
-        lblFont.setPointSizeF(0.9*SHARED.theme.fontPointSize)
-        self.showComments.setFont(lblFont)
-        self.showSynopsis.setFont(lblFont)
-
         # Assemble Layout
         self.outerBox = QHBoxLayout()
         self.outerBox.addWidget(self.showHide, 0)
@@ -911,12 +870,11 @@ class GuiDocViewFooter(QWidget):
 
         # Fix Margins and Size
         # This is needed for high DPI systems. See issue #499.
-        cM = CONFIG.pxInt(8)
         self.setContentsMargins(0, 0, 0, 0)
-        self.outerBox.setContentsMargins(cM, cM, cM, cM)
-        self.setMinimumHeight(fPx + 2*cM)
+        self.outerBox.setContentsMargins(mPx, mPx, mPx, mPx)
+        self.setMinimumHeight(iPx + 2*mPx)
 
-        # Fix the Colours
+        self.updateFont()
         self.updateTheme()
 
         logger.debug("Ready: GuiDocViewFooter")
@@ -927,22 +885,24 @@ class GuiDocViewFooter(QWidget):
     #  Methods
     ##
 
+    def updateFont(self) -> None:
+        """Update the font settings."""
+        self.setFont(SHARED.theme.guiFont)
+        self.showComments.setFont(SHARED.theme.guiFontSmall)
+        self.showSynopsis.setFont(SHARED.theme.guiFontSmall)
+        return
+
     def updateTheme(self) -> None:
         """Update theme elements."""
         # Icons
         fPx = int(0.9*SHARED.theme.fontPixelSize)
         bulletIcon = SHARED.theme.getToggleIcon("bullet", (fPx, fPx))
 
-        self.showHide.setIcon(SHARED.theme.getIcon("panel"))
+        self.showHide.setThemeIcon("panel")
         self.showComments.setIcon(bulletIcon)
         self.showSynopsis.setIcon(bulletIcon)
 
-        # StyleSheets
-        buttonStyle = (
-            "QToolButton {{border: none; background: transparent;}} "
-            "QToolButton:hover {{border: none; background: rgba({0},{1},{2},0.2);}}"
-        ).format(*SHARED.theme.colText)
-
+        buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
         self.showHide.setStyleSheet(buttonStyle)
         self.showComments.setStyleSheet(buttonStyle)
         self.showSynopsis.setStyleSheet(buttonStyle)
@@ -956,9 +916,9 @@ class GuiDocViewFooter(QWidget):
         theme rather than the main GUI.
         """
         palette = QPalette()
-        palette.setColor(QPalette.ColorRole.Window, QColor(*SHARED.theme.colBack))
-        palette.setColor(QPalette.ColorRole.WindowText, QColor(*SHARED.theme.colText))
-        palette.setColor(QPalette.ColorRole.Text, QColor(*SHARED.theme.colText))
+        palette.setColor(QPalette.ColorRole.Window, SHARED.theme.colBack)
+        palette.setColor(QPalette.ColorRole.WindowText, SHARED.theme.colText)
+        palette.setColor(QPalette.ColorRole.Text, SHARED.theme.colText)
         self.setPalette(palette)
         return
 
@@ -979,5 +939,3 @@ class GuiDocViewFooter(QWidget):
         CONFIG.viewSynopsis = state
         self.docViewer.reloadText()
         return
-
-# END Class GuiDocViewFooter
