@@ -27,17 +27,20 @@ import logging
 
 from enum import Enum
 
-from PyQt5.QtCore import QModelIndex, QSize, Qt, pyqtSignal, pyqtSlot
+from PyQt5.QtCore import QModelIndex, Qt, pyqtSignal, pyqtSlot
 from PyQt5.QtWidgets import (
-    QAbstractItemView, QFrame, QHeaderView, QTabWidget, QTreeWidget,
-    QTreeWidgetItem, QVBoxLayout, QWidget
+    QAbstractItemView, QFrame, QHeaderView, QMenu, QTabWidget, QToolButton,
+    QTreeWidget, QTreeWidgetItem, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.enum import nwDocMode, nwItemClass
 from novelwriter.common import checkInt
 from novelwriter.constants import nwHeaders, nwLabels, nwLists, trConst
 from novelwriter.core.index import IndexHeading, IndexItem
+from novelwriter.enum import nwDocMode, nwItemClass
+from novelwriter.extensions.modified import NIconToolButton
+from novelwriter.gui.theme import STYLES_FLAT_TABS, STYLES_MIN_TOOLBUTTON
+from novelwriter.types import QtDecoration, QtUserRole
 
 logger = logging.getLogger(__name__)
 
@@ -54,10 +57,23 @@ class GuiDocViewerPanel(QWidget):
 
         self._lastHandle = None
 
+        iSz = SHARED.theme.baseIconSize
+
         self.tabBackRefs = _ViewPanelBackRefs(self)
 
+        self.optsMenu = QMenu(self)
+
+        self.aInactive = self.optsMenu.addAction(self.tr("Hide Inactive Tags"))
+        self.aInactive.setCheckable(True)
+        self.aInactive.toggled.connect(self._toggleHideInactive)
+
+        self.optsButton = NIconToolButton(self, iSz)
+        self.optsButton.setMenu(self.optsMenu)
+        self.optsButton.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
+
         self.mainTabs = QTabWidget(self)
         self.mainTabs.addTab(self.tabBackRefs, self.tr("References"))
+        self.mainTabs.setCornerWidget(self.optsButton, Qt.Corner.TopLeftCorner)
 
         self.kwTabs: dict[str, _ViewPanelKeyWords] = {}
         self.idTabs: dict[str, int] = {}
@@ -85,46 +101,34 @@ class GuiDocViewerPanel(QWidget):
 
     def updateTheme(self, updateTabs: bool = True) -> None:
         """Update theme elements."""
-        vPx = CONFIG.pxInt(4)
-        lPx = CONFIG.pxInt(2)
-        rPx = CONFIG.pxInt(14)
-        hCol = self.palette().highlight().color()
-
-        styleSheet = (
-            "QTabWidget::pane {border: 0;} "
-            "QTabWidget QTabBar::tab {"
-            f"border: 0; padding: {vPx}px {rPx}px {vPx}px {lPx}px;"
-            "} "
-            "QTabWidget QTabBar::tab:selected {"
-            f"color: rgb({hCol.red()}, {hCol.green()}, {hCol.blue()});"
-            "} "
-        )
-        self.mainTabs.setStyleSheet(styleSheet)
+        self.optsButton.setThemeIcon("menu")
+        self.optsButton.setStyleSheet(SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON))
+        self.mainTabs.setStyleSheet(SHARED.theme.getStyleSheet(STYLES_FLAT_TABS))
         self.updateHandle(self._lastHandle)
-
         if updateTabs:
             self.tabBackRefs.updateTheme()
             for tab in self.kwTabs.values():
                 tab.updateTheme()
-
         return
 
     def openProjectTasks(self) -> None:
         """Run open project tasks."""
-        widths = SHARED.project.options.getValue("GuiDocViewerPanel", "colWidths", {})
-        if isinstance(widths, dict):
-            for key, value in widths.items():
+        colWidths = SHARED.project.options.getValue("GuiDocViewerPanel", "colWidths", {})
+        hideInactive = SHARED.project.options.getBool("GuiDocViewerPanel", "hideInactive", False)
+        self.aInactive.setChecked(hideInactive)
+        if isinstance(colWidths, dict):
+            for key, value in colWidths.items():
                 if key in self.kwTabs and isinstance(value, list):
                     self.kwTabs[key].setColumnWidths(value)
         return
 
     def closeProjectTasks(self) -> None:
         """Run close project tasks."""
-        widths = {}
-        for key, tab in self.kwTabs.items():
-            widths[key] = tab.getColumnWidths()
         logger.debug("Saving State: GuiDocViewerPanel")
-        SHARED.project.options.setValue("GuiDocViewerPanel", "colWidths", widths)
+        colWidths = {k: t.getColumnWidths() for k, t in self.kwTabs.items()}
+        hideInactive = self.aInactive.isChecked()
+        SHARED.project.options.setValue("GuiDocViewerPanel", "colWidths", colWidths)
+        SHARED.project.options.setValue("GuiDocViewerPanel", "hideInactive", hideInactive)
         return
 
     ##
@@ -142,9 +146,7 @@ class GuiDocViewerPanel(QWidget):
     @pyqtSlot()
     def indexHasAppeared(self) -> None:
         """Handle event when the index has appeared."""
-        for key, name, tClass, iItem, hItem in SHARED.project.index.getTagsData():
-            if tClass in self.kwTabs and iItem and hItem:
-                self.kwTabs[tClass].addUpdateEntry(key, name, iItem, hItem)
+        self._loadAllTags()
         self._updateTabVisibility()
         self.updateHandle(self._lastHandle)
         return
@@ -153,10 +155,15 @@ class GuiDocViewerPanel(QWidget):
     def projectItemChanged(self, tHandle: str) -> None:
         """Update meta data for project item."""
         self.tabBackRefs.refreshDocument(tHandle)
+        activeOnly = self.aInactive.isChecked()
         for key in SHARED.project.index.getDocumentTags(tHandle):
             name, tClass, iItem, hItem = SHARED.project.index.getSingleTag(key)
             if tClass in self.kwTabs and iItem and hItem:
-                self.kwTabs[tClass].addUpdateEntry(key, name, iItem, hItem)
+                if not activeOnly or (iItem and iItem.item.isActive):
+                    self.kwTabs[tClass].addUpdateEntry(key, name, iItem, hItem)
+                else:
+                    self.kwTabs[tClass].removeEntry(key)
+        self._updateTabVisibility()
         return
 
     @pyqtSlot(str)
@@ -182,18 +189,44 @@ class GuiDocViewerPanel(QWidget):
         self._updateTabVisibility()
         return
 
+    @pyqtSlot(str)
+    def updateStatusLabels(self, kind: str) -> None:
+        """Update the importance labels."""
+        if kind == "i":
+            self._loadAllTags()
+        return
+
+    ##
+    #  Private Slots
+    ##
+
+    @pyqtSlot(bool)
+    def _toggleHideInactive(self, state: bool) -> None:
+        """Process toggling of active/inactive visibility."""
+        logger.debug("Setting inactive items to %s", "hidden" if state else "visible")
+        for cTab in self.kwTabs.values():
+            cTab.clearContent()
+        self._loadAllTags()
+        self._updateTabVisibility()
+        return
+
     ##
     #  Internal Functions
     ##
 
     def _updateTabVisibility(self) -> None:
         """Hide class tabs with no content."""
-        if CONFIG.verQtValue >= 0x050f00:
-            for tClass, cTab in self.kwTabs.items():
-                self.mainTabs.setTabVisible(self.idTabs[tClass], cTab.countEntries() > 0)
+        for tClass, cTab in self.kwTabs.items():
+            self.mainTabs.setTabVisible(self.idTabs[tClass], cTab.countEntries() > 0)
         return
 
-# END Class GuiDocViewerPanel
+    def _loadAllTags(self) -> None:
+        """Load all tags into the tabs."""
+        data = SHARED.project.index.getTagsData(activeOnly=self.aInactive.isChecked())
+        for key, name, tClass, iItem, hItem in data:
+            if tClass in self.kwTabs and iItem and hItem:
+                self.kwTabs[tClass].addUpdateEntry(key, name, iItem, hItem)
+        return
 
 
 class _ViewPanelBackRefs(QTreeWidget):
@@ -204,7 +237,7 @@ class _ViewPanelBackRefs(QTreeWidget):
     C_VIEW  = 2
     C_TITLE = 3
 
-    D_HANDLE = Qt.ItemDataRole.UserRole
+    D_HANDLE = QtUserRole
 
     def __init__(self, parent: GuiDocViewerPanel) -> None:
         super().__init__(parent=parent)
@@ -212,13 +245,14 @@ class _ViewPanelBackRefs(QTreeWidget):
         self._parent = parent
         self._treeMap: dict[str, QTreeWidgetItem] = {}
 
-        iPx = SHARED.theme.baseIconSize
+        iPx = SHARED.theme.baseIconHeight
+        iSz = SHARED.theme.baseIconSize
         cMg = CONFIG.pxInt(6)
 
         self.setHeaderLabels([self.tr("Document"), "", "", self.tr("First Heading")])
         self.setIndentation(0)
         self.setSelectionMode(QAbstractItemView.SelectionMode.NoSelection)
-        self.setIconSize(QSize(iPx, iPx))
+        self.setIconSize(iSz)
         self.setFrameStyle(QFrame.Shape.NoFrame)
 
         # Set Header Sizes
@@ -320,7 +354,7 @@ class _ViewPanelBackRefs(QTreeWidget):
             trItem.setToolTip(self.C_DOC, nwItem.itemName)
             trItem.setIcon(self.C_EDIT, self._editIcon)
             trItem.setIcon(self.C_VIEW, self._viewIcon)
-            trItem.setData(self.C_TITLE, Qt.ItemDataRole.DecorationRole, hDec)
+            trItem.setData(self.C_TITLE, QtDecoration, hDec)
             trItem.setText(self.C_TITLE, hItem.title)
             trItem.setToolTip(self.C_TITLE, hItem.title)
             trItem.setData(self.C_DATA, self.D_HANDLE, tHandle)
@@ -331,8 +365,6 @@ class _ViewPanelBackRefs(QTreeWidget):
 
         return
 
-# END Class _ViewPanelBackRefs
-
 
 class _ViewPanelKeyWords(QTreeWidget):
 
@@ -345,7 +377,7 @@ class _ViewPanelKeyWords(QTreeWidget):
     C_TITLE  = 5
     C_SHORT  = 6
 
-    D_TAG = Qt.ItemDataRole.UserRole
+    D_TAG = QtUserRole
 
     def __init__(self, parent: GuiDocViewerPanel, itemClass: nwItemClass) -> None:
         super().__init__(parent=parent)
@@ -354,7 +386,8 @@ class _ViewPanelKeyWords(QTreeWidget):
         self._class = itemClass
         self._treeMap: dict[str, QTreeWidgetItem] = {}
 
-        iPx = SHARED.theme.baseIconSize
+        iPx = SHARED.theme.baseIconHeight
+        iSz = SHARED.theme.baseIconSize
         cMg = CONFIG.pxInt(6)
 
         self.setHeaderLabels([
@@ -362,7 +395,7 @@ class _ViewPanelKeyWords(QTreeWidget):
             self.tr("Heading"), self.tr("Short Description")
         ])
         self.setIndentation(0)
-        self.setIconSize(QSize(iPx, iPx))
+        self.setIconSize(iSz)
         self.setFrameStyle(QFrame.Shape.NoFrame)
         self.setSelectionMode(QAbstractItemView.SelectionMode.NoSelection)
         self.setExpandsOnDoubleClick(False)
@@ -419,7 +452,7 @@ class _ViewPanelKeyWords(QTreeWidget):
             nwItem.itemType, nwItem.itemClass,
             nwItem.itemLayout, nwItem.mainHeading
         )
-        impLabel, impIcon = nwItem.getImportStatus(incIcon=True)
+        impLabel, impIcon = nwItem.getImportStatus()
         iLevel = nwHeaders.H_LEVEL.get(hItem.level, 0) if nwItem.isDocumentLayout() else 5
         hDec = SHARED.theme.getHeaderDecorationNarrow(iLevel)
 
@@ -438,7 +471,7 @@ class _ViewPanelKeyWords(QTreeWidget):
         trItem.setIcon(self.C_DOC, docIcon)
         trItem.setText(self.C_DOC, nwItem.itemName)
         trItem.setToolTip(self.C_DOC, nwItem.itemName)
-        trItem.setData(self.C_TITLE, Qt.ItemDataRole.DecorationRole, hDec)
+        trItem.setData(self.C_TITLE, QtDecoration, hDec)
         trItem.setText(self.C_TITLE, hItem.title)
         trItem.setToolTip(self.C_TITLE, hItem.title)
         trItem.setText(self.C_SHORT, hItem.synopsis)
@@ -498,5 +531,3 @@ class _ViewPanelKeyWords(QTreeWidget):
         if index.column() not in (self.C_EDIT, self.C_VIEW):
             self._parent.loadDocumentTagRequest.emit(tag, nwDocMode.VIEW)
         return
-
-# END Class _ViewPanelKeyWords
