@@ -25,30 +25,29 @@ from __future__ import annotations
 
 import logging
 
-from typing import TYPE_CHECKING
-
-from PyQt5.QtGui import QFont
-from PyQt5.QtCore import Qt, pyqtSlot
-from PyQt5.QtWidgets import QWidget, QGridLayout, QLabel
+from PyQt5.QtCore import pyqtSlot
+from PyQt5.QtWidgets import QGridLayout, QLabel, QWidget
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.constants import trConst, nwLabels
-
-if TYPE_CHECKING:  # pragma: no cover
-    from novelwriter.guimain import GuiMain
+from novelwriter.common import elide
+from novelwriter.constants import nwLabels, trConst
+from novelwriter.types import (
+    QtAlignLeft, QtAlignLeftBase, QtAlignRight, QtAlignRightBase,
+    QtAlignRightMiddle
+)
 
 logger = logging.getLogger(__name__)
 
 
 class GuiItemDetails(QWidget):
 
-    def __init__(self, mainGui: GuiMain) -> None:
-        super().__init__(parent=mainGui)
+    def __init__(self, parent: QWidget) -> None:
+        super().__init__(parent=parent)
 
         logger.debug("Create: GuiItemDetails")
 
         # Internal Variables
-        self._itemHandle  = None
+        self._handle = None
 
         # Sizes
         hSp = CONFIG.pxInt(6)
@@ -56,89 +55,89 @@ class GuiItemDetails(QWidget):
         mPx = CONFIG.pxInt(6)
         fPt = SHARED.theme.fontPointSize
 
-        fntLabel = QFont()
+        fntLabel = self.font()
         fntLabel.setBold(True)
         fntLabel.setPointSizeF(0.9*fPt)
 
-        fntValue = QFont()
+        fntValue = self.font()
         fntValue.setPointSizeF(0.9*fPt)
 
         # Label
-        self.labelName = QLabel(self.tr("Label"))
+        self.labelName = QLabel(self.tr("Label"), self)
         self.labelName.setFont(fntLabel)
-        self.labelName.setAlignment(Qt.AlignLeft | Qt.AlignBaseline)
+        self.labelName.setAlignment(QtAlignLeftBase)
 
-        self.labelIcon = QLabel("")
-        self.labelIcon.setAlignment(Qt.AlignRight | Qt.AlignBaseline)
+        self.labelIcon = QLabel("", self)
+        self.labelIcon.setAlignment(QtAlignRightBase)
 
-        self.labelData = QLabel("")
+        self.labelData = QLabel("", self)
         self.labelData.setFont(fntValue)
-        self.labelData.setAlignment(Qt.AlignLeft | Qt.AlignBaseline)
+        self.labelData.setAlignment(QtAlignLeftBase)
         self.labelData.setWordWrap(True)
 
         # Status
-        self.statusName = QLabel(self.tr("Status"))
+        self.statusName = QLabel(self.tr("Status"), self)
         self.statusName.setFont(fntLabel)
-        self.statusName.setAlignment(Qt.AlignLeft)
+        self.statusName.setAlignment(QtAlignLeft)
 
-        self.statusIcon = QLabel("")
-        self.statusIcon.setAlignment(Qt.AlignRight | Qt.AlignVCenter)
+        self.statusIcon = QLabel("", self)
+        self.statusIcon.setAlignment(QtAlignRightMiddle)
 
-        self.statusData = QLabel("")
+        self.statusData = QLabel("", self)
         self.statusData.setFont(fntValue)
-        self.statusData.setAlignment(Qt.AlignLeft)
+        self.statusData.setAlignment(QtAlignLeft)
 
         # Class
-        self.className = QLabel(self.tr("Class"))
+        self.className = QLabel(self.tr("Class"), self)
         self.className.setFont(fntLabel)
-        self.className.setAlignment(Qt.AlignLeft)
+        self.className.setAlignment(QtAlignLeft)
 
-        self.classIcon = QLabel("")
-        self.classIcon.setAlignment(Qt.AlignRight | Qt.AlignVCenter)
+        self.classIcon = QLabel("", self)
+        self.classIcon.setAlignment(QtAlignRightMiddle)
 
-        self.classData = QLabel("")
+        self.classData = QLabel("", self)
         self.classData.setFont(fntValue)
-        self.classData.setAlignment(Qt.AlignLeft)
+        self.classData.setAlignment(QtAlignLeft)
 
         # Layout
-        self.usageName = QLabel(self.tr("Usage"))
+        self.usageName = QLabel(self.tr("Usage"), self)
         self.usageName.setFont(fntLabel)
-        self.usageName.setAlignment(Qt.AlignLeft)
+        self.usageName.setAlignment(QtAlignLeft)
 
-        self.usageIcon = QLabel("")
-        self.usageIcon.setAlignment(Qt.AlignRight | Qt.AlignVCenter)
+        self.usageIcon = QLabel("", self)
+        self.usageIcon.setAlignment(QtAlignRightMiddle)
 
-        self.usageData = QLabel("")
+        self.usageData = QLabel("", self)
         self.usageData.setFont(fntValue)
-        self.usageData.setAlignment(Qt.AlignLeft)
+        self.usageData.setAlignment(QtAlignLeft)
         self.usageData.setWordWrap(True)
 
         # Character Count
-        self.cCountName = QLabel("  "+self.tr("Characters"))
+        self.cCountName = QLabel("  "+self.tr("Characters"), self)
         self.cCountName.setFont(fntLabel)
-        self.cCountName.setAlignment(Qt.AlignRight)
+        self.cCountName.setAlignment(QtAlignRight)
 
-        self.cCountData = QLabel("")
+        self.cCountData = QLabel("", self)
         self.cCountData.setFont(fntValue)
-        self.cCountData.setAlignment(Qt.AlignRight)
+        self.cCountData.setAlignment(QtAlignRight)
 
         # Word Count
-        self.wCountName = QLabel("  "+self.tr("Words"))
+        self.wCountName = QLabel("  "+self.tr("Words"), self)
         self.wCountName.setFont(fntLabel)
-        self.wCountName.setAlignment(Qt.AlignRight)
+        self.wCountName.setAlignment(QtAlignRight)
 
-        self.wCountData = QLabel("")
+        self.wCountData = QLabel("", self)
         self.wCountData.setFont(fntValue)
-        self.wCountData.setAlignment(Qt.AlignRight)
+        self.wCountData.setAlignment(QtAlignRight)
 
         # Paragraph Count
-        self.pCountName = QLabel("  "+self.tr("Paragraphs"))
+        self.pCountName = QLabel("  "+self.tr("Paragraphs"), self)
         self.pCountName.setFont(fntLabel)
-        self.pCountName.setAlignment(Qt.AlignRight)
+        self.pCountName.setAlignment(QtAlignRight)
 
-        self.pCountData = QLabel("")
+        self.pCountData = QLabel("", self)
         self.pCountData.setFont(fntValue)
-        self.pCountData.setAlignment(Qt.AlignRight)
+        self.pCountData.setAlignment(QtAlignRight)
 
         # Assemble
         self.mainBox = QGridLayout(self)
@@ -194,7 +193,7 @@ class GuiItemDetails(QWidget):
 
     def clearDetails(self) -> None:
         """Clear all the data values."""
-        self._itemHandle = None
+        self._handle = None
         self.labelIcon.clear()
         self.labelData.clear()
         self.statusIcon.clear()
@@ -210,11 +209,11 @@ class GuiItemDetails(QWidget):
 
     def refreshDetails(self) -> None:
         """Reload the content of the details panel."""
-        self.updateViewBox(self._itemHandle)
+        self.updateViewBox(self._handle)
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        self.updateViewBox(self._itemHandle)
+        self.updateViewBox(self._handle)
         return
 
     ##
@@ -233,16 +232,12 @@ class GuiItemDetails(QWidget):
             self.clearDetails()
             return
 
-        self._itemHandle = tHandle
-        iPx = int(round(0.8*SHARED.theme.baseIconSize))
+        self._handle = tHandle
+        iPx = int(round(0.9*SHARED.theme.baseIconHeight))
 
         # Label
         # =====
 
-        theLabel = nwItem.itemName
-        if len(theLabel) > 100:
-            theLabel = theLabel[:96].rstrip()+" ..."
-
         if nwItem.isFileType():
             if nwItem.isActive:
                 self.labelIcon.setPixmap(SHARED.theme.getPixmap("checked", (iPx, iPx)))
@@ -251,14 +246,14 @@ class GuiItemDetails(QWidget):
         else:
             self.labelIcon.setPixmap(SHARED.theme.getPixmap("noncheckable", (iPx, iPx)))
 
-        self.labelData.setText(theLabel)
+        self.labelData.setText(elide(nwItem.itemName, 100))
 
         # Status
         # ======
 
-        theStatus, theIcon = nwItem.getImportStatus(incIcon=True)
-        self.statusIcon.setPixmap(theIcon.pixmap(iPx, iPx))
-        self.statusData.setText(theStatus)
+        status, icon = nwItem.getImportStatus()
+        self.statusIcon.setPixmap(icon.pixmap(iPx, iPx))
+        self.statusData.setText(status)
 
         # Class
         # =====
@@ -295,10 +290,8 @@ class GuiItemDetails(QWidget):
         """Update the counts if the handle is the same as the one we're
         already showing. Otherwise, do nothing.
         """
-        if tHandle == self._itemHandle:
+        if tHandle == self._handle:
             self.cCountData.setText(f"{cC:n}")
             self.wCountData.setText(f"{wC:n}")
             self.pCountData.setText(f"{pC:n}")
         return
-
-# END Class GuiItemDetails
