@@ -25,17 +25,17 @@ from __future__ import annotations
 
 import logging
 
-from typing import TYPE_CHECKING
 from pathlib import Path
+from typing import TYPE_CHECKING
 
-from PyQt5.QtGui import QDesktopServices
 from PyQt5.QtCore import QUrl, pyqtSignal, pyqtSlot
-from PyQt5.QtWidgets import QMenuBar, QAction
+from PyQt5.QtGui import QDesktopServices
+from PyQt5.QtWidgets import QAction, QMenuBar
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.enum import nwDocAction, nwDocInsert, nwWidget
 from novelwriter.common import openExternalPath
-from novelwriter.constants import nwConst, trConst, nwKeyWords, nwLabels, nwUnicode
+from novelwriter.constants import nwConst, nwKeyWords, nwLabels, nwUnicode, trConst
+from novelwriter.enum import nwDocAction, nwDocInsert, nwFocus, nwView
 from novelwriter.extensions.eventfilters import StatusTipFilter
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -54,7 +54,8 @@ class GuiMainMenu(QMenuBar):
     requestDocInsert = pyqtSignal(nwDocInsert)
     requestDocInsertText = pyqtSignal(str)
     requestDocKeyWordInsert = pyqtSignal(str)
-    requestFocusChange = pyqtSignal(nwWidget)
+    requestFocusChange = pyqtSignal(nwFocus)
+    requestViewChange = pyqtSignal(nwView)
 
     def __init__(self, mainGui: GuiMain) -> None:
         super().__init__(parent=mainGui)
@@ -132,14 +133,10 @@ class GuiMainMenu(QMenuBar):
         # Project
         self.projMenu = self.addMenu(self.tr("&Project"))
 
-        # Project > New Project
-        self.aNewProject = self.projMenu.addAction(self.tr("New Project"))
-        self.aNewProject.triggered.connect(lambda: self.mainGui.newProject(None))
-
-        # Project > Open Project
-        self.aOpenProject = self.projMenu.addAction(self.tr("Open Project"))
+        # Project > Create or Open Project
+        self.aOpenProject = self.projMenu.addAction(self.tr("Create or Open Project"))
         self.aOpenProject.setShortcut("Ctrl+Shift+O")
-        self.aOpenProject.triggered.connect(lambda: self.mainGui.showProjectLoadDialog())
+        self.aOpenProject.triggered.connect(self.mainGui.showWelcomeDialog)
 
         # Project > Save Project
         self.aSaveProject = self.projMenu.addAction(self.tr("Save Project"))
@@ -159,10 +156,10 @@ class GuiMainMenu(QMenuBar):
         self.aProjectSettings.setShortcut("Ctrl+Shift+,")
         self.aProjectSettings.triggered.connect(self.mainGui.showProjectSettingsDialog)
 
-        # Project > Project Details
-        self.aProjectDetails = self.projMenu.addAction(self.tr("Project Details"))
-        self.aProjectDetails.setShortcut("Shift+F6")
-        self.aProjectDetails.triggered.connect(self.mainGui.showProjectDetailsDialog)
+        # Project > Novel Details
+        self.aNovelDetails = self.projMenu.addAction(self.tr("Novel Details"))
+        self.aNovelDetails.setShortcut("Shift+F6")
+        self.aNovelDetails.triggered.connect(self.mainGui.showNovelDetailsDialog)
 
         # Project > Separator
         self.projMenu.addSeparator()
@@ -170,7 +167,7 @@ class GuiMainMenu(QMenuBar):
         # Project > Edit
         self.aEditItem = self.projMenu.addAction(self.tr("Rename Item"))
         self.aEditItem.setShortcut("F2")
-        self.aEditItem.triggered.connect(lambda: self.mainGui.editItemLabel(None))
+        self.aEditItem.triggered.connect(lambda: self.mainGui.projView.renameTreeItem(None))
 
         # Project > Delete
         self.aDeleteItem = self.projMenu.addAction(self.tr("Delete Item"))
@@ -200,12 +197,12 @@ class GuiMainMenu(QMenuBar):
         # Document > Open
         self.aOpenDoc = self.docuMenu.addAction(self.tr("Open Document"))
         self.aOpenDoc.setShortcut("Ctrl+O")
-        self.aOpenDoc.triggered.connect(lambda: self.mainGui.openSelectedItem())
+        self.aOpenDoc.triggered.connect(self.mainGui.openSelectedItem)
 
         # Document > Save
         self.aSaveDoc = self.docuMenu.addAction(self.tr("Save Document"))
         self.aSaveDoc.setShortcut("Ctrl+S")
-        self.aSaveDoc.triggered.connect(lambda: self.mainGui.saveDocument())
+        self.aSaveDoc.triggered.connect(self.mainGui.forceSaveDocument)
 
         # Document > Close
         self.aCloseDoc = self.docuMenu.addAction(self.tr("Close Document"))
@@ -223,7 +220,7 @@ class GuiMainMenu(QMenuBar):
         # Document > Close Preview
         self.aCloseView = self.docuMenu.addAction(self.tr("Close Document View"))
         self.aCloseView.setShortcut("Ctrl+Shift+R")
-        self.aCloseView.triggered.connect(lambda: self.mainGui.closeDocViewer())
+        self.aCloseView.triggered.connect(self.mainGui.closeDocViewer)
 
         # Document > Separator
         self.docuMenu.addSeparator()
@@ -234,7 +231,6 @@ class GuiMainMenu(QMenuBar):
 
         # Document > Import From File
         self.aImportFile = self.docuMenu.addAction(self.tr("Import Text from File"))
-        self.aImportFile.setShortcut("Ctrl+Shift+I")
         self.aImportFile.triggered.connect(lambda: self.mainGui.importDocument())
 
         return
@@ -307,24 +303,24 @@ class GuiMainMenu(QMenuBar):
         self.viewMenu = self.addMenu(self.tr("&View"))
 
         # View > TreeView
-        self.aFocusTree = self.viewMenu.addAction(self.tr("Go to Project Tree"))
+        self.aFocusTree = self.viewMenu.addAction(self.tr("Go to Tree View"))
         self.aFocusTree.setShortcut("Ctrl+T")
         self.aFocusTree.triggered.connect(
-            lambda: self.requestFocusChange.emit(nwWidget.TREE)
+            lambda: self.requestFocusChange.emit(nwFocus.TREE)
         )
 
         # View > Document Editor
-        self.aFocusEditor = self.viewMenu.addAction(self.tr("Go to Document Editor"))
-        self.aFocusEditor.setShortcut("Ctrl+E")
-        self.aFocusEditor.triggered.connect(
-            lambda: self.requestFocusChange.emit(nwWidget.EDITOR)
+        self.aFocusDocument = self.viewMenu.addAction(self.tr("Go to Document"))
+        self.aFocusDocument.setShortcut("Ctrl+E")
+        self.aFocusDocument.triggered.connect(
+            lambda: self.requestFocusChange.emit(nwFocus.DOCUMENT)
         )
 
         # View > Outline
         self.aFocusOutline = self.viewMenu.addAction(self.tr("Go to Outline"))
         self.aFocusOutline.setShortcut("Ctrl+Shift+T")
         self.aFocusOutline.triggered.connect(
-            lambda: self.requestFocusChange.emit(nwWidget.OUTLINE)
+            lambda: self.requestFocusChange.emit(nwFocus.OUTLINE)
         )
 
         # View > Separator
@@ -426,7 +422,7 @@ class GuiMainMenu(QMenuBar):
         self.aInsMSApos = self.mInsQuotes.addAction(self.tr("Alternative Apostrophe"))
         self.aInsMSApos.setShortcut("Ctrl+K, '")
         self.aInsMSApos.triggered.connect(
-            lambda: self.requestDocInsertText.emit(nwUnicode.U_MAPOSS)
+            lambda: self.requestDocInsertText.emit(nwUnicode.U_MAPOS)
         )
 
         # Insert > Symbols
@@ -601,6 +597,12 @@ class GuiMainMenu(QMenuBar):
             lambda: self.requestDocInsert.emit(nwDocInsert.LIPSUM)
         )
 
+        # Insert > Footnote
+        self.aFootnote = self.insMenu.addAction(self.tr("Footnote"))
+        self.aFootnote.triggered.connect(
+            lambda: self.requestDocInsert.emit(nwDocInsert.FOOTNOTE)
+        )
+
         return
 
     def _buildFormatMenu(self) -> None:
@@ -676,6 +678,12 @@ class GuiMainMenu(QMenuBar):
             lambda: self.requestDocAction.emit(nwDocAction.SC_ULINE)
         )
 
+        # Shortcode Mark
+        self.aScMark = self.mShortcodes.addAction(self.tr("Highlight"))
+        self.aScMark.triggered.connect(
+            lambda: self.requestDocAction.emit(nwDocAction.SC_MARK)
+        )
+
         # Shortcode Superscript
         self.aScSuper = self.mShortcodes.addAction(self.tr("Superscript"))
         self.aScSuper.triggered.connect(
@@ -691,29 +699,29 @@ class GuiMainMenu(QMenuBar):
         # Format > Separator
         self.fmtMenu.addSeparator()
 
-        # Format > Header 1 (Partition)
-        self.aFmtHead1 = self.fmtMenu.addAction(self.tr("Header 1 (Partition)"))
+        # Format > Heading 1 (Partition)
+        self.aFmtHead1 = self.fmtMenu.addAction(self.tr("Heading 1 (Partition)"))
         self.aFmtHead1.setShortcut("Ctrl+1")
         self.aFmtHead1.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_H1)
         )
 
-        # Format > Header 2 (Chapter)
-        self.aFmtHead2 = self.fmtMenu.addAction(self.tr("Header 2 (Chapter)"))
+        # Format > Heading 2 (Chapter)
+        self.aFmtHead2 = self.fmtMenu.addAction(self.tr("Heading 2 (Chapter)"))
         self.aFmtHead2.setShortcut("Ctrl+2")
         self.aFmtHead2.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_H2)
         )
 
-        # Format > Header 3 (Scene)
-        self.aFmtHead3 = self.fmtMenu.addAction(self.tr("Header 3 (Scene)"))
+        # Format > Heading 3 (Scene)
+        self.aFmtHead3 = self.fmtMenu.addAction(self.tr("Heading 3 (Scene)"))
         self.aFmtHead3.setShortcut("Ctrl+3")
         self.aFmtHead3.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_H3)
         )
 
-        # Format > Header 4 (Section)
-        self.aFmtHead4 = self.fmtMenu.addAction(self.tr("Header 4 (Section)"))
+        # Format > Heading 4 (Section)
+        self.aFmtHead4 = self.fmtMenu.addAction(self.tr("Heading 4 (Section)"))
         self.aFmtHead4.setShortcut("Ctrl+4")
         self.aFmtHead4.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_H4)
@@ -734,6 +742,12 @@ class GuiMainMenu(QMenuBar):
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_UNN)
         )
 
+        # Format > Alternative Scene
+        self.aFmtHardSc = self.fmtMenu.addAction(self.tr("Alternative Scene"))
+        self.aFmtHardSc.triggered.connect(
+            lambda: self.requestDocAction.emit(nwDocAction.BLOCK_HSC)
+        )
+
         # Format > Separator
         self.fmtMenu.addSeparator()
 
@@ -785,6 +799,13 @@ class GuiMainMenu(QMenuBar):
             lambda: self.requestDocAction.emit(nwDocAction.BLOCK_COM)
         )
 
+        # Format > Ignore Text
+        self.aFmtIgnore = self.fmtMenu.addAction(self.tr("Toggle Ignore Text"))
+        self.aFmtIgnore.setShortcut("Ctrl+Shift+D")
+        self.aFmtIgnore.triggered.connect(
+            lambda: self.requestDocAction.emit(nwDocAction.BLOCK_IGN)
+        )
+
         # Format > Remove Block Format
         self.aFmtNoFormat = self.fmtMenu.addAction(self.tr("Remove Block Format"))
         self.aFmtNoFormat.setShortcuts(["Ctrl+0", "Ctrl+Shift+/"])
@@ -795,14 +816,14 @@ class GuiMainMenu(QMenuBar):
         # Format > Separator
         self.fmtMenu.addSeparator()
 
-        # Format > Replace Single Quotes
-        self.aFmtReplSng = self.fmtMenu.addAction(self.tr("Convert Single Quotes"))
+        # Format > Replace Straight Single Quotes
+        self.aFmtReplSng = self.fmtMenu.addAction(self.tr("Replace Straight Single Quotes"))
         self.aFmtReplSng.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.REPL_SNG)
         )
 
-        # Format > Replace Double Quotes
-        self.aFmtReplDbl = self.fmtMenu.addAction(self.tr("Convert Double Quotes"))
+        # Format > Replace Straight Double Quotes
+        self.aFmtReplDbl = self.fmtMenu.addAction(self.tr("Replace Straight Double Quotes"))
         self.aFmtReplDbl.triggered.connect(
             lambda: self.requestDocAction.emit(nwDocAction.REPL_DBL)
         )
@@ -847,6 +868,14 @@ class GuiMainMenu(QMenuBar):
         self.aReplaceNext.setShortcut("Ctrl+Shift+1")
         self.aReplaceNext.triggered.connect(lambda: self.mainGui.docEditor.replaceNext())
 
+        # Search > Separator
+        self.srcMenu.addSeparator()
+
+        # Search > Find in Project
+        self.aFindProj = self.srcMenu.addAction(self.tr("Find in Project"))
+        self.aFindProj.setShortcut("Ctrl+Shift+F")
+        self.aFindProj.triggered.connect(lambda: self.requestViewChange.emit(nwView.SEARCH))
+
         return
 
     def _buildToolsMenu(self) -> None:
@@ -961,13 +990,4 @@ class GuiMainMenu(QMenuBar):
         self.aWebsite = self.helpMenu.addAction(self.tr("The novelWriter Website"))
         self.aWebsite.triggered.connect(lambda: self._openWebsite(nwConst.URL_WEB))
 
-        # Help > Separator
-        self.helpMenu.addSeparator()
-
-        # Document > Check for Updates
-        self.aUpdates = self.helpMenu.addAction(self.tr("Check for New Release"))
-        self.aUpdates.triggered.connect(self.mainGui.showUpdatesDialog)
-
         return
-
-# END Class GuiMainMenu
