@@ -29,25 +29,27 @@ import logging
 
 from enum import Enum
 from time import time
-from typing import TYPE_CHECKING
 
+from PyQt5.QtCore import QModelIndex, QPoint, Qt, pyqtSignal, pyqtSlot
 from PyQt5.QtGui import QFocusEvent, QFont, QMouseEvent, QPalette, QResizeEvent
-from PyQt5.QtCore import QModelIndex, QPoint, Qt, QSize, pyqtSlot, pyqtSignal
 from PyQt5.QtWidgets import (
     QAbstractItemView, QActionGroup, QFrame, QHBoxLayout, QHeaderView,
-    QInputDialog, QMenu, QSizePolicy, QToolButton, QToolTip, QTreeWidget,
-    QTreeWidgetItem, QVBoxLayout, QWidget
+    QInputDialog, QMenu, QToolTip, QTreeWidget, QTreeWidgetItem, QVBoxLayout,
+    QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.enum import nwDocMode, nwItemClass, nwOutline
 from novelwriter.common import minmax
 from novelwriter.constants import nwHeaders, nwKeyWords, nwLabels, trConst
 from novelwriter.core.index import IndexHeading
+from novelwriter.enum import nwDocMode, nwItemClass, nwOutline
+from novelwriter.extensions.modified import NIconToolButton
 from novelwriter.extensions.novelselector import NovelSelector
-
-if TYPE_CHECKING:  # pragma: no cover
-    from novelwriter.guimain import GuiMain
+from novelwriter.gui.theme import STYLES_MIN_TOOLBUTTON
+from novelwriter.types import (
+    QtAlignRight, QtDecoration, QtMouseLeft, QtMouseMiddle, QtSizeExpanding,
+    QtUserRole
+)
 
 logger = logging.getLogger(__name__)
 
@@ -59,8 +61,6 @@ class NovelTreeColumn(Enum):
     FOCUS  = 2
     PLOT   = 3
 
-# END Enum NovelTreeColumn
-
 
 class GuiNovelView(QWidget):
 
@@ -68,10 +68,8 @@ class GuiNovelView(QWidget):
     selectedItemChanged = pyqtSignal(str)
     openDocumentRequest = pyqtSignal(str, Enum, str, bool)
 
-    def __init__(self, mainGui: GuiMain) -> None:
-        super().__init__(parent=mainGui)
-
-        self.mainGui = mainGui
+    def __init__(self, parent: QWidget) -> None:
+        super().__init__(parent=parent)
 
         # Build GUI
         self.novelTree = GuiNovelTree(self)
@@ -185,8 +183,6 @@ class GuiNovelView(QWidget):
         self.novelTree.refreshHandle(tHandle)
         return
 
-# END Class GuiNovelView
-
 
 class GuiNovelToolBar(QWidget):
 
@@ -196,9 +192,8 @@ class GuiNovelToolBar(QWidget):
         logger.debug("Create: GuiNovelToolBar")
 
         self.novelView = novelView
-        self.mainGui   = novelView.mainGui
 
-        iPx = SHARED.theme.baseIconSize
+        iSz = SHARED.theme.baseIconSize
         mPx = CONFIG.pxInt(2)
 
         self.setContentsMargins(0, 0, 0, 0)
@@ -207,22 +202,21 @@ class GuiNovelToolBar(QWidget):
         # Novel Selector
         selFont = self.font()
         selFont.setWeight(QFont.Weight.Bold)
-        self.novelPrefix = self.tr("Outline of {0}")
+
         self.novelValue = NovelSelector(self)
         self.novelValue.setFont(selFont)
+        self.novelValue.setListFormat(self.tr("Outline of {0}"))
         self.novelValue.setMinimumWidth(CONFIG.pxInt(150))
-        self.novelValue.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
+        self.novelValue.setSizePolicy(QtSizeExpanding, QtSizeExpanding)
         self.novelValue.novelSelectionChanged.connect(self.setCurrentRoot)
 
-        self.tbNovel = QToolButton(self)
+        self.tbNovel = NIconToolButton(self, iSz)
         self.tbNovel.setToolTip(self.tr("Novel Root"))
-        self.tbNovel.setIconSize(QSize(iPx, iPx))
         self.tbNovel.clicked.connect(self.novelValue.showPopup)
 
         # Refresh Button
-        self.tbRefresh = QToolButton(self)
+        self.tbRefresh = NIconToolButton(self, iSz)
         self.tbRefresh.setToolTip(self.tr("Refresh"))
-        self.tbRefresh.setIconSize(QSize(iPx, iPx))
         self.tbRefresh.clicked.connect(self._refreshNovelTree)
 
         # More Options Menu
@@ -240,11 +234,9 @@ class GuiNovelToolBar(QWidget):
         self.aLastColSize = self.mLastCol.addAction(self.tr("Column Size"))
         self.aLastColSize.triggered.connect(self._selectLastColumnSize)
 
-        self.tbMore = QToolButton(self)
+        self.tbMore = NIconToolButton(self, iSz)
         self.tbMore.setToolTip(self.tr("More Options"))
-        self.tbMore.setIconSize(QSize(iPx, iPx))
         self.tbMore.setMenu(self.mMore)
-        self.tbMore.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
 
         # Assemble
         self.outerBox = QHBoxLayout()
@@ -270,31 +262,25 @@ class GuiNovelToolBar(QWidget):
     def updateTheme(self) -> None:
         """Update theme elements."""
         # Icons
-        self.tbNovel.setIcon(SHARED.theme.getIcon("cls_novel"))
-        self.tbRefresh.setIcon(SHARED.theme.getIcon("refresh"))
-        self.tbMore.setIcon(SHARED.theme.getIcon("menu"))
+        self.tbNovel.setThemeIcon("cls_novel")
+        self.tbRefresh.setThemeIcon("refresh")
+        self.tbMore.setThemeIcon("menu")
 
         qPalette = self.palette()
         qPalette.setBrush(QPalette.ColorRole.Window, qPalette.base())
         self.setPalette(qPalette)
 
         # StyleSheets
-        fadeCol = qPalette.text().color()
-        buttonStyle = (
-            "QToolButton {{padding: {0}px; border: none; background: transparent;}} "
-            "QToolButton:hover {{border: none; background: rgba({1},{2},{3},0.2);}}"
-        ).format(CONFIG.pxInt(2), fadeCol.red(), fadeCol.green(), fadeCol.blue())
-        buttonStyleMenu = f"{buttonStyle} QToolButton::menu-indicator {{image: none;}}"
-
+        buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
         self.tbNovel.setStyleSheet(buttonStyle)
         self.tbRefresh.setStyleSheet(buttonStyle)
-        self.tbMore.setStyleSheet(buttonStyleMenu)
+        self.tbMore.setStyleSheet(buttonStyle)
 
         self.novelValue.setStyleSheet(
             "QComboBox {border-style: none; padding-left: 0;} "
             "QComboBox::drop-down {border-style: none}"
         )
-        self.novelValue.updateList(prefix=self.novelPrefix)
+        self.novelValue.refreshNovelList()
         self.tbNovel.setVisible(self.novelValue.count() > 1)
 
         return
@@ -307,7 +293,7 @@ class GuiNovelToolBar(QWidget):
 
     def buildNovelRootMenu(self) -> None:
         """Build the novel root menu."""
-        self.novelValue.updateList(prefix=self.novelPrefix)
+        self.novelValue.refreshNovelList()
         self.tbNovel.setVisible(self.novelValue.count() > 1)
         return
 
@@ -350,7 +336,7 @@ class GuiNovelToolBar(QWidget):
     #  Internal Functions
     ##
 
-    def _addLastColAction(self, colType, actionLabel) -> None:
+    def _addLastColAction(self, colType: NovelTreeColumn, actionLabel: str) -> None:
         """Add a column selection entry to the last column menu."""
         aLast = self.mLastCol.addAction(actionLabel)
         aLast.setCheckable(True)
@@ -359,8 +345,6 @@ class GuiNovelToolBar(QWidget):
         self.aLastCol[colType] = aLast
         return
 
-# END Class GuiNovelToolBar
-
 
 class GuiNovelTree(QTreeWidget):
 
@@ -370,10 +354,10 @@ class GuiNovelTree(QTreeWidget):
     C_EXTRA = 2
     C_MORE  = 3
 
-    D_HANDLE = Qt.ItemDataRole.UserRole
-    D_TITLE  = Qt.ItemDataRole.UserRole + 1
-    D_KEY    = Qt.ItemDataRole.UserRole + 2
-    D_EXTRA  = Qt.ItemDataRole.UserRole + 3
+    D_HANDLE = QtUserRole
+    D_TITLE  = QtUserRole + 1
+    D_KEY    = QtUserRole + 2
+    D_EXTRA  = QtUserRole + 3
 
     def __init__(self, novelView: GuiNovelView) -> None:
         super().__init__(parent=novelView)
@@ -381,7 +365,6 @@ class GuiNovelTree(QTreeWidget):
         logger.debug("Create: GuiNovelTree")
 
         self.novelView = novelView
-        self.mainGui   = novelView.mainGui
 
         # Internal Variables
         self._treeMap     = {}
@@ -398,10 +381,11 @@ class GuiNovelTree(QTreeWidget):
         # Build GUI
         # =========
 
-        iPx = SHARED.theme.baseIconSize
+        iPx = SHARED.theme.baseIconHeight
+        iSz = SHARED.theme.baseIconSize
         cMg = CONFIG.pxInt(6)
 
-        self.setIconSize(QSize(iPx, iPx))
+        self.setIconSize(iSz)
         self.setFrameStyle(QFrame.Shape.NoFrame)
         self.setUniformRowHeights(True)
         self.setAllColumnsShowFocus(True)
@@ -462,7 +446,7 @@ class GuiNovelTree(QTreeWidget):
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        iPx = SHARED.theme.baseIconSize
+        iPx = SHARED.theme.baseIconHeight
         self._pMore = SHARED.theme.loadDecoration("deco_doc_more", h=iPx)
         return
 
@@ -495,7 +479,7 @@ class GuiNovelTree(QTreeWidget):
         if rootHandle is None:
             rootHandle = SHARED.project.tree.findRoot(nwItemClass.NOVEL)
 
-        treeChanged = self.mainGui.projView.changedSince(self._lastBuild)
+        treeChanged = SHARED.mainGui.projView.changedSince(self._lastBuild)
         indexChanged = SHARED.project.index.rootChangedSince(rootHandle, self._lastBuild)
         if not (treeChanged or indexChanged or overRide):
             logger.debug("No changes have been made to the novel index")
@@ -588,12 +572,12 @@ class GuiNovelTree(QTreeWidget):
         """
         super().mousePressEvent(event)
 
-        if event.button() == Qt.MouseButton.LeftButton:
+        if event.button() == QtMouseLeft:
             selItem = self.indexAt(event.pos())
             if not selItem.isValid():
                 self.clearSelection()
 
-        elif event.button() == Qt.MouseButton.MiddleButton:
+        elif event.button() == QtMouseMiddle:
             selItem = self.itemAt(event.pos())
             if not isinstance(selItem, QTreeWidgetItem):
                 return
@@ -674,7 +658,7 @@ class GuiNovelTree(QTreeWidget):
         tStart = time()
         logger.debug("Building novel tree for root item '%s'", rootHandle)
 
-        novStruct = SHARED.project.index.novelStructure(rootHandle=rootHandle, skipExcl=True)
+        novStruct = SHARED.project.index.novelStructure(rootHandle=rootHandle, activeOnly=True)
         for tKey, tHandle, sTitle, novIdx in novStruct:
             if novIdx.level == "H0":
                 continue
@@ -683,7 +667,7 @@ class GuiNovelTree(QTreeWidget):
             newItem.setData(self.C_DATA, self.D_HANDLE, tHandle)
             newItem.setData(self.C_DATA, self.D_TITLE, sTitle)
             newItem.setData(self.C_DATA, self.D_KEY, tKey)
-            newItem.setTextAlignment(self.C_WORDS, Qt.AlignmentFlag.AlignRight)
+            newItem.setTextAlignment(self.C_WORDS, QtAlignRight)
 
             self._updateTreeItemValues(newItem, novIdx, tHandle, sTitle)
             self._treeMap[tKey] = newItem
@@ -702,11 +686,11 @@ class GuiNovelTree(QTreeWidget):
         iLevel = nwHeaders.H_LEVEL.get(idxItem.level, 0)
         hDec = SHARED.theme.getHeaderDecoration(iLevel)
 
-        trItem.setData(self.C_TITLE, Qt.ItemDataRole.DecorationRole, hDec)
+        trItem.setData(self.C_TITLE, QtDecoration, hDec)
         trItem.setText(self.C_TITLE, idxItem.title)
         trItem.setFont(self.C_TITLE, self._hFonts[iLevel])
         trItem.setText(self.C_WORDS, f"{idxItem.wordCount:n}")
-        trItem.setData(self.C_MORE, Qt.ItemDataRole.DecorationRole, self._pMore)
+        trItem.setData(self.C_MORE, QtDecoration, self._pMore)
 
         # Custom column
         mW = int(self._lastColSize * self.viewport().width())
@@ -725,17 +709,17 @@ class GuiNovelTree(QTreeWidget):
 
         refData = []
         refName = ""
-        theRefs = SHARED.project.index.getReferences(tHandle, sTitle)
+        refs = SHARED.project.index.getReferences(tHandle, sTitle)
         if self._lastCol == NovelTreeColumn.POV:
-            refData = theRefs[nwKeyWords.POV_KEY]
+            refData = refs[nwKeyWords.POV_KEY]
             refName = self._povLabel
 
         elif self._lastCol == NovelTreeColumn.FOCUS:
-            refData = theRefs[nwKeyWords.FOCUS_KEY]
+            refData = refs[nwKeyWords.FOCUS_KEY]
             refName = self._focLabel
 
         elif self._lastCol == NovelTreeColumn.PLOT:
-            refData = theRefs[nwKeyWords.PLOT_KEY]
+            refData = refs[nwKeyWords.PLOT_KEY]
             refName = self._pltLabel
 
         if refData:
@@ -749,7 +733,7 @@ class GuiNovelTree(QTreeWidget):
         logger.debug("Generating meta data tooltip for '%s:%s'", tHandle, sTitle)
 
         pIndex = SHARED.project.index
-        novIdx = pIndex.getItemHeader(tHandle, sTitle)
+        novIdx = pIndex.getItemHeading(tHandle, sTitle)
         refTags = pIndex.getReferences(tHandle, sTitle)
         if not novIdx:
             return
@@ -788,5 +772,3 @@ class GuiNovelTree(QTreeWidget):
         if tags:
             lines.append(f"<b>{trConst(nwLabels.KEY_NAME[key])}</b>: {tags}")
         return lines
-
-# END Class GuiNovelTree
