@@ -27,29 +27,30 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
+import csv
 import logging
 
-from time import time
 from enum import Enum
+from time import time
 
-from PyQt5.QtCore import (
-    Qt, pyqtSignal, pyqtSlot, QSize, QT_TRANSLATE_NOOP
-)
+from PyQt5.QtCore import QT_TRANSLATE_NOOP, Qt, pyqtSignal, pyqtSlot
 from PyQt5.QtWidgets import (
-    QAbstractItemView, QAction, QFrame, QGridLayout, QGroupBox, QHBoxLayout,
-    QLabel, QMenu, QScrollArea, QSizePolicy, QSplitter, QToolBar, QToolButton,
+    QAbstractItemView, QAction, QFileDialog, QFrame, QGridLayout, QGroupBox,
+    QHBoxLayout, QLabel, QMenu, QScrollArea, QSplitter, QToolBar, QToolButton,
     QTreeWidget, QTreeWidgetItem, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.enum import (
-    nwDocMode, nwItemClass, nwItemLayout, nwItemType, nwOutline
-)
+from novelwriter.common import checkInt, formatFileFilter, makeFileNameSafe
+from novelwriter.constants import nwHeaders, nwKeyWords, nwLabels, trConst
+from novelwriter.enum import nwDocMode, nwItemClass, nwItemLayout, nwItemType, nwOutline
 from novelwriter.error import logException
-from novelwriter.common import checkInt
-from novelwriter.constants import nwHeaders, trConst, nwKeyWords, nwLabels
+from novelwriter.extensions.configlayout import NColourLabel
 from novelwriter.extensions.novelselector import NovelSelector
-
+from novelwriter.types import (
+    QtAlignLeftTop, QtAlignRight, QtAlignRightTop, QtDecoration,
+    QtSizeExpanding, QtUserRole
+)
 
 logger = logging.getLogger(__name__)
 
@@ -68,7 +69,7 @@ class GuiOutlineView(QWidget):
         self.outlineBar = GuiOutlineToolBar(self)
         self.outlineBar.setEnabled(False)
 
-        self.splitOutline = QSplitter(Qt.Vertical)
+        self.splitOutline = QSplitter(Qt.Orientation.Vertical, self)
         self.splitOutline.addWidget(self.outlineTree)
         self.splitOutline.addWidget(self.outlineData)
         self.splitOutline.setOpaqueResize(False)
@@ -88,6 +89,7 @@ class GuiOutlineView(QWidget):
         self.outlineData.itemTagClicked.connect(self._tagClicked)
         self.outlineBar.loadNovelRootRequest.connect(self._rootItemChanged)
         self.outlineBar.viewColumnToggled.connect(self.outlineTree.menuColumnToggled)
+        self.outlineBar.outlineExportRequest.connect(self.outlineTree.exportOutline)
 
         # Function Mappings
         self.getSelectedHandle = self.outlineTree.getSelectedHandle
@@ -124,7 +126,7 @@ class GuiOutlineView(QWidget):
     def openProjectTasks(self) -> None:
         """Run open project tasks."""
         lastOutline = SHARED.project.data.getLastHandle("outline")
-        if not (lastOutline is None or lastOutline in SHARED.project.tree):
+        if not lastOutline or lastOutline not in SHARED.project.tree:
             lastOutline = SHARED.project.tree.findRoot(nwItemClass.NOVEL)
 
         logger.debug("Setting outline tree to root item '%s'", lastOutline)
@@ -187,17 +189,16 @@ class GuiOutlineView(QWidget):
         return
 
     @pyqtSlot(str)
-    def _rootItemChanged(self, tHandle) -> None:
+    def _rootItemChanged(self, tHandle: str) -> None:
         """Handle root novel changed or needs to be refreshed."""
         self.outlineTree.refreshTree(rootHandle=(tHandle or None), overRide=True)
         return
 
-# END Class GuiOutlineView
-
 
 class GuiOutlineToolBar(QToolBar):
 
     loadNovelRootRequest = pyqtSignal(str)
+    outlineExportRequest = pyqtSignal()
     viewColumnToggled = pyqtSignal(bool, Enum)
 
     def __init__(self, outlineView: GuiOutlineView) -> None:
@@ -205,21 +206,21 @@ class GuiOutlineToolBar(QToolBar):
 
         logger.debug("Create: GuiOutlineToolBar")
 
-        iPx = CONFIG.pxInt(22)
-        mPx = CONFIG.pxInt(12)
-
         self.setMovable(False)
-        self.setIconSize(QSize(iPx, iPx))
+        self.setIconSize(1.4*SHARED.theme.baseIconSize)
         self.setContentsMargins(0, 0, 0, 0)
 
         stretch = QWidget(self)
-        stretch.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
+        stretch.setSizePolicy(QtSizeExpanding, QtSizeExpanding)
 
         # Novel Selector
-        self.novelLabel = QLabel(self.tr("Outline of"))
-        self.novelLabel.setContentsMargins(0, 0, mPx, 0)
+        self.novelLabel = NColourLabel(
+            self.tr("Outline of"), self, scale=NColourLabel.HEADER_SCALE, bold=True
+        )
+        self.novelLabel.setContentsMargins(0, 0, CONFIG.pxInt(12), 0)
 
         self.novelValue = NovelSelector(self)
+        self.novelValue.setIncludeAll(True)
         self.novelValue.setMinimumWidth(CONFIG.pxInt(200))
         self.novelValue.novelSelectionChanged.connect(self._novelValueChanged)
 
@@ -227,6 +228,9 @@ class GuiOutlineToolBar(QToolBar):
         self.aRefresh = QAction(self.tr("Refresh"), self)
         self.aRefresh.triggered.connect(self._refreshRequested)
 
+        self.aExport = QAction(self.tr("Export CSV"), self)
+        self.aExport.triggered.connect(self._exportRequested)
+
         # Column Menu
         self.mColumns = GuiOutlineHeaderMenu(self)
         self.mColumns.columnToggled.connect(
@@ -242,6 +246,7 @@ class GuiOutlineToolBar(QToolBar):
         self.addWidget(self.novelValue)
         self.addSeparator()
         self.addAction(self.aRefresh)
+        self.addAction(self.aExport)
         self.addWidget(self.tbColumns)
         self.addWidget(stretch)
 
@@ -258,15 +263,17 @@ class GuiOutlineToolBar(QToolBar):
     def updateTheme(self) -> None:
         """Update theme elements."""
         self.setStyleSheet("QToolBar {border: 0px;}")
-        self.novelValue.updateList(includeAll=True)
+        self.novelValue.refreshNovelList()
         self.aRefresh.setIcon(SHARED.theme.getIcon("refresh"))
+        self.aExport.setIcon(SHARED.theme.getIcon("export"))
         self.tbColumns.setIcon(SHARED.theme.getIcon("menu"))
         self.tbColumns.setStyleSheet("QToolButton::menu-indicator {image: none;}")
+        self.novelLabel.setTextColors(color=self.palette().windowText().color())
         return
 
     def populateNovelList(self) -> None:
         """Reload the content of the novel list."""
-        self.novelValue.updateList(includeAll=True)
+        self.novelValue.refreshNovelList()
         return
 
     def setCurrentRoot(self, rootHandle: str | None) -> None:
@@ -295,7 +302,11 @@ class GuiOutlineToolBar(QToolBar):
         self.loadNovelRootRequest.emit(self.novelValue.handle)
         return
 
-# END Class GuiOutlineToolBar
+    @pyqtSlot()
+    def _exportRequested(self) -> None:
+        """Emit a signal that an export of the outline was requested."""
+        self.outlineExportRequest.emit()
+        return
 
 
 class GuiOutlineTree(QTreeWidget):
@@ -340,8 +351,8 @@ class GuiOutlineTree(QTreeWidget):
         nwOutline.SYNOP:  False,
     }
 
-    D_HANDLE = Qt.ItemDataRole.UserRole
-    D_TITLE  = Qt.ItemDataRole.UserRole + 1
+    D_HANDLE = QtUserRole
+    D_TITLE  = QtUserRole + 1
 
     hiddenStateChanged = pyqtSignal()
     activeItemChanged = pyqtSignal(str, str)
@@ -362,8 +373,7 @@ class GuiOutlineTree(QTreeWidget):
         self.itemDoubleClicked.connect(self._treeDoubleClick)
         self.itemSelectionChanged.connect(self._itemSelected)
 
-        iPx = SHARED.theme.baseIconSize
-        self.setIconSize(QSize(iPx, iPx))
+        self.setIconSize(SHARED.theme.baseIconSize)
         self.setIndentation(0)
 
         self.treeHead = self.header()
@@ -413,7 +423,7 @@ class GuiOutlineTree(QTreeWidget):
     ##
 
     @property
-    def hiddenColumns(self):
+    def hiddenColumns(self) -> dict[nwOutline, bool]:
         return self._colHidden
 
     ##
@@ -491,15 +501,48 @@ class GuiOutlineTree(QTreeWidget):
         """Get the currently selected handle. If multiple items are
         selected, return the first.
         """
-        selItem = self.selectedItems()
-        if selItem:
-            tHandle = selItem[0].data(self._colIdx[nwOutline.TITLE], self.D_HANDLE)
-            sTitle = selItem[0].data(self._colIdx[nwOutline.TITLE], self.D_TITLE)
+        if item := self.selectedItems():
+            tHandle = item[0].data(self._colIdx[nwOutline.TITLE], self.D_HANDLE)
+            sTitle = item[0].data(self._colIdx[nwOutline.TITLE], self.D_TITLE)
             return tHandle, sTitle
         return None, None
 
     ##
-    #  Slots
+    #  Public Slots
+    ##
+
+    @pyqtSlot(bool, Enum)
+    def menuColumnToggled(self, isChecked: bool, hItem: nwOutline) -> None:
+        """Receive the changes to column visibility forwarded by the
+        column selection menu.
+        """
+        if hItem in self._colIdx:
+            self.setColumnHidden(self._colIdx[hItem], not isChecked)
+            self._saveHeaderState()
+        return
+
+    @pyqtSlot()
+    def exportOutline(self) -> None:
+        """Export the outline as a CSV file."""
+        path = CONFIG.lastPath("outline") / f"{makeFileNameSafe(SHARED.project.data.name)}.csv"
+        path, _ = QFileDialog.getSaveFileName(
+            self, self.tr("Save Outline As"), str(path), formatFileFilter(["*.csv", "*"])
+        )
+        if path:
+            CONFIG.setLastPath("outline", path)
+            logger.info("Writing CSV file: %s", path)
+            cols = [col for col in self._treeOrder if not self._colHidden[col]]
+            order = [self._colIdx[col] for col in cols]
+            with open(path, mode="w", newline="") as csvFile:
+                writer = csv.writer(csvFile, dialect="excel", quoting=csv.QUOTE_ALL)
+                writer.writerow([trConst(nwLabels.OUTLINE_COLS[col]) for col in cols])
+                for i in range(self.topLevelItemCount()):
+                    if item := self.topLevelItem(i):
+                        writer.writerow(item.text(i) for i in order)
+        return
+
+    ##
+    #  Private Slots
     ##
 
     @pyqtSlot("QTreeWidgetItem*", int)
@@ -509,9 +552,8 @@ class GuiOutlineTree(QTreeWidget):
         document editor.
         """
         tHandle, sTitle = self.getSelectedHandle()
-        if tHandle is None:
-            return
-        self.outlineView.openDocumentRequest.emit(tHandle, nwDocMode.EDIT, sTitle or "", True)
+        if tHandle:
+            self.outlineView.openDocumentRequest.emit(tHandle, nwDocMode.EDIT, sTitle or "", True)
         return
 
     @pyqtSlot()
@@ -535,21 +577,11 @@ class GuiOutlineTree(QTreeWidget):
         self._saveHeaderState()
         return
 
-    @pyqtSlot(bool, Enum)
-    def menuColumnToggled(self, isChecked: bool, hItem: nwOutline) -> None:
-        """Receive the changes to column visibility forwarded by the
-        column selection menu.
-        """
-        if hItem in self._colIdx:
-            self.setColumnHidden(self._colIdx[hItem], not isChecked)
-            self._saveHeaderState()
-        return
-
     ##
     #  Internal Functions
     ##
 
-    def _loadHeaderState(self):
+    def _loadHeaderState(self) -> None:
         """Load the state of the main tree header, that is, column order
         and column width.
         """
@@ -624,12 +656,12 @@ class GuiOutlineTree(QTreeWidget):
         self.clear()
 
         if self._firstView:
-            theLabels = []
+            labels = []
             for i, hItem in enumerate(self._treeOrder):
-                theLabels.append(trConst(nwLabels.OUTLINE_COLS[hItem]))
+                labels.append(trConst(nwLabels.OUTLINE_COLS[hItem]))
                 self._colIdx[hItem] = i
 
-            self.setHeaderLabels(theLabels)
+            self.setHeaderLabels(labels)
             for hItem in self._treeOrder:
                 self.setColumnWidth(self._colIdx[hItem], self._colWidth[hItem])
                 self.setColumnHidden(self._colIdx[hItem], self._colHidden[hItem])
@@ -640,13 +672,13 @@ class GuiOutlineTree(QTreeWidget):
             headItem = self.headerItem()
             if isinstance(headItem, QTreeWidgetItem):
                 headItem.setTextAlignment(
-                    self._colIdx[nwOutline.CCOUNT], Qt.AlignmentFlag.AlignRight)
+                    self._colIdx[nwOutline.CCOUNT], QtAlignRight)
                 headItem.setTextAlignment(
-                    self._colIdx[nwOutline.WCOUNT], Qt.AlignmentFlag.AlignRight)
+                    self._colIdx[nwOutline.WCOUNT], QtAlignRight)
                 headItem.setTextAlignment(
-                    self._colIdx[nwOutline.PCOUNT], Qt.AlignmentFlag.AlignRight)
+                    self._colIdx[nwOutline.PCOUNT], QtAlignRight)
 
-        novStruct = SHARED.project.index.novelStructure(rootHandle=rootHandle, skipExcl=True)
+        novStruct = SHARED.project.index.novelStructure(rootHandle=rootHandle, activeOnly=True)
         for _, tHandle, sTitle, novIdx in novStruct:
 
             iLevel = nwHeaders.H_LEVEL.get(novIdx.level, 0)
@@ -657,7 +689,7 @@ class GuiOutlineTree(QTreeWidget):
             trItem = QTreeWidgetItem()
             hDec = SHARED.theme.getHeaderDecoration(iLevel)
 
-            trItem.setData(self._colIdx[nwOutline.TITLE], Qt.ItemDataRole.DecorationRole, hDec)
+            trItem.setData(self._colIdx[nwOutline.TITLE], QtDecoration, hDec)
             trItem.setText(self._colIdx[nwOutline.TITLE], novIdx.title)
             trItem.setData(self._colIdx[nwOutline.TITLE], self.D_HANDLE, tHandle)
             trItem.setData(self._colIdx[nwOutline.TITLE], self.D_TITLE, sTitle)
@@ -670,9 +702,9 @@ class GuiOutlineTree(QTreeWidget):
             trItem.setText(self._colIdx[nwOutline.CCOUNT], f"{novIdx.charCount:n}")
             trItem.setText(self._colIdx[nwOutline.WCOUNT], f"{novIdx.wordCount:n}")
             trItem.setText(self._colIdx[nwOutline.PCOUNT], f"{novIdx.paraCount:n}")
-            trItem.setTextAlignment(self._colIdx[nwOutline.CCOUNT], Qt.AlignmentFlag.AlignRight)
-            trItem.setTextAlignment(self._colIdx[nwOutline.WCOUNT], Qt.AlignmentFlag.AlignRight)
-            trItem.setTextAlignment(self._colIdx[nwOutline.PCOUNT], Qt.AlignmentFlag.AlignRight)
+            trItem.setTextAlignment(self._colIdx[nwOutline.CCOUNT], QtAlignRight)
+            trItem.setTextAlignment(self._colIdx[nwOutline.WCOUNT], QtAlignRight)
+            trItem.setTextAlignment(self._colIdx[nwOutline.PCOUNT], QtAlignRight)
 
             refs = SHARED.project.index.getReferences(tHandle, sTitle)
             trItem.setText(self._colIdx[nwOutline.POV],    ", ".join(refs[nwKeyWords.POV_KEY]))
@@ -691,8 +723,6 @@ class GuiOutlineTree(QTreeWidget):
 
         return
 
-# END Class GuiOutlineTree
-
 
 class GuiOutlineHeaderMenu(QMenu):
 
@@ -735,8 +765,6 @@ class GuiOutlineHeaderMenu(QMenu):
 
         return
 
-# END Class GuiOutlineHeaderMenu
-
 
 class GuiOutlineDetails(QScrollArea):
 
@@ -763,13 +791,19 @@ class GuiOutlineDetails(QScrollArea):
         hSpace = int(CONFIG.pxInt(10))
         vSpace = int(CONFIG.pxInt(4))
 
+        bFont = SHARED.theme.guiFontB
+
         # Details Area
-        self.titleLabel = QLabel("<b>%s</b>" % self.tr("Title"))
-        self.fileLabel  = QLabel("<b>%s</b>" % self.tr("Document"))
-        self.itemLabel  = QLabel("<b>%s</b>" % self.tr("Status"))
-        self.titleValue = QLabel("")
-        self.fileValue  = QLabel("")
-        self.itemValue  = QLabel("")
+        self.titleLabel = QLabel(self.tr("Title"), self)
+        self.fileLabel  = QLabel(self.tr("Document"), self)
+        self.itemLabel  = QLabel(self.tr("Status"), self)
+        self.titleValue = QLabel("", self)
+        self.fileValue  = QLabel("", self)
+        self.itemValue  = QLabel("", self)
+
+        self.titleLabel.setFont(bFont)
+        self.fileLabel.setFont(bFont)
+        self.itemLabel.setFont(bFont)
 
         self.titleValue.setMinimumWidth(minTitle)
         self.titleValue.setMaximumWidth(maxTitle)
@@ -779,38 +813,55 @@ class GuiOutlineDetails(QScrollArea):
         self.itemValue.setMaximumWidth(maxTitle)
 
         # Stats Area
-        self.cCLabel = QLabel("<b>%s</b>" % self.tr("Characters"))
-        self.wCLabel = QLabel("<b>%s</b>" % self.tr("Words"))
-        self.pCLabel = QLabel("<b>%s</b>" % self.tr("Paragraphs"))
-        self.cCValue = QLabel("")
-        self.wCValue = QLabel("")
-        self.pCValue = QLabel("")
+        self.cCLabel = QLabel(self.tr("Characters"), self)
+        self.wCLabel = QLabel(self.tr("Words"), self)
+        self.pCLabel = QLabel(self.tr("Paragraphs"), self)
+        self.cCValue = QLabel("", self)
+        self.wCValue = QLabel("", self)
+        self.pCValue = QLabel("", self)
+
+        self.cCLabel.setFont(bFont)
+        self.wCLabel.setFont(bFont)
+        self.pCLabel.setFont(bFont)
 
         self.cCValue.setMinimumWidth(wCount)
         self.wCValue.setMinimumWidth(wCount)
         self.pCValue.setMinimumWidth(wCount)
-        self.cCValue.setAlignment(Qt.AlignRight)
-        self.wCValue.setAlignment(Qt.AlignRight)
-        self.pCValue.setAlignment(Qt.AlignRight)
+        self.cCValue.setAlignment(QtAlignRight)
+        self.wCValue.setAlignment(QtAlignRight)
+        self.pCValue.setAlignment(QtAlignRight)
 
         # Synopsis
-        self.synopLabel = QLabel("<b>%s</b>" % self.tr("Synopsis"))
-        self.synopValue = QLabel("")
-        self.synopLWrap = QHBoxLayout()
+        self.synopLabel = QLabel(self.tr("Synopsis"), self)
+        self.synopLabel.setFont(bFont)
+
+        self.synopValue = QLabel("", self)
         self.synopValue.setWordWrap(True)
-        self.synopValue.setAlignment(Qt.AlignTop | Qt.AlignLeft)
+        self.synopValue.setAlignment(QtAlignLeftTop)
+
+        self.synopLWrap = QHBoxLayout()
         self.synopLWrap.addWidget(self.synopValue, 1)
 
         # Tags
-        self.povKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.POV_KEY]))
-        self.focKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.FOCUS_KEY]))
-        self.chrKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.CHAR_KEY]))
-        self.pltKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.PLOT_KEY]))
-        self.timKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.TIME_KEY]))
-        self.wldKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.WORLD_KEY]))
-        self.objKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.OBJECT_KEY]))
-        self.entKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.ENTITY_KEY]))
-        self.cstKeyLabel = QLabel("<b>%s</b>" % trConst(nwLabels.KEY_NAME[nwKeyWords.CUSTOM_KEY]))
+        self.povKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.POV_KEY]), self)
+        self.focKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.FOCUS_KEY]), self)
+        self.chrKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.CHAR_KEY]), self)
+        self.pltKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.PLOT_KEY]), self)
+        self.timKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.TIME_KEY]), self)
+        self.wldKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.WORLD_KEY]), self)
+        self.objKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.OBJECT_KEY]), self)
+        self.entKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.ENTITY_KEY]), self)
+        self.cstKeyLabel = QLabel(trConst(nwLabels.KEY_NAME[nwKeyWords.CUSTOM_KEY]), self)
+
+        self.povKeyLabel.setFont(bFont)
+        self.focKeyLabel.setFont(bFont)
+        self.chrKeyLabel.setFont(bFont)
+        self.pltKeyLabel.setFont(bFont)
+        self.timKeyLabel.setFont(bFont)
+        self.wldKeyLabel.setFont(bFont)
+        self.objKeyLabel.setFont(bFont)
+        self.entKeyLabel.setFont(bFont)
+        self.cstKeyLabel.setFont(bFont)
 
         self.povKeyLWrap = QHBoxLayout()
         self.focKeyLWrap = QHBoxLayout()
@@ -822,15 +873,15 @@ class GuiOutlineDetails(QScrollArea):
         self.entKeyLWrap = QHBoxLayout()
         self.cstKeyLWrap = QHBoxLayout()
 
-        self.povKeyValue = QLabel("")
-        self.focKeyValue = QLabel("")
-        self.chrKeyValue = QLabel("")
-        self.pltKeyValue = QLabel("")
-        self.timKeyValue = QLabel("")
-        self.wldKeyValue = QLabel("")
-        self.objKeyValue = QLabel("")
-        self.entKeyValue = QLabel("")
-        self.cstKeyValue = QLabel("")
+        self.povKeyValue = QLabel("", self)
+        self.focKeyValue = QLabel("", self)
+        self.chrKeyValue = QLabel("", self)
+        self.pltKeyValue = QLabel("", self)
+        self.timKeyValue = QLabel("", self)
+        self.wldKeyValue = QLabel("", self)
+        self.objKeyValue = QLabel("", self)
+        self.entKeyValue = QLabel("", self)
+        self.cstKeyValue = QLabel("", self)
 
         self.povKeyValue.setWordWrap(True)
         self.focKeyValue.setWordWrap(True)
@@ -842,18 +893,15 @@ class GuiOutlineDetails(QScrollArea):
         self.entKeyValue.setWordWrap(True)
         self.cstKeyValue.setWordWrap(True)
 
-        def tagClicked(link):
-            self.itemTagClicked.emit(link)
-
-        self.povKeyValue.linkActivated.connect(tagClicked)
-        self.focKeyValue.linkActivated.connect(tagClicked)
-        self.chrKeyValue.linkActivated.connect(tagClicked)
-        self.pltKeyValue.linkActivated.connect(tagClicked)
-        self.timKeyValue.linkActivated.connect(tagClicked)
-        self.wldKeyValue.linkActivated.connect(tagClicked)
-        self.objKeyValue.linkActivated.connect(tagClicked)
-        self.entKeyValue.linkActivated.connect(tagClicked)
-        self.cstKeyValue.linkActivated.connect(tagClicked)
+        self.povKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
+        self.focKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
+        self.chrKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
+        self.pltKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
+        self.timKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
+        self.wldKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
+        self.objKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
+        self.entKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
+        self.cstKeyValue.linkActivated.connect(lambda x: self.itemTagClicked.emit(x))
 
         self.povKeyLWrap.addWidget(self.povKeyValue, 1)
         self.focKeyLWrap.addWidget(self.focKeyValue, 1)
@@ -870,23 +918,20 @@ class GuiOutlineDetails(QScrollArea):
         self.mainForm = QGridLayout()
         self.mainGroup.setLayout(self.mainForm)
 
-        topLeft = Qt.AlignmentFlag.AlignTop | Qt.AlignmentFlag.AlignLeft
-        topRight = Qt.AlignmentFlag.AlignTop | Qt.AlignmentFlag.AlignRight
-
-        self.mainForm.addWidget(self.titleLabel,  0, 0, 1, 1, topLeft)
-        self.mainForm.addWidget(self.titleValue,  0, 1, 1, 1, topLeft)
-        self.mainForm.addWidget(self.cCLabel,     0, 2, 1, 1, topLeft)
-        self.mainForm.addWidget(self.cCValue,     0, 3, 1, 1, topRight)
-        self.mainForm.addWidget(self.fileLabel,   1, 0, 1, 1, topLeft)
-        self.mainForm.addWidget(self.fileValue,   1, 1, 1, 1, topLeft)
-        self.mainForm.addWidget(self.wCLabel,     1, 2, 1, 1, topLeft)
-        self.mainForm.addWidget(self.wCValue,     1, 3, 1, 1, topRight)
-        self.mainForm.addWidget(self.itemLabel,   2, 0, 1, 1, topLeft)
-        self.mainForm.addWidget(self.itemValue,   2, 1, 1, 1, topLeft)
-        self.mainForm.addWidget(self.pCLabel,     2, 2, 1, 1, topLeft)
-        self.mainForm.addWidget(self.pCValue,     2, 3, 1, 1, topRight)
-        self.mainForm.addWidget(self.synopLabel,  3, 0, 1, 4, topLeft)
-        self.mainForm.addLayout(self.synopLWrap,  4, 0, 1, 4, topLeft)
+        self.mainForm.addWidget(self.titleLabel,  0, 0, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.titleValue,  0, 1, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.cCLabel,     0, 2, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.cCValue,     0, 3, 1, 1, QtAlignRightTop)
+        self.mainForm.addWidget(self.fileLabel,   1, 0, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.fileValue,   1, 1, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.wCLabel,     1, 2, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.wCValue,     1, 3, 1, 1, QtAlignRightTop)
+        self.mainForm.addWidget(self.itemLabel,   2, 0, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.itemValue,   2, 1, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.pCLabel,     2, 2, 1, 1, QtAlignLeftTop)
+        self.mainForm.addWidget(self.pCValue,     2, 3, 1, 1, QtAlignRightTop)
+        self.mainForm.addWidget(self.synopLabel,  3, 0, 1, 4, QtAlignLeftTop)
+        self.mainForm.addLayout(self.synopLWrap,  4, 0, 1, 4, QtAlignLeftTop)
 
         self.mainForm.setColumnStretch(1, 1)
         self.mainForm.setRowStretch(4, 1)
@@ -898,24 +943,24 @@ class GuiOutlineDetails(QScrollArea):
         self.tagsForm = QGridLayout()
         self.tagsGroup.setLayout(self.tagsForm)
 
-        self.tagsForm.addWidget(self.povKeyLabel, 0, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.povKeyLWrap, 0, 1, 1, 1, topLeft)
-        self.tagsForm.addWidget(self.focKeyLabel, 1, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.focKeyLWrap, 1, 1, 1, 1, topLeft)
-        self.tagsForm.addWidget(self.chrKeyLabel, 2, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.chrKeyLWrap, 2, 1, 1, 1, topLeft)
-        self.tagsForm.addWidget(self.pltKeyLabel, 3, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.pltKeyLWrap, 3, 1, 1, 1, topLeft)
-        self.tagsForm.addWidget(self.timKeyLabel, 4, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.timKeyLWrap, 4, 1, 1, 1, topLeft)
-        self.tagsForm.addWidget(self.wldKeyLabel, 5, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.wldKeyLWrap, 5, 1, 1, 1, topLeft)
-        self.tagsForm.addWidget(self.objKeyLabel, 6, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.objKeyLWrap, 6, 1, 1, 1, topLeft)
-        self.tagsForm.addWidget(self.entKeyLabel, 7, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.entKeyLWrap, 7, 1, 1, 1, topLeft)
-        self.tagsForm.addWidget(self.cstKeyLabel, 8, 0, 1, 1, topLeft)
-        self.tagsForm.addLayout(self.cstKeyLWrap, 8, 1, 1, 1, topLeft)
+        self.tagsForm.addWidget(self.povKeyLabel, 0, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.povKeyLWrap, 0, 1, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addWidget(self.focKeyLabel, 1, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.focKeyLWrap, 1, 1, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addWidget(self.chrKeyLabel, 2, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.chrKeyLWrap, 2, 1, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addWidget(self.pltKeyLabel, 3, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.pltKeyLWrap, 3, 1, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addWidget(self.timKeyLabel, 4, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.timKeyLWrap, 4, 1, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addWidget(self.wldKeyLabel, 5, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.wldKeyLWrap, 5, 1, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addWidget(self.objKeyLabel, 6, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.objKeyLWrap, 6, 1, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addWidget(self.entKeyLabel, 7, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.entKeyLWrap, 7, 1, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addWidget(self.cstKeyLabel, 8, 0, 1, 1, QtAlignLeftTop)
+        self.tagsForm.addLayout(self.cstKeyLWrap, 8, 1, 1, 1, QtAlignLeftTop)
 
         self.tagsForm.setColumnStretch(1, 1)
         self.tagsForm.setRowStretch(8, 1)
@@ -923,7 +968,7 @@ class GuiOutlineDetails(QScrollArea):
         self.tagsForm.setVerticalSpacing(vSpace)
 
         # Assemble
-        self.outerWidget = QWidget()
+        self.outerWidget = QWidget(self)
         self.outerBox = QHBoxLayout()
         self.outerBox.addWidget(self.mainGroup, 0)
         self.outerBox.addWidget(self.tagsGroup, 1)
@@ -957,7 +1002,7 @@ class GuiOutlineDetails(QScrollArea):
 
     def clearDetails(self) -> None:
         """Clear all the data labels."""
-        self.titleLabel.setText("<b>%s</b>" % self.tr("Title"))
+        self.titleLabel.setText(self.tr("Title"))
         self.titleValue.setText("")
         self.fileValue.setText("")
         self.itemValue.setText("")
@@ -982,49 +1027,40 @@ class GuiOutlineDetails(QScrollArea):
     ##
 
     @pyqtSlot(str, str)
-    def showItem(self, tHandle: str, sTitle: str) -> bool:
+    def showItem(self, tHandle: str, sTitle: str) -> None:
         """Update the content of the tree with the given handle and line
         number pointing to a header.
         """
         pIndex = SHARED.project.index
         nwItem = SHARED.project.tree[tHandle]
-        novIdx = pIndex.getItemHeader(tHandle, sTitle)
-        theRefs = pIndex.getReferences(tHandle, sTitle)
-        if nwItem is None or novIdx is None:
-            return False
+        novIdx = pIndex.getItemHeading(tHandle, sTitle)
+        novRefs = pIndex.getReferences(tHandle, sTitle)
+        if nwItem and novIdx:
+            self.titleLabel.setText(self.tr(self.LVL_MAP.get(novIdx.level, "H1")))
+            self.titleValue.setText(novIdx.title)
 
-        if novIdx.level in self.LVL_MAP:
-            self.titleLabel.setText("<b>%s</b>" % self.tr(self.LVL_MAP[novIdx.level]))
-        else:
-            self.titleLabel.setText("<b>%s</b>" % self.tr("Title"))
-        self.titleValue.setText(novIdx.title)
+            itemStatus, _ = nwItem.getImportStatus()
 
-        itemStatus, _ = nwItem.getImportStatus(incIcon=False)
+            self.fileValue.setText(nwItem.itemName)
+            self.itemValue.setText(itemStatus)
 
-        self.fileValue.setText(nwItem.itemName)
-        self.itemValue.setText(itemStatus)
+            self.cCValue.setText(f"{checkInt(novIdx.charCount, 0):n}")
+            self.wCValue.setText(f"{checkInt(novIdx.wordCount, 0):n}")
+            self.pCValue.setText(f"{checkInt(novIdx.paraCount, 0):n}")
 
-        cC = checkInt(novIdx.charCount, 0)
-        wC = checkInt(novIdx.wordCount, 0)
-        pC = checkInt(novIdx.paraCount, 0)
+            self.synopValue.setText(novIdx.synopsis)
 
-        self.cCValue.setText(f"{cC:n}")
-        self.wCValue.setText(f"{wC:n}")
-        self.pCValue.setText(f"{pC:n}")
+            self.povKeyValue.setText(self._formatTags(novRefs, nwKeyWords.POV_KEY))
+            self.focKeyValue.setText(self._formatTags(novRefs, nwKeyWords.FOCUS_KEY))
+            self.chrKeyValue.setText(self._formatTags(novRefs, nwKeyWords.CHAR_KEY))
+            self.pltKeyValue.setText(self._formatTags(novRefs, nwKeyWords.PLOT_KEY))
+            self.timKeyValue.setText(self._formatTags(novRefs, nwKeyWords.TIME_KEY))
+            self.wldKeyValue.setText(self._formatTags(novRefs, nwKeyWords.WORLD_KEY))
+            self.objKeyValue.setText(self._formatTags(novRefs, nwKeyWords.OBJECT_KEY))
+            self.entKeyValue.setText(self._formatTags(novRefs, nwKeyWords.ENTITY_KEY))
+            self.cstKeyValue.setText(self._formatTags(novRefs, nwKeyWords.CUSTOM_KEY))
 
-        self.synopValue.setText(novIdx.synopsis)
-
-        self.povKeyValue.setText(self._formatTags(theRefs, nwKeyWords.POV_KEY))
-        self.focKeyValue.setText(self._formatTags(theRefs, nwKeyWords.FOCUS_KEY))
-        self.chrKeyValue.setText(self._formatTags(theRefs, nwKeyWords.CHAR_KEY))
-        self.pltKeyValue.setText(self._formatTags(theRefs, nwKeyWords.PLOT_KEY))
-        self.timKeyValue.setText(self._formatTags(theRefs, nwKeyWords.TIME_KEY))
-        self.wldKeyValue.setText(self._formatTags(theRefs, nwKeyWords.WORLD_KEY))
-        self.objKeyValue.setText(self._formatTags(theRefs, nwKeyWords.OBJECT_KEY))
-        self.entKeyValue.setText(self._formatTags(theRefs, nwKeyWords.ENTITY_KEY))
-        self.cstKeyValue.setText(self._formatTags(theRefs, nwKeyWords.CUSTOM_KEY))
-
-        return True
+        return
 
     @pyqtSlot()
     def updateClasses(self) -> None:
@@ -1059,5 +1095,3 @@ class GuiOutlineDetails(QScrollArea):
         return ", ".join(
             [f"<a href='{tag}'>{tag}</a>" for tag in refs.get(key, [])]
         )
-
-# END Class GuiOutlineDetails
