@@ -27,13 +27,15 @@ import logging
 
 from typing import TYPE_CHECKING
 
+from PyQt5.QtCore import QEvent, QPoint, QSize, pyqtSignal
 from PyQt5.QtGui import QPalette
-from PyQt5.QtCore import QEvent, QPoint, Qt, QSize, pyqtSignal
-from PyQt5.QtWidgets import QMenu, QToolButton, QVBoxLayout, QWidget
+from PyQt5.QtWidgets import QMenu, QVBoxLayout, QWidget
 
 from novelwriter import CONFIG, SHARED
 from novelwriter.enum import nwView
 from novelwriter.extensions.eventfilters import StatusTipFilter
+from novelwriter.extensions.modified import NIconToolButton
+from novelwriter.gui.theme import STYLES_BIG_TOOLBUTTON
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.guimain import GuiMain
@@ -43,7 +45,7 @@ logger = logging.getLogger(__name__)
 
 class GuiSideBar(QWidget):
 
-    viewChangeRequested = pyqtSignal(nwView)
+    requestViewChange = pyqtSignal(nwView)
 
     def __init__(self, mainGui: GuiMain) -> None:
         super().__init__(parent=mainGui)
@@ -52,47 +54,44 @@ class GuiSideBar(QWidget):
 
         self.mainGui = mainGui
 
-        iPx = CONFIG.pxInt(24)
-        iconSize = QSize(iPx, iPx)
+        iPx = int(1.2*SHARED.theme.baseButtonHeight)
+        iSz = QSize(iPx, iPx)
+
         self.setContentsMargins(0, 0, 0, 0)
-        self.installEventFilter(StatusTipFilter(mainGui))
+        self.installEventFilter(StatusTipFilter(self.mainGui))
 
         # Buttons
-        self.tbProject = QToolButton(self)
+        self.tbProject = NIconToolButton(self, iSz)
         self.tbProject.setToolTip("{0} [Ctrl+T]".format(self.tr("Project Tree View")))
-        self.tbProject.setIconSize(iconSize)
-        self.tbProject.clicked.connect(lambda: self.viewChangeRequested.emit(nwView.PROJECT))
+        self.tbProject.clicked.connect(lambda: self.requestViewChange.emit(nwView.PROJECT))
 
-        self.tbNovel = QToolButton(self)
+        self.tbNovel = NIconToolButton(self, iSz)
         self.tbNovel.setToolTip("{0} [Ctrl+T]".format(self.tr("Novel Tree View")))
-        self.tbNovel.setIconSize(iconSize)
-        self.tbNovel.clicked.connect(lambda: self.viewChangeRequested.emit(nwView.NOVEL))
+        self.tbNovel.clicked.connect(lambda: self.requestViewChange.emit(nwView.NOVEL))
 
-        self.tbOutline = QToolButton(self)
+        self.tbSearch = NIconToolButton(self, iSz)
+        self.tbSearch.setToolTip("{0} [Ctrl+Shift+F]".format(self.tr("Project Search")))
+        self.tbSearch.clicked.connect(lambda: self.requestViewChange.emit(nwView.SEARCH))
+
+        self.tbOutline = NIconToolButton(self, iSz)
         self.tbOutline.setToolTip("{0} [Ctrl+Shift+T]".format(self.tr("Novel Outline View")))
-        self.tbOutline.setIconSize(iconSize)
-        self.tbOutline.clicked.connect(lambda: self.viewChangeRequested.emit(nwView.OUTLINE))
+        self.tbOutline.clicked.connect(lambda: self.requestViewChange.emit(nwView.OUTLINE))
 
-        self.tbBuild = QToolButton(self)
+        self.tbBuild = NIconToolButton(self, iSz)
         self.tbBuild.setToolTip("{0} [F5]".format(self.tr("Build Manuscript")))
-        self.tbBuild.setIconSize(iconSize)
         self.tbBuild.clicked.connect(self.mainGui.showBuildManuscriptDialog)
 
-        self.tbDetails = QToolButton(self)
-        self.tbDetails.setToolTip("{0} [Shift+F6]".format(self.tr("Project Details")))
-        self.tbDetails.setIconSize(iconSize)
-        self.tbDetails.clicked.connect(self.mainGui.showProjectDetailsDialog)
+        self.tbDetails = NIconToolButton(self, iSz)
+        self.tbDetails.setToolTip("{0} [Shift+F6]".format(self.tr("Novel Details")))
+        self.tbDetails.clicked.connect(self.mainGui.showNovelDetailsDialog)
 
-        self.tbStats = QToolButton(self)
+        self.tbStats = NIconToolButton(self, iSz)
         self.tbStats.setToolTip("{0} [F6]".format(self.tr("Writing Statistics")))
-        self.tbStats.setIconSize(iconSize)
         self.tbStats.clicked.connect(self.mainGui.showWritingStatsDialog)
 
         # Settings Menu
-        self.tbSettings = QToolButton(self)
+        self.tbSettings = NIconToolButton(self, iSz)
         self.tbSettings.setToolTip(self.tr("Settings"))
-        self.tbSettings.setIconSize(iconSize)
-        self.tbSettings.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonIconOnly)
 
         self.mSettings = _PopRightMenu(self.tbSettings)
         self.mSettings.addAction(self.mainGui.mainMenu.aEditWordList)
@@ -101,12 +100,12 @@ class GuiSideBar(QWidget):
         self.mSettings.addAction(self.mainGui.mainMenu.aPreferences)
 
         self.tbSettings.setMenu(self.mSettings)
-        self.tbSettings.setPopupMode(QToolButton.InstantPopup)
 
         # Assemble
         self.outerBox = QVBoxLayout()
         self.outerBox.addWidget(self.tbProject)
         self.outerBox.addWidget(self.tbNovel)
+        self.outerBox.addWidget(self.tbSearch)
         self.outerBox.addWidget(self.tbOutline)
         self.outerBox.addWidget(self.tbBuild)
         self.outerBox.addStretch(1)
@@ -126,51 +125,38 @@ class GuiSideBar(QWidget):
     def updateTheme(self) -> None:
         """Initialise GUI elements that depend on specific settings."""
         qPalette = self.palette()
-        qPalette.setBrush(QPalette.Window, qPalette.base())
+        qPalette.setBrush(QPalette.ColorRole.Window, qPalette.base())
         self.setPalette(qPalette)
 
-        fadeCol = qPalette.text().color()
-        buttonStyle = (
-            "QToolButton {{padding: {0}px; border: none; background: transparent;}} "
-            "QToolButton:hover {{border: none; background: rgba({1},{2},{3},0.2);}}"
-        ).format(CONFIG.pxInt(6), fadeCol.red(), fadeCol.green(), fadeCol.blue())
-        buttonStyleMenu = f"{buttonStyle} QToolButton::menu-indicator {{image: none;}}"
+        buttonStyle = SHARED.theme.getStyleSheet(STYLES_BIG_TOOLBUTTON)
 
-        self.tbProject.setIcon(SHARED.theme.getIcon("view_editor"))
         self.tbProject.setStyleSheet(buttonStyle)
-
-        self.tbNovel.setIcon(SHARED.theme.getIcon("view_novel"))
         self.tbNovel.setStyleSheet(buttonStyle)
-
-        self.tbOutline.setIcon(SHARED.theme.getIcon("view_outline"))
+        self.tbSearch.setStyleSheet(buttonStyle)
         self.tbOutline.setStyleSheet(buttonStyle)
-
-        self.tbBuild.setIcon(SHARED.theme.getIcon("view_build"))
         self.tbBuild.setStyleSheet(buttonStyle)
-
-        self.tbDetails.setIcon(SHARED.theme.getIcon("proj_details"))
         self.tbDetails.setStyleSheet(buttonStyle)
-
-        self.tbStats.setIcon(SHARED.theme.getIcon("proj_stats"))
         self.tbStats.setStyleSheet(buttonStyle)
+        self.tbSettings.setStyleSheet(buttonStyle)
 
-        self.tbSettings.setIcon(SHARED.theme.getIcon("settings"))
-        self.tbSettings.setStyleSheet(buttonStyleMenu)
+        self.tbProject.setThemeIcon("view_editor")
+        self.tbNovel.setThemeIcon("view_novel")
+        self.tbSearch.setThemeIcon("view_search")
+        self.tbOutline.setThemeIcon("view_outline")
+        self.tbBuild.setThemeIcon("view_build")
+        self.tbDetails.setThemeIcon("proj_details")
+        self.tbStats.setThemeIcon("proj_stats")
+        self.tbSettings.setThemeIcon("settings")
 
         return
 
-# END Class GuiSideBar
-
 
 class _PopRightMenu(QMenu):
 
     def event(self, event: QEvent) -> bool:
         """Overload the show event and move the menu popup location."""
-        if event.type() == QEvent.Show:
-            parent = self.parent()
-            if isinstance(parent, QWidget):
+        if event.type() == QEvent.Type.Show:
+            if isinstance(parent := self.parent(), QWidget):
                 offset = QPoint(parent.width(), parent.height() - self.height())
                 self.move(parent.mapToGlobal(offset))
         return super(_PopRightMenu, self).event(event)
-
-# END Class _PopRightMenu
