@@ -25,29 +25,25 @@ from __future__ import annotations
 
 import logging
 
-from time import time
-from typing import TYPE_CHECKING, Literal
 from datetime import datetime
+from time import time
 
-from PyQt5.QtGui import QColor
-from PyQt5.QtCore import pyqtSlot, QLocale
-from PyQt5.QtWidgets import qApp, QStatusBar, QLabel
+from PyQt5.QtCore import QLocale, pyqtSlot
+from PyQt5.QtWidgets import QApplication, QLabel, QStatusBar, QWidget
 
 from novelwriter import CONFIG, SHARED
 from novelwriter.common import formatTime
 from novelwriter.constants import nwConst
+from novelwriter.enum import nwTrinary
 from novelwriter.extensions.statusled import StatusLED
 
-if TYPE_CHECKING:  # pragma: no cover
-    from novelwriter.guimain import GuiMain
-
 logger = logging.getLogger(__name__)
 
 
 class GuiMainStatus(QStatusBar):
 
-    def __init__(self, mainGui: GuiMain) -> None:
-        super().__init__(parent=mainGui)
+    def __init__(self, parent: QWidget) -> None:
+        super().__init__(parent=parent)
 
         logger.debug("Create: GuiMainStatus")
 
@@ -55,11 +51,7 @@ class GuiMainStatus(QStatusBar):
         self._userIdle = False
         self._debugInfo = False
 
-        colNone = QColor(*SHARED.theme.statNone)
-        colSaved = QColor(*SHARED.theme.statSaved)
-        colUnsaved = QColor(*SHARED.theme.statUnsaved)
-
-        iPx = SHARED.theme.baseIconSize
+        iPx = SHARED.theme.baseIconHeight
 
         # Permanent Widgets
         # =================
@@ -67,32 +59,32 @@ class GuiMainStatus(QStatusBar):
         xM = CONFIG.pxInt(8)
 
         # The Spell Checker Language
-        self.langIcon = QLabel("")
-        self.langText = QLabel(self.tr("None"))
+        self.langIcon = QLabel("", self)
+        self.langText = QLabel(self.tr("None"), self)
         self.langIcon.setContentsMargins(0, 0, 0, 0)
         self.langText.setContentsMargins(0, 0, xM, 0)
         self.addPermanentWidget(self.langIcon)
         self.addPermanentWidget(self.langText)
 
         # The Editor Status
-        self.docIcon = StatusLED(colNone, colSaved, colUnsaved, iPx, iPx, self)
-        self.docText = QLabel(self.tr("Editor"))
+        self.docIcon = StatusLED(iPx, iPx, self)
+        self.docText = QLabel(self.tr("Editor"), self)
         self.docIcon.setContentsMargins(0, 0, 0, 0)
         self.docText.setContentsMargins(0, 0, xM, 0)
         self.addPermanentWidget(self.docIcon)
         self.addPermanentWidget(self.docText)
 
         # The Project Status
-        self.projIcon = StatusLED(colNone, colSaved, colUnsaved, iPx, iPx, self)
-        self.projText = QLabel(self.tr("Project"))
+        self.projIcon = StatusLED(iPx, iPx, self)
+        self.projText = QLabel(self.tr("Project"), self)
         self.projIcon.setContentsMargins(0, 0, 0, 0)
         self.projText.setContentsMargins(0, 0, xM, 0)
         self.addPermanentWidget(self.projIcon)
         self.addPermanentWidget(self.projText)
 
         # The Project and Session Stats
-        self.statsIcon = QLabel()
-        self.statsText = QLabel("")
+        self.statsIcon = QLabel(self)
+        self.statsText = QLabel("", self)
         self.statsIcon.setContentsMargins(0, 0, 0, 0)
         self.statsText.setContentsMargins(0, 0, xM, 0)
         self.addPermanentWidget(self.statsIcon)
@@ -100,8 +92,8 @@ class GuiMainStatus(QStatusBar):
 
         # The Session Clock
         # Set the minimum width so the label doesn't rescale every second
-        self.timeIcon = QLabel()
-        self.timeText = QLabel("")
+        self.timeIcon = QLabel(self)
+        self.timeText = QLabel("", self)
         self.timeText.setToolTip(self.tr("Session Time"))
         self.timeText.setMinimumWidth(SHARED.theme.getTextWidth("00:00:00:"))
         self.timeIcon.setContentsMargins(0, 0, 0, 0)
@@ -124,19 +116,26 @@ class GuiMainStatus(QStatusBar):
         self.setRefTime(-1.0)
         self.setLanguage(*SHARED.spelling.describeDict())
         self.setProjectStats(0, 0)
-        self.setProjectStatus(StatusLED.S_NONE)
-        self.setDocumentStatus(StatusLED.S_NONE)
+        self.setProjectStatus(nwTrinary.NEUTRAL)
+        self.setDocumentStatus(nwTrinary.NEUTRAL)
         self.updateTime()
         return
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        iPx = SHARED.theme.baseIconSize
+        iPx = SHARED.theme.baseIconHeight
         self.langIcon.setPixmap(SHARED.theme.getPixmap("status_lang", (iPx, iPx)))
         self.statsIcon.setPixmap(SHARED.theme.getPixmap("status_stats", (iPx, iPx)))
         self.timePixmap = SHARED.theme.getPixmap("status_time", (iPx, iPx))
         self.idlePixmap = SHARED.theme.getPixmap("status_idle", (iPx, iPx))
         self.timeIcon.setPixmap(self.timePixmap)
+
+        colNone = SHARED.theme.statNone
+        colSaved = SHARED.theme.statSaved
+        colUnsaved = SHARED.theme.statUnsaved
+        self.docIcon.setColors(colNone, colSaved, colUnsaved)
+        self.projIcon.setColors(colNone, colSaved, colUnsaved)
+
         return
 
     ##
@@ -148,12 +147,12 @@ class GuiMainStatus(QStatusBar):
         self._refTime = refTime
         return
 
-    def setProjectStatus(self, state: Literal[0, 1, 2]) -> None:
+    def setProjectStatus(self, state: nwTrinary) -> None:
         """Set the project status colour icon."""
         self.projIcon.setState(state)
         return
 
-    def setDocumentStatus(self, state: Literal[0, 1, 2]) -> None:
+    def setDocumentStatus(self, state: nwTrinary) -> None:
         """Set the document status colour icon."""
         self.docIcon.setState(state)
         return
@@ -199,7 +198,7 @@ class GuiMainStatus(QStatusBar):
     def setStatusMessage(self, message: str) -> None:
         """Set the status bar message to display."""
         self.showMessage(message, nwConst.STATUS_MSG_TIMEOUT)
-        qApp.processEvents()
+        QApplication.processEvents()
         return
 
     @pyqtSlot(str, str)
@@ -216,13 +215,13 @@ class GuiMainStatus(QStatusBar):
     @pyqtSlot(bool)
     def updateProjectStatus(self, status: bool) -> None:
         """Update the project status."""
-        self.setProjectStatus(StatusLED.S_BAD if status else StatusLED.S_GOOD)
+        self.setProjectStatus(nwTrinary.NEGATIVE if status else nwTrinary.POSITIVE)
         return
 
     @pyqtSlot(bool)
     def updateDocumentStatus(self, status: bool) -> None:
         """Update the document status."""
-        self.setDocumentStatus(StatusLED.S_BAD if status else StatusLED.S_GOOD)
+        self.setDocumentStatus(nwTrinary.NEGATIVE if status else nwTrinary.POSITIVE)
         return
 
     ##
@@ -239,9 +238,8 @@ class GuiMainStatus(QStatusBar):
         before starting novelWriter.
         """
         import tracemalloc
-        from collections import Counter
 
-        widgets = qApp.allWidgets()
+        count = len(QApplication.allWidgets())
         if not self._debugInfo:
             if tracemalloc.is_tracing():
                 self._traceMallocRef = "Total"
@@ -249,21 +247,14 @@ class GuiMainStatus(QStatusBar):
                 self._traceMallocRef = "Relative"
                 tracemalloc.start()
             self._debugInfo = True
-            self._wCounts = Counter([type(x).__name__ for x in widgets])
 
-        if hasattr(self, "_wCounts"):
-            diff = Counter([type(x).__name__ for x in widgets]) - self._wCounts
-            for name, count in diff.items():
-                logger.debug("Widget '%s': +%d", name, count)
-
-        mem = tracemalloc.get_traced_memory()
+        current, peak = tracemalloc.get_traced_memory()
         stamp = datetime.now().strftime("%H:%M:%S")
-        self.showMessage((
-            f"Debug [{stamp}]"
-            f" \u2013 Widgets: {len(widgets)}"
-            f" \u2013 {self._traceMallocRef} Memory: {mem[0]:n}"
-            f" \u2013 Peak: {mem[1]:n}"
-        ), 6000)
+        message = (
+            f"Widgets: {count} \u2013 "
+            f"{self._traceMallocRef} Memory: {current/1024:,.2f} kiB \u2013 "
+            f"Peak: {peak/1024:,.2f} kiB"
+        )
+        self.showMessage(f"Debug [{stamp}] {message}", 6000)
+        logger.debug("[MEMINFO] %s", message)
         return
-
-# END Class GuiMainStatus
