@@ -29,27 +29,28 @@ import logging
 from math import ceil
 from pathlib import Path
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtWidgets import qApp
-from PyQt5.QtGui import (
-    QPalette, QColor, QIcon, QFont, QFontMetrics, QFontDatabase, QPixmap
-)
+from PyQt5.QtCore import QSize, Qt
+from PyQt5.QtGui import QColor, QFont, QFontDatabase, QFontMetrics, QIcon, QPalette, QPixmap
+from PyQt5.QtWidgets import QApplication
 
 from novelwriter import CONFIG
+from novelwriter.common import NWConfigParser, cssCol, minmax
+from novelwriter.constants import nwLabels
 from novelwriter.enum import nwItemClass, nwItemLayout, nwItemType
 from novelwriter.error import logException
-from novelwriter.common import NWConfigParser, minmax
-from novelwriter.constants import nwLabels
 
 logger = logging.getLogger(__name__)
 
+STYLES_FLAT_TABS = "flatTabWidget"
+STYLES_MIN_TOOLBUTTON = "minimalToolButton"
+STYLES_BIG_TOOLBUTTON = "bigToolButton"
 
-# =============================================================================================== #
-#  Gui Theme Class
-#  Handles the look and feel of novelWriter
-# =============================================================================================== #
 
 class GuiTheme:
+    """Gui Theme Class
+
+    Handles the look and feel of novelWriter.
+    """
 
     def __init__(self) -> None:
 
@@ -67,12 +68,15 @@ class GuiTheme:
         self.themeLicense     = ""
         self.themeLicenseUrl  = ""
         self.themeIcons       = ""
+        self.isLightTheme     = True
 
         # GUI
-        self.statNone    = [120, 120, 120]
-        self.statUnsaved = [200, 15, 39]
-        self.statSaved   = [2, 133, 37]
-        self.helpText    = [0, 0, 0]
+        self.statNone    = QColor(0, 0, 0)
+        self.statUnsaved = QColor(0, 0, 0)
+        self.statSaved   = QColor(0, 0, 0)
+        self.helpText    = QColor(0, 0, 0)
+        self.fadedText   = QColor(0, 0, 0)
+        self.errorText   = QColor(255, 0, 0)
 
         # Loaded Syntax Settings
         # ======================
@@ -87,36 +91,37 @@ class GuiTheme:
         self.syntaxLicenseUrl  = ""
 
         # Colours
-        self.colBack   = [255, 255, 255]
-        self.colText   = [0, 0, 0]
-        self.colLink   = [0, 0, 0]
-        self.colHead   = [0, 0, 0]
-        self.colHeadH  = [0, 0, 0]
-        self.colEmph   = [0, 0, 0]
-        self.colDialN  = [0, 0, 0]
-        self.colDialD  = [0, 0, 0]
-        self.colDialS  = [0, 0, 0]
-        self.colHidden = [0, 0, 0]
-        self.colCode   = [0, 0, 0]
-        self.colKey    = [0, 0, 0]
-        self.colVal    = [0, 0, 0]
-        self.colSpell  = [0, 0, 0]
-        self.colError  = [0, 0, 0]
-        self.colRepTag = [0, 0, 0]
-        self.colMod    = [0, 0, 0]
+        self.colBack   = QColor(255, 255, 255)
+        self.colText   = QColor(0, 0, 0)
+        self.colLink   = QColor(0, 0, 0)
+        self.colHead   = QColor(0, 0, 0)
+        self.colHeadH  = QColor(0, 0, 0)
+        self.colEmph   = QColor(0, 0, 0)
+        self.colDialN  = QColor(0, 0, 0)
+        self.colDialA  = QColor(0, 0, 0)
+        self.colHidden = QColor(0, 0, 0)
+        self.colNote   = QColor(0, 0, 0)
+        self.colCode   = QColor(0, 0, 0)
+        self.colKey    = QColor(0, 0, 0)
+        self.colTag    = QColor(0, 0, 0)
+        self.colVal    = QColor(0, 0, 0)
+        self.colOpt    = QColor(0, 0, 0)
+        self.colSpell  = QColor(0, 0, 0)
+        self.colError  = QColor(0, 0, 0)
+        self.colRepTag = QColor(0, 0, 0)
+        self.colMod    = QColor(0, 0, 0)
+        self.colMark   = QColor(255, 255, 255, 128)
 
         # Class Setup
         # ===========
 
-        # Init GUI Font
-        self._setGuiFont()
-
         # Load Themes
-        self._guiPalette  = QPalette()
+        self._guiPalette = QPalette()
         self._themeList: list[tuple[str, str]] = []
         self._syntaxList: list[tuple[str, str]] = []
         self._availThemes: dict[str, Path] = {}
         self._availSyntax: dict[str, Path] = {}
+        self._styleSheets: dict[str, str] = {}
 
         self._listConf(self._availSyntax, CONFIG.assetPath("syntax"))
         self._listConf(self._availThemes, CONFIG.assetPath("themes"))
@@ -136,31 +141,44 @@ class GuiTheme:
         self.getHeaderDecorationNarrow = self.iconCache.getHeaderDecorationNarrow
 
         # Extract Other Info
-        self.guiDPI = qApp.primaryScreen().logicalDotsPerInchX()
-        self.guiScale = qApp.primaryScreen().logicalDotsPerInchX()/96.0
+        self.guiDPI = QApplication.primaryScreen().logicalDotsPerInchX()
+        self.guiScale = QApplication.primaryScreen().logicalDotsPerInchX()/96.0
         CONFIG.guiScale = self.guiScale
         logger.debug("GUI DPI: %.1f", self.guiDPI)
         logger.debug("GUI Scale: %.2f", self.guiScale)
 
         # Fonts
-        self.guiFont = qApp.font()
+        self.guiFont = QApplication.font()
+        self.guiFontB = QApplication.font()
+        self.guiFontB.setBold(True)
+        self.guiFontSmall = QApplication.font()
+        self.guiFontSmall.setPointSizeF(0.9*self.guiFont.pointSizeF())
 
         qMetric = QFontMetrics(self.guiFont)
+        fHeight = qMetric.height()
+        fAscent = qMetric.ascent()
         self.fontPointSize = self.guiFont.pointSizeF()
-        self.fontPixelSize = int(round(qMetric.height()))
-        self.baseIconSize = int(round(qMetric.ascent()))
+        self.fontPixelSize = int(round(fHeight))
+        self.baseIconHeight = int(round(fAscent))
+        self.baseButtonHeight = int(round(1.35*fAscent))
         self.textNHeight = qMetric.boundingRect("N").height()
         self.textNWidth = qMetric.boundingRect("N").width()
 
+        self.baseIconSize = QSize(self.baseIconHeight, self.baseIconHeight)
+        self.buttonIconSize = QSize(int(0.9*self.baseIconHeight), int(0.9*self.baseIconHeight))
+
         # Monospace Font
         self.guiFontFixed = QFont()
         self.guiFontFixed.setPointSizeF(0.95*self.fontPointSize)
-        self.guiFontFixed.setFamily(QFontDatabase.systemFont(QFontDatabase.FixedFont).family())
+        self.guiFontFixed.setFamily(
+            QFontDatabase.systemFont(QFontDatabase.SystemFont.FixedFont).family()
+        )
 
         logger.debug("GUI Font Family: %s", self.guiFont.family())
         logger.debug("GUI Font Point Size: %.2f", self.fontPointSize)
         logger.debug("GUI Font Pixel Size: %d", self.fontPixelSize)
-        logger.debug("GUI Base Icon Size: %d", self.baseIconSize)
+        logger.debug("GUI Base Icon Height: %d", self.baseIconHeight)
+        logger.debug("GUI Base Button Height: %d", self.baseButtonHeight)
         logger.debug("Text 'N' Height: %d", self.textNHeight)
         logger.debug("Text 'N' Width: %d", self.textNWidth)
 
@@ -208,6 +226,10 @@ class GuiTheme:
             logException()
             return False
 
+        # Reset Palette
+        self._guiPalette = QApplication.style().standardPalette()
+        self._resetGuiColors()
+
         # Main
         sec = "Main"
         if parser.has_section(sec):
@@ -237,13 +259,13 @@ class GuiTheme:
             self._setPalette(parser, sec, "highlightedtext", QPalette.ColorRole.HighlightedText)
             self._setPalette(parser, sec, "link",            QPalette.ColorRole.Link)
             self._setPalette(parser, sec, "linkvisited",     QPalette.ColorRole.LinkVisited)
-        else:
-            self._guiPalette = qApp.style().standardPalette()
 
         # GUI
         sec = "GUI"
         if parser.has_section(sec):
             self.helpText    = self._parseColour(parser, sec, "helptext")
+            self.fadedText   = self._parseColour(parser, sec, "fadedtext")
+            self.errorText   = self._parseColour(parser, sec, "errortext")
             self.statNone    = self._parseColour(parser, sec, "statusnone")
             self.statUnsaved = self._parseColour(parser, sec, "statusunsaved")
             self.statSaved   = self._parseColour(parser, sec, "statussaved")
@@ -254,20 +276,27 @@ class GuiTheme:
 
         backLNess = backCol.lightnessF()
         textLNess = textCol.lightnessF()
-
-        if self.helpText == [0, 0, 0]:
-            if backLNess > textLNess:
+        self.isLightTheme = backLNess > textLNess
+        if self.helpText == QColor(0, 0, 0):
+            if self.isLightTheme:
                 helpLCol = textLNess + 0.35*(backLNess - textLNess)
             else:
                 helpLCol = backLNess + 0.65*(textLNess - backLNess)
-            self.helpText = [int(255*helpLCol)]*3
+            self.helpText = QColor.fromHsl(0, 0, int(255*helpLCol))
+            logger.debug(
+                "Computed help text colour: rgb(%d, %d, %d)",
+                self.helpText.red(), self.helpText.green(), self.helpText.blue()
+            )
 
         # Icons
         defaultIcons = "typicons_light" if backLNess >= 0.5 else "typicons_dark"
         self.iconCache.loadTheme(self.themeIcons or defaultIcons)
 
         # Apply Styles
-        qApp.setPalette(self._guiPalette)
+        QApplication.setPalette(self._guiPalette)
+
+        # Reset stylesheets so that they are regenerated
+        self._buildStyleSheets(self._guiPalette)
 
         return True
 
@@ -315,17 +344,20 @@ class GuiTheme:
             self.colHead   = self._parseColour(confParser, cnfSec, "headertext")
             self.colHeadH  = self._parseColour(confParser, cnfSec, "headertag")
             self.colEmph   = self._parseColour(confParser, cnfSec, "emphasis")
-            self.colDialN  = self._parseColour(confParser, cnfSec, "straightquotes")
-            self.colDialD  = self._parseColour(confParser, cnfSec, "doublequotes")
-            self.colDialS  = self._parseColour(confParser, cnfSec, "singlequotes")
+            self.colDialN  = self._parseColour(confParser, cnfSec, "dialog")
+            self.colDialA  = self._parseColour(confParser, cnfSec, "altdialog")
             self.colHidden = self._parseColour(confParser, cnfSec, "hidden")
+            self.colNote   = self._parseColour(confParser, cnfSec, "note")
             self.colCode   = self._parseColour(confParser, cnfSec, "shortcode")
             self.colKey    = self._parseColour(confParser, cnfSec, "keyword")
+            self.colTag    = self._parseColour(confParser, cnfSec, "tag")
             self.colVal    = self._parseColour(confParser, cnfSec, "value")
+            self.colOpt    = self._parseColour(confParser, cnfSec, "optional")
             self.colSpell  = self._parseColour(confParser, cnfSec, "spellcheckline")
             self.colError  = self._parseColour(confParser, cnfSec, "errorline")
             self.colRepTag = self._parseColour(confParser, cnfSec, "replacetag")
             self.colMod    = self._parseColour(confParser, cnfSec, "modifier")
+            self.colMark   = self._parseColour(confParser, cnfSec, "texthighlight")
 
         return True
 
@@ -341,7 +373,7 @@ class GuiTheme:
             if themeName:
                 self._themeList.append((themeKey, themeName))
 
-        self._themeList = sorted(self._themeList, key=lambda x: x[1])
+        self._themeList = sorted(self._themeList, key=_sortTheme)
 
         return self._themeList
 
@@ -357,33 +389,26 @@ class GuiTheme:
             if syntaxName:
                 self._syntaxList.append((syntaxKey, syntaxName))
 
-        self._syntaxList = sorted(self._syntaxList, key=lambda x: x[1])
+        self._syntaxList = sorted(self._syntaxList, key=_sortTheme)
 
         return self._syntaxList
 
+    def getStyleSheet(self, name: str) -> str:
+        """Load a standard style sheet."""
+        return self._styleSheets.get(name, "")
+
     ##
     #  Internal Functions
     ##
 
-    def _setGuiFont(self) -> None:
-        """Update the GUI's font style from settings."""
-        theFont = QFont()
-        fontDB = QFontDatabase()
-        if CONFIG.guiFont not in fontDB.families():
-            if CONFIG.osWindows and "Arial" in fontDB.families():
-                # On Windows we default to Arial if possible
-                theFont.setFamily("Arial")
-                theFont.setPointSize(10)
-            else:
-                theFont = fontDB.systemFont(QFontDatabase.GeneralFont)
-            CONFIG.guiFont = theFont.family()
-            CONFIG.guiFontSize = theFont.pointSize()
-        else:
-            theFont.setFamily(CONFIG.guiFont)
-            theFont.setPointSize(CONFIG.guiFontSize)
-
-        qApp.setFont(theFont)
-
+    def _resetGuiColors(self) -> None:
+        """Reset GUI colours to default values."""
+        self.statNone    = QColor(120, 120, 120)
+        self.statUnsaved = QColor(200, 15, 39)
+        self.statSaved   = QColor(2, 133, 37)
+        self.helpText    = QColor(0, 0, 0)
+        self.fadedText   = QColor(128, 128, 128)
+        self.errorText   = QColor(255, 0, 0)
         return
 
     def _listConf(self, targetDict: dict, checkDir: Path) -> bool:
@@ -397,37 +422,51 @@ class GuiTheme:
 
         return True
 
-    def _parseColour(self, parser: NWConfigParser, section: str, name: str) -> list[int]:
+    def _parseColour(self, parser: NWConfigParser, section: str, name: str) -> QColor:
         """Parse a colour value from a config string."""
-        if parser.has_option(section, name):
-            values = parser.get(section, name).split(",")
-            result = []
-            try:
-                result.append(minmax(int(values[0]), 0, 255))
-                result.append(minmax(int(values[1]), 0, 255))
-                result.append(minmax(int(values[2]), 0, 255))
-            except Exception:
-                logger.error("Could not load theme colours for '%s' from config file", name)
-                result = [0, 0, 0]
-        else:
-            logger.warning("Could not find theme colours for '%s' in config file", name)
-            result = [0, 0, 0]
-        return result
+        return QColor(*parser.rdIntList(section, name, [0, 0, 0, 255]))
 
     def _setPalette(self, parser: NWConfigParser, section: str,
                     name: str, value: QPalette.ColorRole) -> None:
         """Set a palette colour value from a config string."""
-        self._guiPalette.setColor(
-            value, QColor(*self._parseColour(parser, section, name))
-        )
+        self._guiPalette.setColor(value, self._parseColour(parser, section, name))
         return
 
-# End Class GuiTheme
+    def _buildStyleSheets(self, palette: QPalette) -> None:
+        """Build default style sheets."""
+        self._styleSheets = {}
 
+        aPx = CONFIG.pxInt(2)
+        bPx = CONFIG.pxInt(4)
+        cPx = CONFIG.pxInt(6)
+        dPx = CONFIG.pxInt(8)
+
+        tCol = palette.text().color()
+        hCol = palette.highlight().color()
+
+        # Flat Tab Widget and Tab Bar:
+        self._styleSheets[STYLES_FLAT_TABS] = (
+            "QTabWidget::pane {border: 0;} "
+            f"QTabWidget QTabBar::tab {{border: 0; padding: {bPx}px {dPx}px;}} "
+            f"QTabWidget QTabBar::tab:selected {{color: {cssCol(hCol)};}} "
+        )
+
+        # Minimal Tool Button
+        self._styleSheets[STYLES_MIN_TOOLBUTTON] = (
+            f"QToolButton {{padding: {aPx}px; margin: 0; border: none; background: transparent;}} "
+            f"QToolButton:hover {{border: none; background: {cssCol(tCol, 48)};}} "
+            "QToolButton::menu-indicator {image: none;} "
+        )
+
+        # Big Tool Button
+        self._styleSheets[STYLES_BIG_TOOLBUTTON] = (
+            f"QToolButton {{padding: {cPx}px; margin: 0; border: none; background: transparent;}} "
+            f"QToolButton:hover {{border: none; background: {cssCol(tCol, 48)};}} "
+            "QToolButton::menu-indicator {image: none;} "
+        )
+
+        return
 
-# =============================================================================================== #
-#  Icons Class
-# =============================================================================================== #
 
 class GuiIcons:
     """The icon class manages the content of the assets/icons folder,
@@ -443,34 +482,36 @@ class GuiIcons:
     missing, a blank icon is returned and a warning issued.
     """
 
-    ICON_KEYS = {
+    ICON_KEYS: set[str] = {
         # Project and GUI Icons
         "novelwriter", "alert_error", "alert_info", "alert_question", "alert_warn",
         "build_excluded", "build_filtered", "build_included", "proj_chapter", "proj_details",
         "proj_document", "proj_folder", "proj_note", "proj_nwx", "proj_section", "proj_scene",
         "proj_stats", "proj_title", "status_idle", "status_lang", "status_lines", "status_stats",
-        "status_time", "view_build", "view_editor", "view_novel", "view_outline",
+        "status_time", "view_build", "view_editor", "view_novel", "view_outline", "view_search",
 
         # Class Icons
         "cls_archive", "cls_character", "cls_custom", "cls_entity", "cls_none", "cls_novel",
-        "cls_object", "cls_plot", "cls_timeline", "cls_trash", "cls_world",
+        "cls_object", "cls_plot", "cls_template", "cls_timeline", "cls_trash", "cls_world",
 
         # Search Icons
         "search_cancel", "search_case", "search_loop", "search_preserve", "search_project",
         "search_regex", "search_word",
 
         # Format Icons
-        "fmt_bold", "fmt_bold-md", "fmt_italic", "fmt_italic-md", "fmt_strike", "fmt_strike-md",
-        "fmt_subscript", "fmt_superscript", "fmt_underline",
+        "fmt_bold", "fmt_bold-md", "fmt_italic", "fmt_italic-md", "fmt_mark", "fmt_strike",
+        "fmt_strike-md", "fmt_subscript", "fmt_superscript", "fmt_underline",
 
         # General Button Icons
-        "add", "backward", "bookmark", "browse", "checked", "close", "cross", "down", "edit",
-        "export", "forward", "maximise", "menu", "minimise", "noncheckable", "panel", "refresh",
-        "remove", "revert", "search_replace", "search", "settings", "unchecked", "up", "view",
+        "add", "add_document", "backward", "bookmark", "browse", "checked", "close", "cross",
+        "document", "down", "edit", "export", "font", "forward", "import", "list", "maximise",
+        "menu", "minimise", "more", "noncheckable", "open", "panel", "quote", "refresh", "remove",
+        "revert", "search_replace", "search", "settings", "star", "unchecked", "up", "view",
 
         # Switches
         "sticky-on", "sticky-off",
         "bullet-on", "bullet-off",
+        "unfold-show", "unfold-hide",
 
         # Decorations
         "deco_doc_h0", "deco_doc_h1", "deco_doc_h2", "deco_doc_h3", "deco_doc_h4", "deco_doc_more",
@@ -478,13 +519,15 @@ class GuiIcons:
         "deco_doc_nt_n",
     }
 
-    TOGGLE_ICON_KEYS = {
+    TOGGLE_ICON_KEYS: dict[str, tuple[str, str]] = {
         "sticky": ("sticky-on", "sticky-off"),
         "bullet": ("bullet-on", "bullet-off"),
+        "unfold": ("unfold-show", "unfold-hide"),
     }
 
-    IMAGE_MAP = {
-        "wiz-back": "wizard-back.jpg",
+    IMAGE_MAP: dict[str, tuple[str, str]] = {
+        "welcome":  ("welcome-light.jpg", "welcome-dark.jpg"),
+        "nw-text":  ("novelwriter-text-light.svg", "novelwriter-text-dark.svg"),
     }
 
     def __init__(self, mainTheme: GuiTheme) -> None:
@@ -501,6 +544,9 @@ class GuiIcons:
         self._confName = "icons.conf"
         self._iconPath = CONFIG.assetPath("icons")
 
+        # None Icon
+        self._noIcon = QIcon(str(self._iconPath / "none.svg"))
+
         # Icon Theme Meta
         self.themeName        = ""
         self.themeDescription = ""
@@ -598,7 +644,8 @@ class GuiIcons:
         if name in self._themeMap:
             imgPath = self._themeMap[name]
         elif name in self.IMAGE_MAP:
-            imgPath = CONFIG.assetPath("images") / self.IMAGE_MAP[name]
+            idx = 0 if self.mainTheme.isLightTheme else 1
+            imgPath = CONFIG.assetPath("images") / self.IMAGE_MAP[name][idx]
         else:
             logger.error("Decoration with name '%s' does not exist", name)
             return QPixmap()
@@ -608,12 +655,13 @@ class GuiIcons:
             return QPixmap()
 
         pixmap = QPixmap(str(imgPath))
+        tMode = Qt.TransformationMode.SmoothTransformation
         if w is not None and h is not None:
-            return pixmap.scaled(w, h, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
+            return pixmap.scaled(w, h, Qt.AspectRatioMode.IgnoreAspectRatio, tMode)
         elif w is None and h is not None:
-            return pixmap.scaledToHeight(h, Qt.SmoothTransformation)
+            return pixmap.scaledToHeight(h, tMode)
         elif w is not None and h is None:
-            return pixmap.scaledToWidth(w, Qt.SmoothTransformation)
+            return pixmap.scaledToWidth(w, tMode)
 
         return pixmap
 
@@ -629,24 +677,24 @@ class GuiIcons:
     def getToggleIcon(self, name: str, size: tuple[int, int]) -> QIcon:
         """Return a toggle icon from the icon buffer. or load it."""
         if name in self.TOGGLE_ICON_KEYS:
-            pOne  = self.getPixmap(self.TOGGLE_ICON_KEYS[name][0], size)
+            pOne = self.getPixmap(self.TOGGLE_ICON_KEYS[name][0], size)
             pTwo = self.getPixmap(self.TOGGLE_ICON_KEYS[name][1], size)
             icon = QIcon()
-            icon.addPixmap(pOne, QIcon.Normal, QIcon.On)
-            icon.addPixmap(pTwo, QIcon.Normal, QIcon.Off)
+            icon.addPixmap(pOne, QIcon.Mode.Normal, QIcon.State.On)
+            icon.addPixmap(pTwo, QIcon.Mode.Normal, QIcon.State.Off)
             return icon
-        return QIcon()
+        return self._noIcon
 
     def getPixmap(self, name: str, size: tuple[int, int]) -> QPixmap:
         """Return an icon from the icon buffer as a QPixmap. If it
         doesn't exist, return an empty QPixmap.
         """
-        return self.getIcon(name).pixmap(size[0], size[1], QIcon.Normal)
+        return self.getIcon(name).pixmap(size[0], size[1], QIcon.Mode.Normal)
 
     def getItemIcon(self, tType: nwItemType, tClass: nwItemClass,
                     tLayout: nwItemLayout, hLevel: str = "H0") -> QIcon:
         """Get the correct icon for a project item based on type, class
-        and header level
+        and heading level
         """
         iconName = None
         if tType == nwItemType.ROOT:
@@ -667,14 +715,14 @@ class GuiIcons:
             elif tLayout == nwItemLayout.NOTE:
                 iconName = "proj_note"
         if iconName is None:
-            return QIcon()
+            return self._noIcon
 
         return self.getIcon(iconName)
 
     def getHeaderDecoration(self, hLevel: int) -> QPixmap:
-        """Get the decoration for a specific header level."""
+        """Get the decoration for a specific heading level."""
         if not self._headerDec:
-            iPx = self.mainTheme.baseIconSize
+            iPx = self.mainTheme.baseIconHeight
             self._headerDec = [
                 self.loadDecoration("deco_doc_h0", h=iPx),
                 self.loadDecoration("deco_doc_h1", h=iPx),
@@ -685,9 +733,9 @@ class GuiIcons:
         return self._headerDec[minmax(hLevel, 0, 4)]
 
     def getHeaderDecorationNarrow(self, hLevel: int) -> QPixmap:
-        """Get the narrow decoration for a specific header level."""
+        """Get the narrow decoration for a specific heading level."""
         if not self._headerDecNarrow:
-            iPx = self.mainTheme.baseIconSize
+            iPx = self.mainTheme.baseIconHeight
             self._headerDecNarrow = [
                 self.loadDecoration("deco_doc_h0_n", h=iPx),
                 self.loadDecoration("deco_doc_h1_n", h=iPx),
@@ -708,7 +756,7 @@ class GuiIcons:
         """
         if name not in self.ICON_KEYS:
             logger.error("Requested unknown icon name '%s'", name)
-            return QIcon()
+            return self._noIcon
 
         # If we just want the app icons, return right away
         if name == "novelwriter":
@@ -724,14 +772,18 @@ class GuiIcons:
         # If we didn't find one, give up and return an empty icon
         logger.warning("Did not load an icon for '%s'", name)
 
-        return QIcon()
-
-# END Class GuiIcons
+        return self._noIcon
 
 
-# =============================================================================================== #
-#  Module Functions
-# =============================================================================================== #
+# Module Functions
+# ================
+
+
+def _sortTheme(data: tuple[str, str]) -> str:
+    """Key function for theme sorting."""
+    key, name = data
+    return f"*{name}" if key.startswith("default_") else name
+
 
 def _loadInternalName(confParser: NWConfigParser, confFile: str | Path) -> str:
     """Open a conf file and read the 'name' setting."""
