@@ -23,43 +23,43 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-import random
 import logging
+import random
 
-from PyQt5.QtCore import Qt, pyqtSlot
+from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import (
-    QDialog, QDialogButtonBox, QGridLayout, QHBoxLayout, QLabel, QSpinBox,
-    QVBoxLayout, QWidget
+    QDialogButtonBox, QGridLayout, QHBoxLayout, QLabel, QSpinBox, QVBoxLayout,
+    QWidget
 )
 
 from novelwriter import CONFIG, SHARED
 from novelwriter.common import readTextFile
+from novelwriter.extensions.modified import NDialog
 from novelwriter.extensions.switch import NSwitch
+from novelwriter.types import QtAlignLeft, QtAlignRight, QtDialogClose, QtRoleAction
 
 logger = logging.getLogger(__name__)
 
 
-class GuiLipsum(QDialog):
+class GuiLipsum(NDialog):
 
     def __init__(self, parent: QWidget) -> None:
         super().__init__(parent=parent)
 
         logger.debug("Create: GuiLipsum")
         self.setObjectName("GuiLipsum")
-        if CONFIG.osDarwin:
-            self.setWindowFlag(Qt.WindowType.Tool)
+        self.setWindowTitle(self.tr("Insert Placeholder Text"))
 
         self._lipsumText = ""
 
-        self.setWindowTitle(self.tr("Insert Placeholder Text"))
+        vSp = CONFIG.pxInt(4)
+        nPx = CONFIG.pxInt(64)
 
         self.innerBox = QHBoxLayout()
         self.innerBox.setSpacing(CONFIG.pxInt(16))
 
         # Icon
-        nPx = CONFIG.pxInt(64)
-        vSp = CONFIG.pxInt(4)
-        self.docIcon = QLabel()
+        self.docIcon = QLabel(self)
         self.docIcon.setPixmap(SHARED.theme.getPixmap("proj_document", (nPx, nPx)))
 
         self.leftBox = QVBoxLayout()
@@ -69,40 +69,39 @@ class GuiLipsum(QDialog):
         self.innerBox.addLayout(self.leftBox)
 
         # Form
-        self.headLabel = QLabel("<b>{0}</b>".format(self.tr("Insert Lorem Ipsum Text")))
+        self.headLabel = QLabel(self.tr("Insert Lorem Ipsum Text"))
+        self.headLabel.setFont(SHARED.theme.guiFontB)
 
-        self.paraLabel = QLabel(self.tr("Number of paragraphs"))
-        self.paraCount = QSpinBox()
+        self.paraLabel = QLabel(self.tr("Number of paragraphs"), self)
+        self.paraCount = QSpinBox(self)
         self.paraCount.setMinimum(1)
         self.paraCount.setMaximum(100)
         self.paraCount.setValue(5)
 
-        self.randLabel = QLabel(self.tr("Randomise order"))
-        self.randSwitch = NSwitch()
+        self.randLabel = QLabel(self.tr("Randomise order"), self)
+        self.randSwitch = NSwitch(self)
 
         self.formBox = QGridLayout()
-        self.formBox.addWidget(self.headLabel, 0, 0, 1, 2, Qt.AlignLeft)
-        self.formBox.addWidget(self.paraLabel, 1, 0, 1, 1, Qt.AlignLeft)
-        self.formBox.addWidget(self.paraCount, 1, 1, 1, 1, Qt.AlignRight)
-        self.formBox.addWidget(self.randLabel, 2, 0, 1, 1, Qt.AlignLeft)
-        self.formBox.addWidget(self.randSwitch, 2, 1, 1, 1, Qt.AlignRight)
+        self.formBox.addWidget(self.headLabel, 0, 0, 1, 2, QtAlignLeft)
+        self.formBox.addWidget(self.paraLabel, 1, 0, 1, 1, QtAlignLeft)
+        self.formBox.addWidget(self.paraCount, 1, 1, 1, 1, QtAlignRight)
+        self.formBox.addWidget(self.randLabel, 2, 0, 1, 1, QtAlignLeft)
+        self.formBox.addWidget(self.randSwitch, 2, 1, 1, 1, QtAlignRight)
         self.formBox.setVerticalSpacing(vSp)
         self.formBox.setRowStretch(3, 1)
         self.innerBox.addLayout(self.formBox)
 
         # Buttons
-        self.buttonBox = QDialogButtonBox()
-        self.buttonBox.rejected.connect(self.close)
+        self.buttonBox = QDialogButtonBox(self)
+        self.buttonBox.rejected.connect(self.reject)
 
-        self.btnClose = self.buttonBox.addButton(QDialogButtonBox.Close)
+        self.btnClose = self.buttonBox.addButton(QtDialogClose)
         self.btnClose.setAutoDefault(False)
 
-        self.btnInsert = self.buttonBox.addButton(self.tr("Insert"), QDialogButtonBox.ActionRole)
+        self.btnInsert = self.buttonBox.addButton(self.tr("Insert"), QtRoleAction)
         self.btnInsert.clicked.connect(self._doInsert)
         self.btnInsert.setAutoDefault(False)
 
-        self.rejected.connect(self.close)
-
         # Assemble
         self.outerBox = QVBoxLayout()
         self.outerBox.addLayout(self.innerBox)
@@ -127,9 +126,9 @@ class GuiLipsum(QDialog):
     def getLipsum(cls, parent: QWidget) -> str:
         """Pop the dialog and return the lipsum text."""
         cls = GuiLipsum(parent)
-        cls.exec_()
+        cls.exec()
         text = cls.lipsumText
-        cls.deleteLater()
+        cls.softDelete()
         return text
 
     ##
@@ -147,5 +146,3 @@ class GuiLipsum(QDialog):
         self._lipsumText = "\n\n".join(lipsumText[0:pCount]) + "\n\n"
         self.close()
         return
-
-# END Class GuiLipsum
