@@ -29,18 +29,24 @@ import logging
 from datetime import datetime
 from typing import TYPE_CHECKING
 
-from PyQt5.QtGui import QCloseEvent, QPixmap, QCursor
 from PyQt5.QtCore import Qt, pyqtSlot
+from PyQt5.QtGui import QCloseEvent, QCursor, QPixmap
 from PyQt5.QtWidgets import (
-    qApp, QDialog, QTreeWidget, QTreeWidgetItem, QDialogButtonBox, QGridLayout,
-    QLabel, QGroupBox, QMenu, QAction, QFileDialog, QSpinBox, QHBoxLayout
+    QAction, QApplication, QDialogButtonBox, QFileDialog, QGridLayout,
+    QGroupBox, QHBoxLayout, QLabel, QMenu, QSpinBox, QTreeWidget,
+    QTreeWidgetItem
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.error import formatException
-from novelwriter.common import formatTime, checkInt, checkIntTuple, minmax
+from novelwriter.common import checkInt, checkIntTuple, formatTime, minmax
 from novelwriter.constants import nwConst
+from novelwriter.error import formatException
+from novelwriter.extensions.modified import NToolDialog
 from novelwriter.extensions.switch import NSwitch
+from novelwriter.types import (
+    QtAlignLeftMiddle, QtAlignRight, QtAlignRightMiddle, QtDecoration,
+    QtDialogClose, QtRoleAction
+)
 
 if TYPE_CHECKING:  # pragma: no cover
     from novelwriter.guimain import GuiMain
@@ -48,7 +54,7 @@ if TYPE_CHECKING:  # pragma: no cover
 logger = logging.getLogger(__name__)
 
 
-class GuiWritingStats(QDialog):
+class GuiWritingStats(NToolDialog):
     """GUI Tools: Writing Statistics
 
     Displays data from the NWSessionLog object.
@@ -63,13 +69,11 @@ class GuiWritingStats(QDialog):
     FMT_JSON = 0
     FMT_CSV  = 1
 
-    def __init__(self, mainGui: GuiMain) -> None:
-        super().__init__(parent=mainGui)
+    def __init__(self, parent: GuiMain) -> None:
+        super().__init__(parent=parent)
 
         logger.debug("Create: GuiWritingStats")
         self.setObjectName("GuiWritingStats")
-        if CONFIG.osDarwin:
-            self.setWindowFlag(Qt.WindowType.Tool)
 
         self.logData    = []
         self.filterData = []
@@ -100,7 +104,7 @@ class GuiWritingStats(QDialog):
             pOptions.getInt("GuiWritingStats", "widthCol3", 80)
         )
 
-        self.listBox = QTreeWidget()
+        self.listBox = QTreeWidget(self)
         self.listBox.setHeaderLabels([
             self.tr("Session Start"),
             self.tr("Length"),
@@ -116,14 +120,15 @@ class GuiWritingStats(QDialog):
 
         hHeader = self.listBox.headerItem()
         if hHeader is not None:
-            hHeader.setTextAlignment(self.C_LENGTH, Qt.AlignRight)
-            hHeader.setTextAlignment(self.C_IDLE, Qt.AlignRight)
-            hHeader.setTextAlignment(self.C_COUNT, Qt.AlignRight)
+            hHeader.setTextAlignment(self.C_LENGTH, QtAlignRight)
+            hHeader.setTextAlignment(self.C_IDLE, QtAlignRight)
+            hHeader.setTextAlignment(self.C_COUNT, QtAlignRight)
 
+        sDec = Qt.SortOrder.DescendingOrder
+        sAsc = Qt.SortOrder.AscendingOrder
         sortCol = minmax(pOptions.getInt("GuiWritingStats", "sortCol", 0), 0, 2)
         sortOrder = checkIntTuple(
-            pOptions.getInt("GuiWritingStats", "sortOrder", Qt.DescendingOrder),
-            (Qt.AscendingOrder, Qt.DescendingOrder), Qt.DescendingOrder
+            pOptions.getInt("GuiWritingStats", "sortOrder", sDec), (sAsc, sDec), sDec
         )
         self.listBox.sortByColumn(sortCol, sortOrder)  # type: ignore
         self.listBox.setSortingEnabled(True)
@@ -139,36 +144,36 @@ class GuiWritingStats(QDialog):
         self.infoForm = QGridLayout(self)
         self.infoBox.setLayout(self.infoForm)
 
-        self.labelTotal = QLabel(formatTime(0))
+        self.labelTotal = QLabel(formatTime(0), self)
         self.labelTotal.setFont(SHARED.theme.guiFontFixed)
-        self.labelTotal.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
+        self.labelTotal.setAlignment(QtAlignRightMiddle)
 
-        self.labelIdleT = QLabel(formatTime(0))
+        self.labelIdleT = QLabel(formatTime(0), self)
         self.labelIdleT.setFont(SHARED.theme.guiFontFixed)
-        self.labelIdleT.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
+        self.labelIdleT.setAlignment(QtAlignRightMiddle)
 
-        self.labelFilter = QLabel(formatTime(0))
+        self.labelFilter = QLabel(formatTime(0), self)
         self.labelFilter.setFont(SHARED.theme.guiFontFixed)
-        self.labelFilter.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
+        self.labelFilter.setAlignment(QtAlignRightMiddle)
 
-        self.novelWords = QLabel("0")
+        self.novelWords = QLabel("0", self)
         self.novelWords.setFont(SHARED.theme.guiFontFixed)
-        self.novelWords.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
+        self.novelWords.setAlignment(QtAlignRightMiddle)
 
-        self.notesWords = QLabel("0")
+        self.notesWords = QLabel("0", self)
         self.notesWords.setFont(SHARED.theme.guiFontFixed)
-        self.notesWords.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
+        self.notesWords.setAlignment(QtAlignRightMiddle)
 
-        self.totalWords = QLabel("0")
+        self.totalWords = QLabel("0", self)
         self.totalWords.setFont(SHARED.theme.guiFontFixed)
-        self.totalWords.setAlignment(Qt.AlignVCenter | Qt.AlignRight)
+        self.totalWords.setAlignment(QtAlignRightMiddle)
 
-        lblTTime   = QLabel(self.tr("Total Time:"))
-        lblITime   = QLabel(self.tr("Idle Time:"))
-        lblFTime   = QLabel(self.tr("Filtered Time:"))
-        lblNvCount = QLabel(self.tr("Novel Word Count:"))
-        lblNtCount = QLabel(self.tr("Notes Word Count:"))
-        lblTtCount = QLabel(self.tr("Total Word Count:"))
+        lblTTime   = QLabel(self.tr("Total Time:"), self)
+        lblITime   = QLabel(self.tr("Idle Time:"), self)
+        lblFTime   = QLabel(self.tr("Filtered Time:"), self)
+        lblNvCount = QLabel(self.tr("Novel Word Count:"), self)
+        lblNtCount = QLabel(self.tr("Notes Word Count:"), self)
+        lblTtCount = QLabel(self.tr("Total Word Count:"), self)
 
         self.infoForm.addWidget(lblTTime,   0, 0)
         self.infoForm.addWidget(lblITime,   1, 0)
@@ -187,54 +192,54 @@ class GuiWritingStats(QDialog):
         self.infoForm.setRowStretch(6, 1)
 
         # Filter Options
-        sPx = SHARED.theme.baseIconSize
+        iPx = SHARED.theme.baseIconHeight
 
         self.filterBox = QGroupBox(self.tr("Filters"), self)
         self.filterForm = QGridLayout(self)
         self.filterBox.setLayout(self.filterForm)
 
-        self.incNovel = NSwitch(width=2*sPx, height=sPx)
+        self.incNovel = NSwitch(self, height=iPx)
         self.incNovel.setChecked(
             pOptions.getBool("GuiWritingStats", "incNovel", True)
         )
         self.incNovel.clicked.connect(self._updateListBox)
 
-        self.incNotes = NSwitch(width=2*sPx, height=sPx)
+        self.incNotes = NSwitch(self, height=iPx)
         self.incNotes.setChecked(
             pOptions.getBool("GuiWritingStats", "incNotes", True)
         )
         self.incNotes.clicked.connect(self._updateListBox)
 
-        self.hideZeros = NSwitch(width=2*sPx, height=sPx)
+        self.hideZeros = NSwitch(self, height=iPx)
         self.hideZeros.setChecked(
             pOptions.getBool("GuiWritingStats", "hideZeros", True)
         )
         self.hideZeros.clicked.connect(self._updateListBox)
 
-        self.hideNegative = NSwitch(width=2*sPx, height=sPx)
+        self.hideNegative = NSwitch(self, height=iPx)
         self.hideNegative.setChecked(
             pOptions.getBool("GuiWritingStats", "hideNegative", False)
         )
         self.hideNegative.clicked.connect(self._updateListBox)
 
-        self.groupByDay = NSwitch(width=2*sPx, height=sPx)
+        self.groupByDay = NSwitch(self, height=iPx)
         self.groupByDay.setChecked(
             pOptions.getBool("GuiWritingStats", "groupByDay", False)
         )
         self.groupByDay.clicked.connect(self._updateListBox)
 
-        self.showIdleTime = NSwitch(width=2*sPx, height=sPx)
+        self.showIdleTime = NSwitch(self, height=iPx)
         self.showIdleTime.setChecked(
             pOptions.getBool("GuiWritingStats", "showIdleTime", False)
         )
         self.showIdleTime.clicked.connect(self._updateListBox)
 
-        self.filterForm.addWidget(QLabel(self.tr("Count novel files")),        0, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Count note files")),         1, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Hide zero word count")),     2, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Hide negative word count")), 3, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Group entries by day")),     4, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Show idle time")),           5, 0)
+        self.filterForm.addWidget(QLabel(self.tr("Count novel files"), self),        0, 0)
+        self.filterForm.addWidget(QLabel(self.tr("Count note files"), self),         1, 0)
+        self.filterForm.addWidget(QLabel(self.tr("Hide zero word count"), self),     2, 0)
+        self.filterForm.addWidget(QLabel(self.tr("Hide negative word count"), self), 3, 0)
+        self.filterForm.addWidget(QLabel(self.tr("Group entries by day"), self),     4, 0)
+        self.filterForm.addWidget(QLabel(self.tr("Show idle time"), self),           5, 0)
         self.filterForm.addWidget(self.incNovel,     0, 1)
         self.filterForm.addWidget(self.incNotes,     1, 1)
         self.filterForm.addWidget(self.hideZeros,    2, 1)
@@ -255,17 +260,17 @@ class GuiWritingStats(QDialog):
 
         self.optsBox = QHBoxLayout()
         self.optsBox.addStretch(1)
-        self.optsBox.addWidget(QLabel(self.tr("Word count cap for the histogram")), 0)
+        self.optsBox.addWidget(QLabel(self.tr("Word count cap for the histogram"), self), 0)
         self.optsBox.addWidget(self.histMax, 0)
 
         # Buttons
-        self.buttonBox = QDialogButtonBox()
+        self.buttonBox = QDialogButtonBox(self)
         self.buttonBox.rejected.connect(self._doClose)
 
-        self.btnClose = self.buttonBox.addButton(QDialogButtonBox.Close)
+        self.btnClose = self.buttonBox.addButton(QtDialogClose)
         self.btnClose.setAutoDefault(False)
 
-        self.btnSave = self.buttonBox.addButton(self.tr("Save As"), QDialogButtonBox.ActionRole)
+        self.btnSave = self.buttonBox.addButton(self.tr("Save As"), QtRoleAction)
         self.btnSave.setAutoDefault(False)
 
         self.saveMenu = QMenu(self)
@@ -300,10 +305,10 @@ class GuiWritingStats(QDialog):
 
     def populateGUI(self) -> None:
         """Populate list box with data from the log file."""
-        qApp.setOverrideCursor(QCursor(Qt.WaitCursor))
+        QApplication.setOverrideCursor(QCursor(Qt.CursorShape.WaitCursor))
         self._loadLogFile()
         self._updateListBox()
-        qApp.restoreOverrideCursor()
+        QApplication.restoreOverrideCursor()
         return
 
     ##
@@ -313,7 +318,7 @@ class GuiWritingStats(QDialog):
     def closeEvent(self, event: QCloseEvent) -> None:
         """Capture the user closing the window."""
         event.accept()
-        self.deleteLater()
+        self.softDelete()
         return
 
     ##
@@ -379,14 +384,14 @@ class GuiWritingStats(QDialog):
             return False
 
         # Generate the file name
-        savePath = CONFIG.lastPath() / f"sessionStats.{fileExt}"
+        savePath = CONFIG.lastPath("stats") / f"sessionStats.{fileExt}"
         savePath, _ = QFileDialog.getSaveFileName(
-            self, self.tr("Save Data As"), str(savePath), "%s (*.%s)" % (textFmt, fileExt)
+            self, self.tr("Save Data As"), str(savePath), f"{textFmt} (*.{fileExt})"
         )
         if not savePath:
             return False
 
-        CONFIG.setLastPath(savePath)
+        CONFIG.setLastPath("stats", savePath)
 
         # Do the actual writing
         wSuccess = False
@@ -569,6 +574,8 @@ class GuiWritingStats(QDialog):
             pcTotal = wcTotal
 
         # Populate the list
+        mTrans = Qt.TransformationMode.FastTransformation
+        mAspect = Qt.AspectRatioMode.IgnoreAspectRatio
         showIdleTime = self.showIdleTime.isChecked()
         for _, sStart, sDiff, nWords, _, _, sIdle in self.filterData:
 
@@ -585,18 +592,16 @@ class GuiWritingStats(QDialog):
             newItem.setText(self.C_COUNT, f"{nWords:n}")
 
             if nWords > 0 and listMax > 0:
-                theBar = self.barImage.scaled(
+                wBar = self.barImage.scaled(
                     int(200*min(nWords, histMax)/listMax),
-                    self.barHeight,
-                    Qt.IgnoreAspectRatio,
-                    Qt.FastTransformation
+                    self.barHeight, mAspect, mTrans
                 )
-                newItem.setData(self.C_BAR, Qt.DecorationRole, theBar)
+                newItem.setData(self.C_BAR, QtDecoration, wBar)
 
-            newItem.setTextAlignment(self.C_LENGTH, Qt.AlignRight)
-            newItem.setTextAlignment(self.C_IDLE, Qt.AlignRight)
-            newItem.setTextAlignment(self.C_COUNT, Qt.AlignRight)
-            newItem.setTextAlignment(self.C_BAR, Qt.AlignLeft | Qt.AlignVCenter)
+            newItem.setTextAlignment(self.C_LENGTH, QtAlignRight)
+            newItem.setTextAlignment(self.C_IDLE, QtAlignRight)
+            newItem.setTextAlignment(self.C_COUNT, QtAlignRight)
+            newItem.setTextAlignment(self.C_BAR, QtAlignLeftMiddle)
 
             newItem.setFont(self.C_TIME, SHARED.theme.guiFontFixed)
             newItem.setFont(self.C_LENGTH, SHARED.theme.guiFontFixed)
@@ -609,5 +614,3 @@ class GuiWritingStats(QDialog):
         self.labelFilter.setText(formatTime(round(self.timeFilter)))
 
         return
-
-# END Class GuiWritingStats
